@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 #
-# Copyright 2020 MongoDB, Inc.
+# Copyright 2009-present MongoDB, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -88,7 +88,7 @@ ISSUE_TYPE_ID = {'Backport': '10300',
               show_default=True,
               help='The remote reference which points to the mongodb/mongo-cxx-driver repo')
 @click.option('--c-driver-build-ref',
-              default='1.25.0',
+              default='1.29.0',
               show_default=True,
               help='When building the C driver, build at this Git reference')
 @click.option('--with-c-driver',
@@ -187,6 +187,10 @@ def release(jira_creds_file,
             click.echo('C++ driver distribution not built or not found...exiting!', err=True)
             sys.exit(1)
 
+    click.echo('Signing distribution...')
+    run_shell_script(f'./etc/garasign_dist_file.sh {dist_file}')
+    click.echo('Signing distribution... done.')
+
     jira_vers_dict = get_jira_project_versions(auth_jira)
 
     if release_version not in jira_vers_dict.keys():
@@ -403,7 +407,7 @@ def build_c_driver(c_driver_build_ref, quiet):
 
     env = os.environ.copy()
     env['mongoc_version'] = c_driver_build_ref
-    run_shell_script('./.evergreen/install_c_driver.sh', env=env)
+    run_shell_script('./.evergreen/scripts/install-c-driver.sh', env=env)
 
     if not quiet:
         click.echo('Build of C Driver version "{}" was successful.'.format(c_driver_build_ref))
@@ -434,10 +438,10 @@ def build_distribution(release_tag, release_version, c_driver_dir, quiet, skip_d
         click.echo('Clear ./build with "git clean -xdf ./build"', err=True)
         return None
 
-    run_shell_script('. .evergreen/find_cmake.sh;'
+    run_shell_script('. .evergreen/scripts/find-cmake-old.sh;'
                      'cd build;'
                      'echo ' + release_version + ' > VERSION_CURRENT;'
-                     '${CMAKE} -DCMAKE_BUILD_TYPE=Release '
+                     '${CMAKE} -DCMAKE_BUILD_TYPE=Release -DENABLE_TESTS=ON '
                      '-DCMAKE_PREFIX_PATH="' + c_driver_dir + '" '
                      '-DENABLE_UNINSTALL=ON ..;'
                      'cmake --build . --target dist')
@@ -496,6 +500,7 @@ def get_jira_project_versions(auth_jira):
 def get_all_issues_for_version(auth_jira, release_version):
     """
     Return a list of all issues in the project assigned to the given release.
+    Excludes the ticket created to track the release itself.
     """
 
     jql_query = 'project={} and fixVersion={} and (labels IS EMPTY OR labels != release) ORDER BY issueKey ASC'\
@@ -572,6 +577,9 @@ def generate_release_notes(release_version: str, changelog_contents: str) -> str
     - [Create an account](https://jira.mongodb.org) and login.
     - Navigate to the [CXX project](https://jira.mongodb.org/browse/CXX)
     - Click `Create`.
+
+    ## Signature Verification
+    Release artifacts may be verified by using the accompanying detached signature (.asc) and the cpp-driver public key obtained from https://pgp.mongodb.com.
     """).lstrip()
 
     release_notes = "".join(lines) + "\n"
@@ -649,7 +657,9 @@ def create_github_release_draft(gh_repo,
     gh_release = gh_repo.create_git_release(tag=release_tag, name=release_name,
                                             message=release_notes_text, draft=True,
                                             prerelease=is_pre_release)
+
     gh_release.upload_asset(dist_file)
+    gh_release.upload_asset(dist_file + ".asc")
 
     click.echo('Github release has been created.  Review and publish here: {}'
                .format(gh_release.html_url))
