@@ -1,4 +1,4 @@
-// Copyright 2015 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -21,9 +21,11 @@
 
 #include <bsoncxx/config/prelude.hpp>
 
+#include <examples/macros.hh>
+
 using namespace bsoncxx;
 
-int main(int, char**) {
+int EXAMPLES_CDECL main() {
     using namespace builder::stream;
 
     builder::stream::document build_doc;
@@ -88,7 +90,7 @@ int main(int, char**) {
 
     // Make all variables used.
     return (awards && first_award_year && second_award_year && last_name && id_i32 == 1 &&
-            0 == first_name_str.compare("John"))
+            first_name_str == "John")
                ? EXIT_SUCCESS
                : EXIT_FAILURE;
 }
