@@ -1,4 +1,4 @@
-// Copyright 2016 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,7 +17,6 @@
 #include <iterator>
 #include <vector>
 
-#include <bsoncxx/array/view.hpp>
 #include <bsoncxx/array/view.hpp>
 #include <bsoncxx/builder/basic/array.hpp>
 #include <bsoncxx/builder/basic/document.hpp>
@@ -30,9 +29,11 @@
 #include <bsoncxx/types.hpp>
 #include <bsoncxx/types/bson_value/view.hpp>
 
+#include <examples/macros.hh>
+
 using namespace bsoncxx;
 
-int main(int, char**) {
+int EXAMPLES_CDECL main() {
     // This example will cover the read-only BSON interface.
 
     // Lets first build up a non-trivial BSON document using the builder interface.
@@ -59,17 +60,17 @@ int main(int, char**) {
     // note that all of the interesting methods for reading BSON are defined on the view type.
 
     // iterate over the elements in a bson document
-    for (document::element ele : view) {
+    for (document::element doc_ele : view) {
         // element is non owning view of a key-value pair within a document.
 
         // we can use the key() method to get a string_view of the key.
-        stdx::string_view field_key{ele.key()};
+        stdx::string_view field_key{doc_ele.key()};
 
         std::cout << "Got key, key = " << field_key << std::endl;
 
         // we can use type() to get the type of the value.
-        switch (ele.type()) {
-            case type::k_utf8:
+        switch (doc_ele.type()) {
+            case type::k_string:
                 std::cout << "Got String!" << std::endl;
                 break;
             case type::k_oid:
@@ -78,20 +79,40 @@ int main(int, char**) {
             case type::k_array: {
                 std::cout << "Got Array!" << std::endl;
                 // if we have a subarray, we can access it by getting a view of it.
-                array::view subarr{ele.get_array().value};
-                for (array::element ele : subarr) {
+                array::view subarr{doc_ele.get_array().value};
+                for (array::element arr_ele : subarr) {
                     std::cout << "array element: "
-                              << bsoncxx::string::to_string(ele.get_utf8().value) << std::endl;
+                              << bsoncxx::string::to_string(arr_ele.get_string().value)
+                              << std::endl;
                 }
                 break;
             }
-            default:
+
+            case type::k_double:
+            case type::k_document:
+            case type::k_binary:
+            case type::k_undefined:
+            case type::k_bool:
+            case type::k_date:
+            case type::k_null:
+            case type::k_regex:
+            case type::k_dbpointer:
+            case type::k_code:
+            case type::k_symbol:
+            case type::k_codewscope:
+            case type::k_int32:
+            case type::k_timestamp:
+            case type::k_int64:
+            case type::k_decimal128:
+            case type::k_maxkey:
+            case type::k_minkey:
                 std::cout << "We messed up!" << std::endl;
+                break;
         }
 
         // usually we don't need to actually use a switch statement, because we can also
         // get a variant 'value' that can hold any BSON type.
-        types::bson_value::view ele_val{ele.get_value()};
+        types::bson_value::view doc_ele_val{doc_ele.get_value()};
     }
 
     // If we want to search for an element we can use operator[]
