@@ -1,7 +1,7 @@
-#!/bin/bash
+#!/usr/bin/env bash
+
 set -o errexit
 set -o pipefail
-set -o xtrace
 
 CXX=${CXX:-c++}
 CXX_STANDARD=${CXX_STANDARD:-11}
