@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -16,8 +16,11 @@
 
 #include <memory>
 #include <stdexcept>
+#include <string>
 #include <type_traits>
 
+#include <bsoncxx/builder/core-fwd.hpp>
+
 #include <bsoncxx/array/value.hpp>
 #include <bsoncxx/array/view.hpp>
 #include <bsoncxx/document/value.hpp>
@@ -29,7 +32,7 @@
 #include <bsoncxx/config/prelude.hpp>
 
 namespace bsoncxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace builder {
 
 ///
@@ -40,9 +43,9 @@ namespace builder {
 ///   using this class directly. However, developers who wish to write their own abstractions may
 ///   find this class useful.
 ///
-class BSONCXX_API core {
+class core {
    public:
-    class BSONCXX_PRIVATE impl;
+    class impl;
 
     ///
     /// Constructs an empty BSON datum.
@@ -50,12 +53,15 @@ class BSONCXX_API core {
     /// @param is_array
     ///   True if the top-level BSON datum should be an array.
     ///
-    explicit core(bool is_array);
+    explicit BSONCXX_ABI_EXPORT_CDECL() core(bool is_array);
 
-    core(core&& rhs) noexcept;
-    core& operator=(core&& rhs) noexcept;
+    BSONCXX_ABI_EXPORT_CDECL() core(core&& rhs) noexcept;
+    BSONCXX_ABI_EXPORT_CDECL(core&) operator=(core&& rhs) noexcept;
 
-    ~core();
+    BSONCXX_ABI_EXPORT_CDECL() ~core();
+
+    core(const core&) = delete;
+    core& operator=(const core&) = delete;
 
     ///
     /// Appends a key passed as a non-owning stdx::string_view.
@@ -74,10 +80,10 @@ class BSONCXX_API core {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @throws bsoncxx::exception if the current BSON datum is an array or if the previous value
-    /// appended to the builder was also a key.
+    /// @throws bsoncxx::v_noabi::exception if the current BSON datum is an array or if the previous
+    /// value appended to the builder was also a key.
     ///
-    core& key_view(stdx::string_view key);
+    BSONCXX_ABI_EXPORT_CDECL(core&) key_view(stdx::string_view key);
 
     ///
     /// Appends a key passed as an STL string.  Transfers ownership of the key to this class.
@@ -89,10 +95,10 @@ class BSONCXX_API core {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @throws bsoncxx::exception if the current BSON datum is an array or if the previous value
-    /// appended to the builder was a key.
+    /// @throws bsoncxx::v_noabi::exception if the current BSON datum is an array or if the previous
+    /// value appended to the builder was a key.
     ///
-    core& key_owned(std::string key);
+    BSONCXX_ABI_EXPORT_CDECL(core&) key_owned(std::string key);
 
     ///
     /// Opens a sub-document within this BSON datum.
@@ -102,10 +108,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& open_document();
+    BSONCXX_ABI_EXPORT_CDECL(core&) open_document();
 
     ///
     /// Opens a sub-array within this BSON datum.
@@ -115,10 +121,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& open_array();
+    BSONCXX_ABI_EXPORT_CDECL(core&) open_array();
 
     ///
     /// Closes the current sub-document within this BSON datum.
@@ -127,9 +133,9 @@ class BSONCXX_API core {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @throws bsoncxx::exception if the current BSON datum is not an open sub-document.
+    /// @throws bsoncxx::v_noabi::exception if the current BSON datum is not an open sub-document.
     ///
-    core& close_document();
+    BSONCXX_ABI_EXPORT_CDECL(core&) close_document();
 
     ///
     /// Closes the current sub-array within this BSON datum.
@@ -138,9 +144,9 @@ class BSONCXX_API core {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @throws bsoncxx::exception if the current BSON datum is not an open sub-array.
+    /// @throws bsoncxx::v_noabi::exception if the current BSON datum is not an open sub-array.
     ///
-    core& close_array();
+    BSONCXX_ABI_EXPORT_CDECL(core&) close_array();
 
     ///
     /// Appends the keys from a BSON document into this BSON datum.
@@ -157,9 +163,9 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if one of the keys fails to append.
+    ///   bsoncxx::v_noabi::exception if one of the keys fails to append.
     ///
-    core& concatenate(const document::view& view);
+    BSONCXX_ABI_EXPORT_CDECL(core&) concatenate(const bsoncxx::v_noabi::document::view& view);
 
     ///
     /// Appends a BSON double.
@@ -169,11 +175,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the double fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the double fails to append.
     ///
-    core& append(const types::b_double& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_double& value);
 
     ///
     /// Append a BSON UTF-8 string.
@@ -183,11 +189,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the string fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the string fails to append.
     ///
-    core& append(const types::b_string& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_string& value);
 
     ///
     /// Appends a BSON document.
@@ -197,11 +203,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the document fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the document fails to append.
     ///
-    core& append(const types::b_document& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_document& value);
 
     ///
     /// Appends a BSON array.
@@ -211,11 +217,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the array fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the array fails to append.
     ///
-    core& append(const types::b_array& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_array& value);
 
     ///
     /// Appends a BSON binary datum.
@@ -225,11 +231,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the binary fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the binary fails to append.
     ///
-    core& append(const types::b_binary& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_binary& value);
 
     ///
     /// Appends a BSON undefined.
@@ -239,11 +245,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if undefined fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if undefined fails to append.
     ///
-    core& append(const types::b_undefined& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_undefined& value);
 
     ///
     /// Appends a BSON ObjectId.
@@ -253,11 +259,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the ObjectId fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the ObjectId fails to append.
     ///
-    core& append(const types::b_oid& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_oid& value);
 
     ///
     /// Appends a BSON boolean.
@@ -267,11 +273,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the boolean fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the boolean fails to append.
     ///
-    core& append(const types::b_bool& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_bool& value);
 
     ///
     /// Appends a BSON date.
@@ -281,11 +287,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the date fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the date fails to append.
     ///
-    core& append(const types::b_date& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_date& value);
 
     ///
     /// Appends a BSON null.
@@ -295,11 +301,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if null fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if null fails to append.
     ///
-    core& append(const types::b_null& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_null& value);
 
     ///
     /// Appends a BSON regex.
@@ -309,11 +315,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the regex fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the regex fails to append.
     ///
-    core& append(const types::b_regex& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_regex& value);
 
     ///
     /// Appends a BSON DBPointer.
@@ -323,11 +329,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the DBPointer fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the DBPointer fails to append.
     ///
-    core& append(const types::b_dbpointer& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_dbpointer& value);
 
     ///
     /// Appends a BSON JavaScript code.
@@ -337,11 +343,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the JavaScript code fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the JavaScript code fails to append.
     ///
-    core& append(const types::b_code& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_code& value);
 
     ///
     /// Appends a BSON symbol.
@@ -351,11 +357,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the symbol fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the symbol fails to append.
     ///
-    core& append(const types::b_symbol& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_symbol& value);
 
     ///
     /// Appends a BSON JavaScript code with scope.
@@ -365,11 +371,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the JavaScript code with scope fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the JavaScript code with scope fails to append.
     ///
-    core& append(const types::b_codewscope& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_codewscope& value);
 
     ///
     /// Appends a BSON 32-bit signed integer.
@@ -379,11 +385,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the 32-bit signed integer fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the 32-bit signed integer fails to append.
     ///
-    core& append(const types::b_int32& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_int32& value);
 
     ///
     /// Appends a BSON replication timestamp.
@@ -393,11 +399,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the timestamp fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the timestamp fails to append.
     ///
-    core& append(const types::b_timestamp& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_timestamp& value);
 
     ///
     /// Appends a BSON 64-bit signed integer.
@@ -407,11 +413,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the 64-bit signed integer fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the 64-bit signed integer fails to append.
     ///
-    core& append(const types::b_int64& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_int64& value);
 
     ///
     /// Appends a BSON Decimal128.
@@ -421,11 +427,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the Decimal128 fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the Decimal128 fails to append.
     ///
-    core& append(const types::b_decimal128& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_decimal128& value);
 
     ///
     /// Appends a BSON min-key.
@@ -435,11 +441,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the min-key fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the min-key fails to append.
     ///
-    core& append(const types::b_minkey& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_minkey& value);
 
     ///
     /// Appends a BSON max-key.
@@ -449,11 +455,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
-    ///   bsoncxx::exception if the max-key fails to append.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the max-key fails to append.
     ///
-    core& append(const types::b_maxkey& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::b_maxkey& value);
 
     ///
     /// Appends a BSON variant value.
@@ -463,10 +469,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& append(const types::bson_value::view& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const types::bson_value::view& value);
 
     ///
     /// Appends an STL string as a BSON UTF-8 string.
@@ -476,10 +482,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& append(std::string str);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(std::string str);
 
     ///
     /// Appends a string view as a BSON UTF-8 string.
@@ -489,10 +495,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& append(stdx::string_view str);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(stdx::string_view str);
 
     ///
     /// Appends a char* or const char*.
@@ -504,11 +510,11 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
     template <typename T>
-    BSONCXX_INLINE core& append(T* v) {
+    core& append(T* v) {
         static_assert(detail::is_alike<T, char>::value,
                       "append is disabled for non-char pointer types");
         append(types::b_string{v});
@@ -524,10 +530,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& append(bool value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(bool value);
 
     ///
     /// Appends a native double as a BSON double.
@@ -537,10 +543,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& append(double value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(double value);
 
     ///
     /// Appends a native int32_t as a BSON 32-bit signed integer.
@@ -550,10 +556,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& append(std::int32_t value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(std::int32_t value);
 
     ///
     /// Appends a native int64_t as a BSON 64-bit signed integer.
@@ -563,10 +569,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& append(std::int64_t value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(std::int64_t value);
 
     ///
     /// Appends an oid as a BSON ObjectId.
@@ -576,10 +582,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& append(const oid& value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(const oid& value);
 
     ///
     /// Appends a decimal128 object as a BSON Decimal128.
@@ -589,10 +595,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& append(decimal128 value);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(decimal128 value);
 
     ///
     /// Appends the given document view.
@@ -602,10 +608,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& append(document::view view);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(bsoncxx::v_noabi::document::view view);
 
     ///
     /// Appends the given array view.
@@ -615,10 +621,10 @@ class BSONCXX_API core {
     ///   method chaining.
     ///
     /// @throws
-    ///   bsoncxx::exception if the current BSON datum is a document that is waiting for a key to be
-    ///   appended to start a new key/value pair.
+    ///   bsoncxx::v_noabi::exception if the current BSON datum is a document that is waiting for a
+    ///   key to be appended to start a new key/value pair.
     ///
-    core& append(array::view view);
+    BSONCXX_ABI_EXPORT_CDECL(core&) append(bsoncxx::v_noabi::array::view view);
 
     ///
     /// Gets a view over the document.
@@ -630,9 +636,9 @@ class BSONCXX_API core {
     ///    appended to start a new key/value pair, and does contain any open sub-documents or open
     ///    sub-arrays.
     ///
-    /// @throws bsoncxx::exception if the precondition is violated.
+    /// @throws bsoncxx::v_noabi::exception if the precondition is violated.
     ///
-    document::view view_document() const;
+    BSONCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::document::view) view_document() const;
 
     ///
     /// Gets a view over the array.
@@ -643,9 +649,9 @@ class BSONCXX_API core {
     ///    The top-level BSON datum should be an array that does not contain any open sub-documents
     ///    or open sub-arrays.
     ///
-    /// @throws bsoncxx::exception if the precondition is violated.
+    /// @throws bsoncxx::v_noabi::exception if the precondition is violated.
     ///
-    array::view view_array() const;
+    BSONCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::array::view) view_array() const;
 
     ///
     /// Transfers ownership of the underlying document to the caller.
@@ -657,13 +663,13 @@ class BSONCXX_API core {
     ///    appended to start a new key/value pair, and does not contain any open sub-documents or
     ///    open sub-arrays.
     ///
-    /// @throws bsoncxx::exception if the precondition is violated.
+    /// @throws bsoncxx::v_noabi::exception if the precondition is violated.
     ///
     /// @warning
     ///   After calling extract_document() it is illegal to call any methods on this class, unless
     ///   it is subsequenly moved into.
     ///
-    document::value extract_document();
+    BSONCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::document::value) extract_document();
 
     ///
     /// Transfers ownership of the underlying document to the caller.
@@ -674,19 +680,19 @@ class BSONCXX_API core {
     ///    The top-level BSON datum should be an array that does not contain any open sub-documents
     ///    or open sub-arrays.
     ///
-    /// @throws bsoncxx::exception if the precondition is violated.
+    /// @throws bsoncxx::v_noabi::exception if the precondition is violated.
     ///
     /// @warning
     ///   After calling extract_array() it is illegal to call any methods on this class, unless it
     ///   is subsequenly moved into.
     ///
-    array::value extract_array();
+    BSONCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::array::value) extract_array();
 
     ///
     /// Deletes the contents of the underlying BSON datum. After calling clear(), the state of this
     /// class will be the same as it was immediately after construction.
     ///
-    void clear();
+    BSONCXX_ABI_EXPORT_CDECL(void) clear();
 
    private:
     std::unique_ptr<impl> _impl;
@@ -697,3 +703,8 @@ class BSONCXX_API core {
 }  // namespace bsoncxx
 
 #include <bsoncxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref bsoncxx::v_noabi::builder::core.
+///
