@@ -1,4 +1,4 @@
-// Copyright 2020 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -30,16 +30,6 @@ namespace bsoncxx {
 namespace v_noabi {
 namespace builder {
 
-using namespace ::bsoncxx::v_noabi::types;  // Deprecated.
-
-}  // namespace builder
-}  // namespace v_noabi
-}  // namespace bsoncxx
-
-namespace bsoncxx {
-namespace v_noabi {
-namespace builder {
-
 ///
 /// A JSON-like builder for creating documents and arrays.
 ///
@@ -60,7 +50,8 @@ class list {
     /// @param value
     ///     the BSON value
     ///
-    /// @see bsoncxx::v_noabi::types::bson_value::value.
+    /// @see
+    /// - @ref bsoncxx::v_noabi::types::bson_value::value.
     ///
     template <typename T>
     list(T value) : val{value} {}
@@ -81,31 +72,34 @@ class list {
     ///     bsoncxx::v_noabi::builder::document or bsoncxx::v_noabi::builder::array constructor,
     ///     respectively.
     ///
-    /// @see bsoncxx::v_noabi::builder::document
-    /// @see bsoncxx::v_noabi::builder::array
+    /// @see
+    /// - @ref bsoncxx::v_noabi::builder::document
+    /// - @ref bsoncxx::v_noabi::builder::array
     ///
     list(initializer_list_t init) : list(init, true, true) {}
 
     ///
     /// Provides a view of the underlying BSON value.
     ///
-    /// @see bsoncxx::v_noabi::types::bson_value::view.
+    /// @see
+    /// - @ref bsoncxx::v_noabi::types::bson_value::view.
     ///
-    operator bson_value::view() {
+    operator types::bson_value::view() {
         return view();
     }
 
     ///
     /// Provides a view of the underlying BSON value.
     ///
-    /// @see bsoncxx::v_noabi::types::bson_value::view.
+    /// @see
+    /// - @ref bsoncxx::v_noabi::types::bson_value::view.
     ///
-    bson_value::view view() {
+    types::bson_value::view view() {
         return val.view();
     }
 
    private:
-    bson_value::value val;
+    types::bson_value::value val;
 
     friend ::bsoncxx::v_noabi::builder::document;
     friend ::bsoncxx::v_noabi::builder::array;
@@ -121,7 +115,7 @@ class list {
                 }
                 for (size_t i = 0; i < init.size(); i += 2) {
                     auto t = (begin(init) + i)->val.view().type();
-                    if (t != type::k_utf8) {
+                    if (t != type::k_string) {
                         err_msg << " : all keys must be string type. ";
                         err_msg << "Found type=" << to_string(t);
                         return false;
@@ -137,12 +131,12 @@ class list {
                 _core.key_owned(std::string((begin(init) + i)->val.view().get_string().value));
                 _core.append((begin(init) + i + 1)->val);
             }
-            val = bson_value::value(_core.extract_document());
+            val = types::bson_value::value(_core.extract_document());
         } else if (type_deduction || is_array) {
             core _core{true};
             for (auto&& ele : init)
                 _core.append(ele.val);
-            val = bson_value::value(_core.extract_array());
+            val = types::bson_value::value(_core.extract_array());
         } else {
             throw bsoncxx::v_noabi::exception{error_code::k_unmatched_key_in_builder,
                                               err_msg.str()};
@@ -160,7 +154,7 @@ class document : public list {
     ///
     /// Creates an empty document.
     ///
-    document() : list({}, false, false){};
+    document() : list({}, false, false) {}
 
     ///
     /// Creates a BSON document.
@@ -168,8 +162,9 @@ class document : public list {
     /// @param init
     ///     the initializer list used to construct the BSON document
     ///
-    /// @see bsoncxx::v_noabi::builder::list
-    /// @see bsoncxx::v_noabi::builder::array
+    /// @see
+    /// - @ref bsoncxx::v_noabi::builder::list
+    /// - @ref bsoncxx::v_noabi::builder::array
     ///
     document(initializer_list_t init) : list(init, false, false) {}
 };
@@ -184,7 +179,7 @@ class array : public list {
     ///
     /// Creates an empty array.
     ///
-    array() : list({}, false, true){};
+    array() : list({}, false, true) {}
 
     ///
     /// Creates a BSON array.
@@ -192,8 +187,9 @@ class array : public list {
     /// @param init
     ///     the initializer list used to construct the BSON array
     ///
-    /// @see bsoncxx::v_noabi::builder::list
-    /// @see bsoncxx::v_noabi::builder::document
+    /// @see
+    /// - @ref bsoncxx::v_noabi::builder::list
+    /// - @ref bsoncxx::v_noabi::builder::document
     ///
     array(initializer_list_t init) : list(init, false, true) {}
 };
@@ -201,15 +197,9 @@ class array : public list {
 }  // namespace v_noabi
 }  // namespace bsoncxx
 
-namespace bsoncxx {
-namespace builder {
-
-using namespace ::bsoncxx::v_noabi::types;  // Deprecated.
-
-}  // namespace builder
-}  // namespace bsoncxx
-
-// CXX-2770: missing include of postlude header.
-#if defined(BSONCXX_TEST_MACRO_GUARDS_FIX_MISSING_POSTLUDE)
 #include <bsoncxx/config/postlude.hpp>
-#endif
+
+///
+/// @file
+/// Provides entities for use with "list" BSON builder syntax.
+///
