@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -34,14 +34,14 @@ namespace document {
 ///
 class view {
    public:
-    class BSONCXX_API const_iterator;
+    class const_iterator;
     using iterator = const_iterator;
 
     ///
     /// Default constructs a view. The resulting view will be initialized to point at
     /// an empty BSON document.
     ///
-    view();
+    BSONCXX_ABI_EXPORT_CDECL() view();
 
     ///
     /// Constructs a view from a buffer. The caller is responsible for ensuring that
@@ -52,27 +52,27 @@ class view {
     /// @param length
     ///   The size of the buffer, in bytes.
     ///
-    view(const std::uint8_t* data, std::size_t length);
+    BSONCXX_ABI_EXPORT_CDECL() view(const std::uint8_t* data, std::size_t length);
 
     ///
     /// @returns A const_iterator to the first element of the document.
     ///
-    const_iterator cbegin() const;
+    BSONCXX_ABI_EXPORT_CDECL(const_iterator) cbegin() const;
 
     ///
     /// @returns A const_iterator to the past-the-end element of the document.
     ///
-    const_iterator cend() const;
+    BSONCXX_ABI_EXPORT_CDECL(const_iterator) cend() const;
 
     ///
     /// @returns A const_iterator to the first element of the document.
     ///
-    const_iterator begin() const;
+    BSONCXX_ABI_EXPORT_CDECL(const_iterator) begin() const;
 
     ///
     /// @returns A const_iterator to the past-the-end element of the document.
     ///
-    const_iterator end() const;
+    BSONCXX_ABI_EXPORT_CDECL(const_iterator) end() const;
 
     ///
     /// Finds the first element of the document with the provided key. If there is
@@ -89,7 +89,7 @@ class view {
     ///
     /// @return An iterator to the matching element, if found, or the past-the-end iterator.
     ///
-    const_iterator find(stdx::string_view key) const;
+    BSONCXX_ABI_EXPORT_CDECL(const_iterator) find(stdx::string_view key) const;
 
     ///
     /// Finds the first element of the document with the provided key. If there is no
@@ -101,14 +101,14 @@ class view {
     ///
     /// @return The matching element, if found, or the invalid element.
     ///
-    element operator[](stdx::string_view key) const;
+    BSONCXX_ABI_EXPORT_CDECL(element) operator[](stdx::string_view key) const;
 
     ///
     /// Access the raw bytes of the underlying document.
     ///
     /// @return A (non-owning) pointer to the view's buffer.
     ///
-    const std::uint8_t* data() const;
+    BSONCXX_ABI_EXPORT_CDECL(const std::uint8_t*) data() const;
 
     ///
     /// Gets the length of the underlying buffer.
@@ -118,7 +118,7 @@ class view {
     ///
     /// @return The length of the document, in bytes.
     ///
-    std::size_t length() const;
+    BSONCXX_ABI_EXPORT_CDECL(std::size_t) length() const;
 
     ///
     /// Checks if the underlying document is empty, i.e. it is equivalent to
@@ -126,18 +126,16 @@ class view {
     ///
     /// @return true if the underlying document is empty.
     ///
-    bool empty() const;
+    BSONCXX_ABI_EXPORT_CDECL(bool) empty() const;
 
+    ///
+    /// @relates bsoncxx::v_noabi::document::view
+    ///
+    /// Compare two document views for (in)-equality.
     ///
     /// @{
-    ///
-    /// Compare two document views for (in)-equality
-    ///
-    /// @relates view
-    ///
-    friend BSONCXX_API bool BSONCXX_CALL operator==(view, view);
-    friend BSONCXX_API bool BSONCXX_CALL operator!=(view, view);
-    ///
+    friend BSONCXX_ABI_EXPORT_CDECL(bool) operator==(view, view);
+    friend BSONCXX_ABI_EXPORT_CDECL(bool) operator!=(view, view);
     /// @}
     ///
 
@@ -163,25 +161,23 @@ class view::const_iterator {
     using iterator_category = std::forward_iterator_tag;
     using difference_type = std::ptrdiff_t;
 
-    const_iterator();
-    explicit const_iterator(const element& element);
+    BSONCXX_ABI_EXPORT_CDECL() const_iterator();
+    explicit BSONCXX_ABI_EXPORT_CDECL() const_iterator(const element& element);
 
-    reference operator*();
-    pointer operator->();
+    BSONCXX_ABI_EXPORT_CDECL(reference) operator*();
+    BSONCXX_ABI_EXPORT_CDECL(pointer) operator->();
 
-    const_iterator& operator++();
-    const_iterator operator++(int);
+    BSONCXX_ABI_EXPORT_CDECL(const_iterator&) operator++();
+    BSONCXX_ABI_EXPORT_CDECL(const_iterator) operator++(int);
 
+    ///
+    /// @relates bsoncxx::v_noabi::document::view::const_iterator
+    ///
+    /// Compares two const_iterators for (in)-equality.
     ///
     /// @{
-    ///
-    /// Compares two const_iterators for (in)-equality
-    ///
-    /// @relates view::const_iterator
-    ///
-    friend BSONCXX_API bool BSONCXX_CALL operator==(const const_iterator&, const const_iterator&);
-    friend BSONCXX_API bool BSONCXX_CALL operator!=(const const_iterator&, const const_iterator&);
-    ///
+    friend BSONCXX_ABI_EXPORT_CDECL(bool) operator==(const const_iterator&, const const_iterator&);
+    friend BSONCXX_ABI_EXPORT_CDECL(bool) operator!=(const const_iterator&, const const_iterator&);
     /// @}
     ///
 
@@ -194,3 +190,8 @@ class view::const_iterator {
 }  // namespace bsoncxx
 
 #include <bsoncxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref bsoncxx::v_noabi::document::view.
+///
