@@ -1,4 +1,4 @@
-// Copyright 2015 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -16,19 +16,41 @@
 
 #include <system_error>
 
+#include <bsoncxx/exception/exception-fwd.hpp>
+
 #include <bsoncxx/config/prelude.hpp>
 
 namespace bsoncxx {
-inline namespace v_noabi {
+namespace v_noabi {
+
+BSONCXX_PUSH_WARNINGS();
+BSONCXX_DISABLE_WARNING(MSVC(4251));
+BSONCXX_DISABLE_WARNING(MSVC(4275));
+
 ///
 /// Class representing any exceptions emitted from the bsoncxx library or
 /// its underlying implementation.
 ///
-class BSONCXX_API exception : public std::system_error {
+class exception : public std::system_error {
+   public:
+    ~exception() override;
+
+    exception(exception&&) = default;
+    exception& operator=(exception&&) = default;
+    exception(const exception&) = default;
+    exception& operator=(const exception&) = default;
+
     using std::system_error::system_error;
 };
 
+BSONCXX_POP_WARNINGS();
+
 }  // namespace v_noabi
 }  // namespace bsoncxx
 
 #include <bsoncxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref bsoncxx::v_noabi::exception.
+///
