@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -19,9 +19,9 @@
 #include <bsoncxx/exception/exception.hpp>
 #include <bsoncxx/private/itoa.hh>
 #include <bsoncxx/private/libbson.hh>
+#include <bsoncxx/private/make_unique.hh>
 #include <bsoncxx/private/stack.hh>
 #include <bsoncxx/private/suppress_deprecation_warnings.hh>
-#include <bsoncxx/stdx/make_unique.hpp>
 #include <bsoncxx/stdx/string_view.hpp>
 #include <bsoncxx/string/to_string.hpp>
 #include <bsoncxx/types.hpp>
@@ -256,7 +256,7 @@ class core::impl {
 };
 
 core::core(bool is_array) {
-    _impl = stdx::make_unique<impl>(is_array);
+    _impl = make_unique<impl>(is_array);
 }
 
 core::core(core&&) noexcept = default;
