@@ -1,4 +1,4 @@
-// Copyright 2016 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@
 #include <bsoncxx/exception/exception.hpp>
 #include <bsoncxx/json.hpp>
 #include <bsoncxx/private/libbson.hh>
+
 #include <bsoncxx/test/catch.hh>
 
 namespace {
@@ -54,14 +55,14 @@ TEST_CASE("valid json is converted to equivalent BSON") {
 
 TEST_CASE("empty document is converted correctly to json string") {
     using namespace bsoncxx;
-    REQUIRE(0 == to_json(make_document().view()).compare("{ }"));
+    REQUIRE(to_json(make_document().view()) == "{ }");
 }
 
 TEST_CASE("empty array is converted correctly to json string") {
     using bsoncxx::to_json;
 
     auto doc = make_document(kvp("array", make_array()));
-    REQUIRE(0 == to_json(doc.view()).compare(R"({ "array" : [  ] })"));
+    REQUIRE(to_json(doc.view()) == R"({ "array" : [  ] })");
 }
 
 TEST_CASE("CXX-941 is resolved") {
