@@ -1,4 +1,4 @@
-// Copyright 2018-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -29,52 +29,58 @@ namespace events {
 /// An event notification sent when the driver completes a "hello" command to check the status
 /// of a server.
 ///
-/// @see "ServerHeartbeatSucceededEvent" in
-/// https://github.com/mongodb/specifications/blob/master/source/server-discovery-and-monitoring/server-discovery-and-monitoring.rst
+/// @see
+/// - "ServerHeartbeatSucceededEvent" in https://github.com/mongodb/specifications/blob/master/source/server-discovery-and-monitoring/server-discovery-and-monitoring.md
 ///
 class heartbeat_succeeded_event {
    public:
-    MONGOCXX_PRIVATE explicit heartbeat_succeeded_event(const void* event);
+    explicit heartbeat_succeeded_event(const void* event);
 
     ///
     /// Destroys a heartbeat_succeeded_event.
     ///
-    ~heartbeat_succeeded_event();
+    MONGOCXX_ABI_EXPORT_CDECL() ~heartbeat_succeeded_event();
+
+    heartbeat_succeeded_event(heartbeat_succeeded_event&&) = default;
+    heartbeat_succeeded_event& operator=(heartbeat_succeeded_event&&) = default;
+
+    heartbeat_succeeded_event(const heartbeat_succeeded_event&) = default;
+    heartbeat_succeeded_event& operator=(const heartbeat_succeeded_event&) = default;
 
     ///
     /// Returns the server reply for the succeeded operation.
     ///
     /// @return The reply.
     ///
-    bsoncxx::v_noabi::document::view reply() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::document::view) reply() const;
 
     ///
     /// Returns the duration of the successful operation.
     ///
     /// @return The duration in microseconds.
     ///
-    std::int64_t duration() const;
+    MONGOCXX_ABI_EXPORT_CDECL(std::int64_t) duration() const;
 
     ///
     /// Returns the host name.
     ///
     /// @return The host name.
     ///
-    bsoncxx::v_noabi::stdx::string_view host() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::string_view) host() const;
 
     ///
     /// Returns the port.
     ///
     /// @return The port.
     ///
-    std::uint16_t port() const;
+    MONGOCXX_ABI_EXPORT_CDECL(std::uint16_t) port() const;
 
     ///
     /// Returns a boolean indicating whether this heartbeat event is from an awaitable hello.
     ///
     /// @return A boolean.
     ///
-    bool awaited() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bool) awaited() const;
 
    private:
     const void* _succeeded_event;
@@ -85,3 +91,8 @@ class heartbeat_succeeded_event {
 }  // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::events::heartbeat_succeeded_event.
+///
