@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,20 +14,32 @@
 
 #pragma once
 
+#include <mongocxx/exception/bulk_write_exception-fwd.hpp>
+
 #include <bsoncxx/document/value.hpp>
+
 #include <mongocxx/exception/operation_exception.hpp>
 
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
+
 ///
 /// Class representing an exception during a bulk write operation.
 ///
-/// @see mongocxx::operation_exception
+/// @see
+/// - @ref mongocxx::v_noabi::operation_exception
 ///
-class MONGOCXX_API bulk_write_exception : public operation_exception {
+class bulk_write_exception : public operation_exception {
    public:
+    ~bulk_write_exception() override;
+
+    bulk_write_exception(bulk_write_exception&&) = default;
+    bulk_write_exception& operator=(bulk_write_exception&&) = default;
+    bulk_write_exception(const bulk_write_exception&) = default;
+    bulk_write_exception& operator=(const bulk_write_exception&) = default;
+
     using operation_exception::operation_exception;
 };
 
@@ -35,3 +47,8 @@ class MONGOCXX_API bulk_write_exception : public operation_exception {
 }  // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::bulk_write_exception.
+///
