@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,18 +17,44 @@
 #include <string>
 #include <system_error>
 
+#include <mongocxx/exception/exception-fwd.hpp>
+
+#include <bsoncxx/config/prelude.hpp>
+
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
+
+BSONCXX_PUSH_WARNINGS();
+BSONCXX_DISABLE_WARNING(MSVC(4251));
+BSONCXX_DISABLE_WARNING(MSVC(4275));
+
 ///
 /// A class to be used as the base class for all mongocxx exceptions.
 ///
-class MONGOCXX_API exception : public std::system_error {
+class exception : public std::system_error {
+   public:
+    ~exception() override;
+
+    exception(exception&&) = default;
+    exception& operator=(exception&&) = default;
+    exception(const exception&) = default;
+    exception& operator=(const exception&) = default;
+
     using system_error::system_error;
 };
 
+BSONCXX_POP_WARNINGS();
+
 }  // namespace v_noabi
 }  // namespace mongocxx
 
+#include <bsoncxx/config/postlude.hpp>
+
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::exception.
+///
