@@ -1,4 +1,4 @@
-// Copyright 2017 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -18,10 +18,14 @@
 #include <memory>
 #include <ostream>
 
+#include <mongocxx/database-fwd.hpp>
+#include <mongocxx/gridfs/bucket-fwd.hpp>
+
 #include <bsoncxx/document/view_or_value.hpp>
 #include <bsoncxx/stdx/optional.hpp>
 #include <bsoncxx/stdx/string_view.hpp>
 #include <bsoncxx/types/bson_value/view.hpp>
+
 #include <mongocxx/cursor.hpp>
 #include <mongocxx/gridfs/downloader.hpp>
 #include <mongocxx/gridfs/uploader.hpp>
@@ -29,14 +33,11 @@
 #include <mongocxx/options/gridfs/bucket.hpp>
 #include <mongocxx/options/gridfs/upload.hpp>
 #include <mongocxx/result/gridfs/upload.hpp>
-#include <mongocxx/stdx.hpp>
 
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
-class database;
-
+namespace v_noabi {
 namespace gridfs {
 
 ///
@@ -49,57 +50,58 @@ namespace gridfs {
 /// in the `<bucketname>.files` collection containing the information about the file. Users should
 /// not modify these collections directly.
 ///
-/// Example of how obtain the default GridFS bucket for a given database:
-/// @code
-///   mongocxx::client mongo_client{mongocxx::uri{}};
-///   auto gridfs_bucket = mongo_client["database"].gridfs_bucket();
-/// @endcode
+/// @par Example
+/// ```cpp
+/// mongocxx::v_noabi::client mongo_client{mongocxx::v_noabi::uri{}};
 ///
-/// See also the method documentation for `mongocxx::database::gridfs_bucket()`.
+/// // Obtain the default GridFS bucket for a given database.
+/// auto gridfs_bucket = mongo_client["database"].gridfs_bucket();
+/// ```
 ///
-/// @see https://www.mongodb.com/display/DOCS/GridFS
+/// See also the method documentation for `mongocxx::v_noabi::database::gridfs_bucket()`.
 ///
-class MONGOCXX_API bucket {
+/// @see
+/// - https://www.mongodb.com/display/DOCS/GridFS
+///
+class bucket {
    public:
     ///
     /// Default constructs a bucket object. The bucket is equivalent to the state of a moved from
     /// bucket. The only valid actions to take with a default constructed bucket are to assign to
     /// it, or destroy it.
     ///
-    bucket() noexcept;
+    MONGOCXX_ABI_EXPORT_CDECL() bucket() noexcept;
 
     ///
     /// Move constructs a bucket.
     ///
-    bucket(bucket&&) noexcept;
+    MONGOCXX_ABI_EXPORT_CDECL() bucket(bucket&&) noexcept;
 
     ///
     /// Move assigns a bucket.
     ///
-    bucket& operator=(bucket&&) noexcept;
+    MONGOCXX_ABI_EXPORT_CDECL(bucket&) operator=(bucket&&) noexcept;
 
     ///
     /// Copy constructs a bucket.
     ///
-    bucket(const bucket&);
+    MONGOCXX_ABI_EXPORT_CDECL() bucket(const bucket&);
 
     ///
     /// Copy assigns a bucket.
     ///
-    bucket& operator=(const bucket&);
+    MONGOCXX_ABI_EXPORT_CDECL(bucket&) operator=(const bucket&);
 
     ///
     /// Destroys a bucket.
     ///
-    ~bucket();
+    MONGOCXX_ABI_EXPORT_CDECL() ~bucket();
 
     ///
     /// Returns true if the bucket is valid, meaning it was not default constructed or moved from.
     ///
-    explicit operator bool() const noexcept;
+    explicit MONGOCXX_ABI_EXPORT_CDECL() operator bool() const noexcept;
 
-    ///
-    /// @{
     ///
     /// Opens a gridfs::uploader to create a new GridFS file. The id of the file will be
     /// automatically generated as an ObjectId.
@@ -118,23 +120,25 @@ class MONGOCXX_API bucket {
     ///   If this GridFS bucket does not already exist in the database, it will be implicitly
     ///   created and initialized with GridFS indexes.
     ///
-    /// @throws mongocxx::logic_error if `options` are invalid.
+    /// @throws mongocxx::v_noabi::logic_error if `options` are invalid.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files collection for this bucket.
     ///
-    /// @throws mongocxx::operation_exception if an error occurs when building GridFS indexes.
+    /// @throws mongocxx::v_noabi::operation_exception if an error occurs when building GridFS
+    /// indexes.
     ///
-    uploader open_upload_stream(stdx::string_view filename,
-                                const options::gridfs::upload& options = {});
+    MONGOCXX_ABI_EXPORT_CDECL(uploader)
+    open_upload_stream(bsoncxx::v_noabi::stdx::string_view filename,
+                       const options::gridfs::upload& options = {});
 
     ///
     /// Opens a gridfs::uploader to create a new GridFS file. The id of the file will be
     /// automatically generated as an ObjectId.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the upload. The client session must
-    ///   remain valid for the lifetime of the uploader.
+    ///   The mongocxx::v_noabi::client_session with which to perform the upload. The client session
+    ///   must remain valid for the lifetime of the uploader.
     ///
     /// @param filename
     ///   The name of the file to be uploaded. A bucket can contain multiple files with the same
@@ -150,22 +154,19 @@ class MONGOCXX_API bucket {
     ///   If this GridFS bucket does not already exist in the database, it will be implicitly
     ///   created and initialized with GridFS indexes.
     ///
-    /// @throws mongocxx::logic_error if `options` are invalid.
+    /// @throws mongocxx::v_noabi::logic_error if `options` are invalid.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files collection for this bucket.
     ///
-    /// @throws mongocxx::operation_exception if an error occurs when building GridFS indexes.
-    ///
-    uploader open_upload_stream(const client_session& session,
-                                stdx::string_view filename,
-                                const options::gridfs::upload& options = {});
-    ///
-    /// @}
+    /// @throws mongocxx::v_noabi::operation_exception if an error occurs when building GridFS
+    /// indexes.
     ///
+    MONGOCXX_ABI_EXPORT_CDECL(uploader)
+    open_upload_stream(const client_session& session,
+                       bsoncxx::v_noabi::stdx::string_view filename,
+                       const options::gridfs::upload& options = {});
 
-    ///
-    /// @{
     ///
     /// Opens a gridfs::uploader to create a new GridFS file.
     ///
@@ -186,23 +187,25 @@ class MONGOCXX_API bucket {
     ///   If this GridFS bucket does not already exist in the database, it will be implicitly
     ///   created and initialized with GridFS indexes.
     ///
-    /// @throws mongocxx::logic_error if `options` are invalid.
+    /// @throws mongocxx::v_noabi::logic_error if `options` are invalid.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files collection for this bucket.
     ///
-    /// @throws mongocxx::operation_exception if an error occurs when building GridFS indexes.
+    /// @throws mongocxx::v_noabi::operation_exception if an error occurs when building GridFS
+    /// indexes.
     ///
-    uploader open_upload_stream_with_id(bsoncxx::types::bson_value::view id,
-                                        stdx::string_view filename,
-                                        const options::gridfs::upload& options = {});
+    MONGOCXX_ABI_EXPORT_CDECL(uploader)
+    open_upload_stream_with_id(bsoncxx::v_noabi::types::bson_value::view id,
+                               bsoncxx::v_noabi::stdx::string_view filename,
+                               const options::gridfs::upload& options = {});
 
     ///
     /// Opens a gridfs::uploader to create a new GridFS file.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the upload. The client session must
-    ///   remain valid for the lifetime of the uploader.
+    ///   The mongocxx::v_noabi::client_session with which to perform the upload. The client session
+    ///   must remain valid for the lifetime of the uploader.
     ///
     /// @param id
     ///   The unique id of the file being uploaded.
@@ -221,23 +224,20 @@ class MONGOCXX_API bucket {
     ///   If this GridFS bucket does not already exist in the database, it will be implicitly
     ///   created and initialized with GridFS indexes.
     ///
-    /// @throws mongocxx::logic_error if `options` are invalid.
+    /// @throws mongocxx::v_noabi::logic_error if `options` are invalid.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files collection for this bucket.
     ///
-    /// @throws mongocxx::operation_exception if an error occurs when building GridFS indexes.
-    ///
-    uploader open_upload_stream_with_id(const client_session& session,
-                                        bsoncxx::types::bson_value::view id,
-                                        stdx::string_view filename,
-                                        const options::gridfs::upload& options = {});
-    ///
-    /// @}
+    /// @throws mongocxx::v_noabi::operation_exception if an error occurs when building GridFS
+    /// indexes.
     ///
+    MONGOCXX_ABI_EXPORT_CDECL(uploader)
+    open_upload_stream_with_id(const client_session& session,
+                               bsoncxx::v_noabi::types::bson_value::view id,
+                               bsoncxx::v_noabi::stdx::string_view filename,
+                               const options::gridfs::upload& options = {});
 
-    ///
-    /// @{
     ///
     /// Creates a new GridFS file by uploading bytes from an input stream. The id of the file will
     /// be automatically generated as an ObjectId.
@@ -260,34 +260,36 @@ class MONGOCXX_API bucket {
     ///   If this GridFS bucket does not already exist in the database, it will be implicitly
     ///   created and initialized with GridFS indexes.
     ///
-    /// @throws mongocxx::logic_error if `options` are invalid.
+    /// @throws mongocxx::v_noabi::logic_error if `options` are invalid.
     ///
-    /// @throws mongocxx::bulk_write_exception
+    /// @throws mongocxx::v_noabi::bulk_write_exception
     ///   if an error occurs when writing chunk data or file metadata to the database.
     ///
     /// @throws std::ios_base::failure
     ///   if reading from `source` fails. Any exception thrown during the execution of
     ///   `source::read()` will be re-thrown.
     ///
-    /// @throws mongocxx::gridfs_exception
+    /// @throws mongocxx::v_noabi::gridfs_exception
     ///   if the uploader requires more than 2^31-1 chunks to store the file at the requested chunk
     ///   size.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files collection for this bucket.
     ///
-    /// @throws mongocxx::operation_exception if an error occurs when building GridFS indexes.
+    /// @throws mongocxx::v_noabi::operation_exception if an error occurs when building GridFS
+    /// indexes.
     ///
-    result::gridfs::upload upload_from_stream(stdx::string_view filename,
-                                              std::istream* source,
-                                              const options::gridfs::upload& options = {});
+    MONGOCXX_ABI_EXPORT_CDECL(result::gridfs::upload)
+    upload_from_stream(bsoncxx::v_noabi::stdx::string_view filename,
+                       std::istream* source,
+                       const options::gridfs::upload& options = {});
 
     ///
     /// Creates a new GridFS file by uploading bytes from an input stream. The id of the file will
     /// be automatically generated as an ObjectId.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the upload.
+    ///   The mongocxx::v_noabi::client_session with which to perform the upload.
     ///
     /// @param filename
     ///   The name of the file to be uploaded. A bucket can contain multiple files with the same
@@ -307,34 +309,31 @@ class MONGOCXX_API bucket {
     ///   If this GridFS bucket does not already exist in the database, it will be implicitly
     ///   created and initialized with GridFS indexes.
     ///
-    /// @throws mongocxx::logic_error if `options` are invalid.
+    /// @throws mongocxx::v_noabi::logic_error if `options` are invalid.
     ///
-    /// @throws mongocxx::bulk_write_exception
+    /// @throws mongocxx::v_noabi::bulk_write_exception
     ///   if an error occurs when writing chunk data or file metadata to the database.
     ///
     /// @throws std::ios_base::failure
     ///   if reading from `source` fails. Any exception thrown during the execution of
     ///   `source::read()` will be re-thrown.
     ///
-    /// @throws mongocxx::gridfs_exception
+    /// @throws mongocxx::v_noabi::gridfs_exception
     ///   if the uploader requires more than 2^31-1 chunks to store the file at the requested chunk
     ///   size.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files collection for this bucket.
     ///
-    /// @throws mongocxx::operation_exception if an error occurs when building GridFS indexes.
-    ///
-    result::gridfs::upload upload_from_stream(const client_session& session,
-                                              stdx::string_view filename,
-                                              std::istream* source,
-                                              const options::gridfs::upload& options = {});
-    ///
-    /// @}
+    /// @throws mongocxx::v_noabi::operation_exception if an error occurs when building GridFS
+    /// indexes.
     ///
+    MONGOCXX_ABI_EXPORT_CDECL(result::gridfs::upload)
+    upload_from_stream(const client_session& session,
+                       bsoncxx::v_noabi::stdx::string_view filename,
+                       std::istream* source,
+                       const options::gridfs::upload& options = {});
 
-    ///
-    /// @{
     ///
     /// Creates a new GridFS file with a user-supplied unique id by uploading bytes from an input
     /// stream.
@@ -357,35 +356,37 @@ class MONGOCXX_API bucket {
     ///   If this GridFS bucket does not already exist in the database, it will be implicitly
     ///   created and initialized with GridFS indexes.
     ///
-    /// @throws mongocxx::logic_error if `options` are invalid.
+    /// @throws mongocxx::v_noabi::logic_error if `options` are invalid.
     ///
-    /// @throws mongocxx::bulk_write_exception
+    /// @throws mongocxx::v_noabi::bulk_write_exception
     ///   if an error occurs when writing chunk data or file metadata to the database.
     ///
     /// @throws std::ios_base::failure
     ///   if reading from `source` fails. Any exception thrown during the execution of
     ///   `source::read()` will be re-thrown.
     ///
-    /// @throws mongocxx::gridfs_exception
+    /// @throws mongocxx::v_noabi::gridfs_exception
     ///   if the uploader requires more than 2^31-1 chunks to store the file at the requested chunk
     ///   size.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files collection for this bucket.
     ///
-    /// @throws mongocxx::operation_exception if an error occurs when building GridFS indexes.
+    /// @throws mongocxx::v_noabi::operation_exception if an error occurs when building GridFS
+    /// indexes.
     ///
-    void upload_from_stream_with_id(bsoncxx::types::bson_value::view id,
-                                    stdx::string_view filename,
-                                    std::istream* source,
-                                    const options::gridfs::upload& options = {});
+    MONGOCXX_ABI_EXPORT_CDECL(void)
+    upload_from_stream_with_id(bsoncxx::v_noabi::types::bson_value::view id,
+                               bsoncxx::v_noabi::stdx::string_view filename,
+                               std::istream* source,
+                               const options::gridfs::upload& options = {});
 
     ///
     /// Creates a new GridFS file with a user-supplied unique id by uploading bytes from an input
     /// stream.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the upload.
+    ///   The mongocxx::v_noabi::client_session with which to perform the upload.
     ///
     /// @param id
     ///   A unique id for the file being uploaded.
@@ -405,35 +406,32 @@ class MONGOCXX_API bucket {
     ///   If this GridFS bucket does not already exist in the database, it will be implicitly
     ///   created and initialized with GridFS indexes.
     ///
-    /// @throws mongocxx::logic_error if `options` are invalid.
+    /// @throws mongocxx::v_noabi::logic_error if `options` are invalid.
     ///
-    /// @throws mongocxx::bulk_write_exception
+    /// @throws mongocxx::v_noabi::bulk_write_exception
     ///   if an error occurs when writing chunk data or file metadata to the database.
     ///
     /// @throws std::ios_base::failure
     ///   if reading from `source` fails. Any exception thrown during the execution of
     ///   `source::read()` will be re-thrown.
     ///
-    /// @throws mongocxx::gridfs_exception
+    /// @throws mongocxx::v_noabi::gridfs_exception
     ///   if the uploader requires more than 2^31-1 chunks to store the file at the requested chunk
     ///   size.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files collection for this bucket.
     ///
-    /// @throws mongocxx::operation_exception if an error occurs when building GridFS indexes.
-    ///
-    void upload_from_stream_with_id(const client_session& session,
-                                    bsoncxx::types::bson_value::view id,
-                                    stdx::string_view filename,
-                                    std::istream* source,
-                                    const options::gridfs::upload& options = {});
-    ///
-    /// @}
+    /// @throws mongocxx::v_noabi::operation_exception if an error occurs when building GridFS
+    /// indexes.
     ///
+    MONGOCXX_ABI_EXPORT_CDECL(void)
+    upload_from_stream_with_id(const client_session& session,
+                               bsoncxx::v_noabi::types::bson_value::view id,
+                               bsoncxx::v_noabi::stdx::string_view filename,
+                               std::istream* source,
+                               const options::gridfs::upload& options = {});
 
-    ///
-    /// @{
     ///
     /// Opens a gridfs::downloader to read a GridFS file.
     ///
@@ -443,20 +441,21 @@ class MONGOCXX_API bucket {
     /// @return
     ///   The gridfs::downloader from which the GridFS file should be read.
     ///
-    /// @throws mongocxx::gridfs_exception
+    /// @throws mongocxx::v_noabi::gridfs_exception
     ///   if the requested file does not exist, or if the requested file has been corrupted.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files collection for this bucket.
     ///
-    downloader open_download_stream(bsoncxx::types::bson_value::view id);
+    MONGOCXX_ABI_EXPORT_CDECL(downloader)
+    open_download_stream(bsoncxx::v_noabi::types::bson_value::view id);
 
     ///
     /// Opens a gridfs::downloader to read a GridFS file.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the download. The client session must
-    ///   remain valid for the lifetime of the downloader.
+    ///   The mongocxx::v_noabi::client_session with which to perform the download. The client
+    ///   session must remain valid for the lifetime of the downloader.
     ///
     /// @param id
     ///   The id of the file to read.
@@ -464,20 +463,16 @@ class MONGOCXX_API bucket {
     /// @return
     ///   The gridfs::downloader from which the GridFS file should be read.
     ///
-    /// @throws mongocxx::gridfs_exception
+    /// @throws mongocxx::v_noabi::gridfs_exception
     ///   if the requested file does not exist, or if the requested file has been corrupted.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files collection for this bucket.
     ///
-    downloader open_download_stream(const client_session& session,
-                                    bsoncxx::types::bson_value::view id);
-    ///
-    /// @}
-    ///
+    MONGOCXX_ABI_EXPORT_CDECL(downloader)
+    open_download_stream(const client_session& session,
+                         bsoncxx::v_noabi::types::bson_value::view id);
 
-    ///
-    /// @{
     ///
     /// Downloads the contents of a stored GridFS file from the bucket and writes it to a stream.
     ///
@@ -487,10 +482,10 @@ class MONGOCXX_API bucket {
     /// @param destination
     ///   The non-null stream to which the GridFS file should be written.
     ///
-    /// @throws mongocxx::gridfs_exception
+    /// @throws mongocxx::v_noabi::gridfs_exception
     ///   if the requested file does not exist, or if the requested file has been corrupted.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files or chunks collections for this bucket.
     ///
     /// @throws std::ios_base::failure
@@ -498,24 +493,26 @@ class MONGOCXX_API bucket {
     ///   `badbit`, any exception thrown during execution of `destination::write()` will be
     ///   re-thrown.
     ///
-    void download_to_stream(bsoncxx::types::bson_value::view id, std::ostream* destination);
+    MONGOCXX_ABI_EXPORT_CDECL(void)
+    download_to_stream(bsoncxx::v_noabi::types::bson_value::view id, std::ostream* destination);
 
     ///
-    /// @copydoc download_to_stream(bsoncxx::types::bson_value::view id, std::ostream* destination)
+    /// @copydoc download_to_stream(bsoncxx::v_noabi::types::bson_value::view id, std::ostream* destination)
     ///
     /// @param start The byte offset to the beginning of content to download.
     /// @param end The byte offset to the end of content to download.
     ///
-    void download_to_stream(bsoncxx::types::bson_value::view id,
-                            std::ostream* destination,
-                            std::size_t start,
-                            std::size_t end);
+    MONGOCXX_ABI_EXPORT_CDECL(void)
+    download_to_stream(bsoncxx::v_noabi::types::bson_value::view id,
+                       std::ostream* destination,
+                       std::size_t start,
+                       std::size_t end);
 
     ///
     /// Downloads the contents of a stored GridFS file from the bucket and writes it to a stream.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the download.
+    ///   The mongocxx::v_noabi::client_session with which to perform the download.
     ///
     /// @param id
     ///   The id of the file to read.
@@ -523,10 +520,10 @@ class MONGOCXX_API bucket {
     /// @param destination
     ///   The non-null stream to which the GridFS file should be written.
     ///
-    /// @throws mongocxx::gridfs_exception
+    /// @throws mongocxx::v_noabi::gridfs_exception
     ///   if the requested file does not exist, or if the requested file has been corrupted.
     ///
-    /// @throws mongocxx::query_exception
+    /// @throws mongocxx::v_noabi::query_exception
     ///   if an error occurs when reading from the files or chunks collections for this bucket.
     ///
     /// @throws std::ios_base::failure
@@ -534,63 +531,54 @@ class MONGOCXX_API bucket {
     ///   `badbit`, any exception thrown during execution of `destination::write()` will be
     ///   re-thrown.
     ///
-    void download_to_stream(const client_session& session,
-                            bsoncxx::types::bson_value::view id,
-                            std::ostream* destination);
+    MONGOCXX_ABI_EXPORT_CDECL(void)
+    download_to_stream(const client_session& session,
+                       bsoncxx::v_noabi::types::bson_value::view id,
+                       std::ostream* destination);
 
-    // clang-format off
     ///
-    /// @copydoc download_to_stream(const client_session& session, bsoncxx::types::bson_value::view id, std::ostream* destination)
+    /// @copydoc download_to_stream(const client_session& session, bsoncxx::v_noabi::types::bson_value::view id, std::ostream* destination)
     ///
     /// @param start The byte offset to the beginning of content to download.
     /// @param end The byte offset to the end of content to download.
     ///
-    // clang-format on
-    void download_to_stream(const client_session& session,
-                            bsoncxx::types::bson_value::view id,
-                            std::ostream* destination,
-                            std::size_t start,
-                            std::size_t end);
-    ///
-    /// @}
-    ///
+    MONGOCXX_ABI_EXPORT_CDECL(void)
+    download_to_stream(const client_session& session,
+                       bsoncxx::v_noabi::types::bson_value::view id,
+                       std::ostream* destination,
+                       std::size_t start,
+                       std::size_t end);
 
-    ///
-    /// @{
     ///
     /// Deletes a GridFS file from the bucket.
     ///
     /// @param id
     ///   The id of the file to be deleted.
     ///
-    /// @throws mongocxx::gridfs_exception if the requested file does not exist.
+    /// @throws mongocxx::v_noabi::gridfs_exception if the requested file does not exist.
     ///
-    /// @throws mongocxx::bulk_write_exception
+    /// @throws mongocxx::v_noabi::bulk_write_exception
     ///   if an error occurs when removing file data or chunk data from the database.
     ///
-    void delete_file(bsoncxx::types::bson_value::view id);
+    MONGOCXX_ABI_EXPORT_CDECL(void) delete_file(bsoncxx::v_noabi::types::bson_value::view id);
 
     ///
     /// Deletes a GridFS file from the bucket.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the delete.
+    ///   The mongocxx::v_noabi::client_session with which to perform the delete.
     ///
     /// @param id
     ///   The id of the file to be deleted.
     ///
-    /// @throws mongocxx::gridfs_exception if the requested file does not exist.
+    /// @throws mongocxx::v_noabi::gridfs_exception if the requested file does not exist.
     ///
-    /// @throws mongocxx::bulk_write_exception
+    /// @throws mongocxx::v_noabi::bulk_write_exception
     ///   if an error occurs when removing file data or chunk data from the database.
     ///
-    void delete_file(const client_session& session, bsoncxx::types::bson_value::view id);
-    ///
-    /// @}
-    ///
+    MONGOCXX_ABI_EXPORT_CDECL(void)
+    delete_file(const client_session& session, bsoncxx::v_noabi::types::bson_value::view id);
 
-    ///
-    /// @{
     ///
     /// Finds the documents in the files collection of the bucket which match the provided filter.
     ///
@@ -601,22 +589,24 @@ class MONGOCXX_API bucket {
     ///   Optional arguments; see options::find.
     ///
     /// @return
-    ///   A mongocxx::cursor with the results. If the query fails, the cursor throws
-    ///   mongocxx::query_exception when the returned cursor is iterated.
+    ///   A mongocxx::v_noabi::cursor with the results. If the query fails, the cursor throws
+    ///   mongocxx::v_noabi::query_exception when the returned cursor is iterated.
     ///
-    /// @throws mongocxx::logic_error if the options are invalid, or if the unsupported option
-    /// modifiers "$query" or "$explain" are used.
+    /// @throws mongocxx::v_noabi::logic_error if the options are invalid, or if the unsupported
+    /// option modifiers "$query" or "$explain" are used.
     ///
-    /// @see mongocxx::collection::find.
+    /// @see
+    /// - @ref mongocxx::v_noabi::collection::find.
     ///
-    cursor find(bsoncxx::document::view_or_value filter, const options::find& options = {});
+    MONGOCXX_ABI_EXPORT_CDECL(cursor)
+    find(bsoncxx::v_noabi::document::view_or_value filter, const options::find& options = {});
 
     ///
     /// Finds the documents in the files collection of the bucket which match the provided filter.
     ///
     /// @param session
-    ///   The mongocxx::client_session with which to perform the query. The client session must
-    ///   remain valid for the lifetime of the cursor.
+    ///   The mongocxx::v_noabi::client_session with which to perform the query. The client session
+    ///   must remain valid for the lifetime of the cursor.
     ///
     /// @param filter
     ///   Document view representing a document that should match the query.
@@ -625,20 +615,19 @@ class MONGOCXX_API bucket {
     ///   Optional arguments; see options::find.
     ///
     /// @return
-    ///   A mongocxx::cursor with the results. If the query fails, the cursor throws
-    ///   mongocxx::query_exception when the returned cursor is iterated.
+    ///   A mongocxx::v_noabi::cursor with the results. If the query fails, the cursor throws
+    ///   mongocxx::v_noabi::query_exception when the returned cursor is iterated.
     ///
-    /// @throws mongocxx::logic_error if the options are invalid, or if the unsupported option
-    /// modifiers "$query" or "$explain" are used.
+    /// @throws mongocxx::v_noabi::logic_error if the options are invalid, or if the unsupported
+    /// option modifiers "$query" or "$explain" are used.
     ///
-    /// @see mongocxx::collection::find.
-    ///
-    cursor find(const client_session& session,
-                bsoncxx::document::view_or_value filter,
-                const options::find& options = {});
-    ///
-    /// @}
+    /// @see
+    /// - @ref mongocxx::v_noabi::collection::find.
     ///
+    MONGOCXX_ABI_EXPORT_CDECL(cursor)
+    find(const client_session& session,
+         bsoncxx::v_noabi::document::view_or_value filter,
+         const options::find& options = {});
 
     ///
     /// Gets the name of the GridFS bucket.
@@ -646,45 +635,44 @@ class MONGOCXX_API bucket {
     /// @return
     ///   The name of the GridFS bucket.
     ///
-    stdx::string_view bucket_name() const;
+    MONGOCXX_ABI_EXPORT_CDECL(bsoncxx::v_noabi::stdx::string_view) bucket_name() const;
 
    private:
-    friend class mongocxx::database;
+    friend ::mongocxx::v_noabi::database;
 
     // Constructs a new GridFS bucket.  Throws if options are invalid.
-    MONGOCXX_PRIVATE bucket(const database& db, const options::gridfs::bucket& options);
+    bucket(const database& db, const options::gridfs::bucket& options);
 
-    MONGOCXX_PRIVATE void create_indexes_if_nonexistent(const client_session* session);
+    void create_indexes_if_nonexistent(const client_session* session);
 
-    MONGOCXX_PRIVATE uploader _open_upload_stream_with_id(const client_session* session,
-                                                          bsoncxx::types::bson_value::view id,
-                                                          stdx::string_view filename,
-                                                          const options::gridfs::upload& options);
+    uploader _open_upload_stream_with_id(const client_session* session,
+                                         bsoncxx::v_noabi::types::bson_value::view id,
+                                         bsoncxx::v_noabi::stdx::string_view filename,
+                                         const options::gridfs::upload& options);
 
-    MONGOCXX_PRIVATE void _upload_from_stream_with_id(const client_session* session,
-                                                      bsoncxx::types::bson_value::view id,
-                                                      stdx::string_view filename,
-                                                      std::istream* source,
-                                                      const options::gridfs::upload& options);
+    void _upload_from_stream_with_id(const client_session* session,
+                                     bsoncxx::v_noabi::types::bson_value::view id,
+                                     bsoncxx::v_noabi::stdx::string_view filename,
+                                     std::istream* source,
+                                     const options::gridfs::upload& options);
 
-    MONGOCXX_PRIVATE downloader _open_download_stream(const client_session* session,
-                                                      bsoncxx::types::bson_value::view id,
-                                                      stdx::optional<std::size_t> start,
-                                                      stdx::optional<std::size_t> end);
+    downloader _open_download_stream(const client_session* session,
+                                     bsoncxx::v_noabi::types::bson_value::view id,
+                                     bsoncxx::v_noabi::stdx::optional<std::size_t> start,
+                                     bsoncxx::v_noabi::stdx::optional<std::size_t> end);
 
-    MONGOCXX_PRIVATE void _download_to_stream(const client_session* session,
-                                              bsoncxx::types::bson_value::view id,
-                                              std::ostream* destination,
-                                              stdx::optional<std::size_t> start,
-                                              stdx::optional<std::size_t> end);
+    void _download_to_stream(const client_session* session,
+                             bsoncxx::v_noabi::types::bson_value::view id,
+                             std::ostream* destination,
+                             bsoncxx::v_noabi::stdx::optional<std::size_t> start,
+                             bsoncxx::v_noabi::stdx::optional<std::size_t> end);
 
-    MONGOCXX_PRIVATE void _delete_file(const client_session* session,
-                                       bsoncxx::types::bson_value::view id);
+    void _delete_file(const client_session* session, bsoncxx::v_noabi::types::bson_value::view id);
 
-    class MONGOCXX_PRIVATE impl;
+    class impl;
 
-    MONGOCXX_PRIVATE impl& _get_impl();
-    MONGOCXX_PRIVATE const impl& _get_impl() const;
+    impl& _get_impl();
+    const impl& _get_impl() const;
 
     std::unique_ptr<impl> _impl;
 };
@@ -694,3 +682,8 @@ class MONGOCXX_API bucket {
 }  // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::gridfs::bucket.
+///
