@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,10 +17,13 @@
 #include <chrono>
 #include <cstdint>
 
+#include <mongocxx/options/find-fwd.hpp>
+
 #include <bsoncxx/document/view_or_value.hpp>
 #include <bsoncxx/stdx/optional.hpp>
 #include <bsoncxx/string/view_or_value.hpp>
 #include <bsoncxx/types/bson_value/view_or_value.hpp>
+
 #include <mongocxx/cursor.hpp>
 #include <mongocxx/hint.hpp>
 #include <mongocxx/read_preference.hpp>
@@ -28,13 +31,13 @@
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace options {
 
 ///
 /// Class representing the optional arguments to a MongoDB query.
 ///
-class MONGOCXX_API find {
+class find {
    public:
     ///
     /// Enables writing to temporary files on the server. When set to true, the server
@@ -51,9 +54,10 @@ class MONGOCXX_API find {
     /// @return
     ///   A reference to this object to facilitate method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& allow_disk_use(bool allow_disk_use);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) allow_disk_use(bool allow_disk_use);
 
     ///
     /// Gets the current setting for allowing disk use on the server.
@@ -62,7 +66,7 @@ class MONGOCXX_API find {
     ///
     /// @return Whether disk use on the server is allowed.
     ///
-    const stdx::optional<bool>& allow_disk_use() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&) allow_disk_use() const;
 
     ///
     /// Sets whether to allow partial results from a mongos if some shards are down (instead of
@@ -75,18 +79,21 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& allow_partial_results(bool allow_partial);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) allow_partial_results(bool allow_partial);
 
     ///
     /// Gets the current setting for allowing partial results from mongos.
     ///
     /// @return Whether partial results from mongos are allowed.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bool>& allow_partial_results() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&)
+    allow_partial_results() const;
 
     ///
     /// Sets the number of documents to return per batch.
@@ -98,18 +105,21 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& batch_size(std::int32_t batch_size);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) batch_size(std::int32_t batch_size);
 
     ///
     /// The current batch size setting.
     ///
     /// @return The current batch size.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<std::int32_t>& batch_size() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<std::int32_t>&)
+    batch_size() const;
 
     ///
     /// Sets the collation for this operation.
@@ -121,9 +131,10 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& collation(bsoncxx::document::view_or_value collation);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) collation(bsoncxx::v_noabi::document::view_or_value collation);
 
     ///
     /// Retrieves the current collation for this operation.
@@ -131,9 +142,12 @@ class MONGOCXX_API find {
     /// @return
     ///   The current collation.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bsoncxx::document::view_or_value>& collation() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&)
+    collation() const;
 
     ///
     /// Attaches a comment to the query. If $comment also exists in the modifiers document then
@@ -148,9 +162,10 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& comment(bsoncxx::string::view_or_value comment);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) comment(bsoncxx::v_noabi::string::view_or_value comment);
 
     ///
     /// Gets the current comment attached to this query.
@@ -159,9 +174,12 @@ class MONGOCXX_API find {
     ///
     /// @return The comment attached to this query.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bsoncxx::string::view_or_value>& comment() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value>&)
+    comment() const;
 
     ///
     /// Indicates the type of cursor to use for this query.
@@ -173,23 +191,27 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& cursor_type(cursor::type cursor_type);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) cursor_type(cursor::type cursor_type);
 
     ///
     /// Gets the current cursor type.
     ///
     /// @return The current cursor type.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<cursor::type>& cursor_type() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<cursor::type>&)
+    cursor_type() const;
 
     ///
     /// Sets the index to use for this operation.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
     /// @note if the server already has a cached shape for this query, it may
     /// ignore a hint.
@@ -201,16 +223,18 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    find& hint(class hint index_hint);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) hint(mongocxx::v_noabi::hint index_hint);
 
     ///
     /// Gets the current hint.
     ///
     /// @return The current hint, if one is set.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<class hint>& hint() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::hint>&)
+    hint() const;
 
     ///
     /// Set the value of the let option.
@@ -222,9 +246,10 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& let(bsoncxx::document::view_or_value let);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) let(bsoncxx::v_noabi::document::view_or_value let);
 
     ///
     /// Gets the current value of the let option.
@@ -232,9 +257,12 @@ class MONGOCXX_API find {
     /// @return
     ///  The current let option.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bsoncxx::document::view_or_value> let() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>)
+    let() const;
 
     ///
     /// Set the value of the comment option.
@@ -248,9 +276,11 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& comment_option(bsoncxx::types::bson_value::view_or_value comment);
+    MONGOCXX_ABI_EXPORT_CDECL(find&)
+    comment_option(bsoncxx::v_noabi::types::bson_value::view_or_value comment);
 
     ///
     /// Gets the current value of the comment option.
@@ -260,9 +290,12 @@ class MONGOCXX_API find {
     /// @return
     ///  The current comment option.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bsoncxx::types::bson_value::view_or_value>& comment_option() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>&)
+    comment_option() const;
 
     ///
     /// Sets maximum number of documents to return.
@@ -273,18 +306,20 @@ class MONGOCXX_API find {
     /// @return
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& limit(std::int64_t limit);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) limit(std::int64_t limit);
 
     ///
     /// Gets the current limit.
     ///
     /// @return The current limit.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<std::int64_t>& limit() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<std::int64_t>&) limit() const;
 
     ///
     /// Gets the current exclusive upper bound for a specific index.
@@ -296,18 +331,22 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& max(bsoncxx::document::view_or_value max);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) max(bsoncxx::v_noabi::document::view_or_value max);
 
     ///
     /// Sets the current exclusive upper bound for a specific index.
     ///
     /// @return The exclusive upper bound for a specific index.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bsoncxx::document::view_or_value>& max() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&)
+    max() const;
 
     ///
     /// The maximum amount of time for the server to wait on new documents to satisfy a tailable
@@ -324,9 +363,10 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& max_await_time(std::chrono::milliseconds max_await_time);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) max_await_time(std::chrono::milliseconds max_await_time);
 
     ///
     /// The maximum amount of time for the server to wait on new documents to satisfy a tailable
@@ -334,9 +374,11 @@ class MONGOCXX_API find {
     ///
     /// @return The current max await time (in milliseconds).
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<std::chrono::milliseconds>& max_await_time() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds>&)
+    max_await_time() const;
 
     ///
     /// Sets the maximum amount of time for this operation to run (server-side) in milliseconds.
@@ -348,18 +390,21 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& max_time(std::chrono::milliseconds max_time);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) max_time(std::chrono::milliseconds max_time);
 
     ///
     /// The current max_time_ms setting.
     ///
     /// @return The current max time (in milliseconds).
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<std::chrono::milliseconds>& max_time() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds>&)
+    max_time() const;
 
     ///
     /// Gets the current inclusive lower bound for a specific index.
@@ -371,18 +416,22 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& min(bsoncxx::document::view_or_value min);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) min(bsoncxx::v_noabi::document::view_or_value min);
 
     ///
     /// Sets the current inclusive lower bound for a specific index.
     ///
     /// @return The inclusive lower bound for a specific index.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bsoncxx::document::view_or_value>& min() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&)
+    min() const;
 
     ///
     /// Sets the cursor flag to prevent cursor from timing out server-side due to a period of
@@ -395,18 +444,21 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& no_cursor_timeout(bool no_cursor_timeout);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) no_cursor_timeout(bool no_cursor_timeout);
 
     ///
     /// Gets the current no_cursor_timeout setting.
     ///
     /// @return The current no_cursor_timeout setting.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bool>& no_cursor_timeout() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&)
+    no_cursor_timeout() const;
 
     ///
     /// Sets a projection which limits the returned fields for all matching documents.
@@ -418,18 +470,23 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& projection(bsoncxx::document::view_or_value projection);
+    MONGOCXX_ABI_EXPORT_CDECL(find&)
+    projection(bsoncxx::v_noabi::document::view_or_value projection);
 
     ///
     /// Gets the current projection set on this query.
     ///
     /// @return The current projection.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bsoncxx::document::view_or_value>& projection() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&)
+    projection() const;
 
     ///
     /// Sets the read_preference for this operation.
@@ -441,9 +498,10 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& read_preference(class read_preference rp);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) read_preference(mongocxx::v_noabi::read_preference rp);
 
     ///
     /// The current read_preference for this operation.
@@ -451,9 +509,12 @@ class MONGOCXX_API find {
     /// @return
     ///   The current read_preference.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<class read_preference>& read_preference() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_preference>&)
+    read_preference() const;
 
     ///
     /// Sets whether to return the index keys associated with the query results, instead of the
@@ -467,9 +528,10 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& return_key(bool return_key);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) return_key(bool return_key);
 
     ///
     /// Gets the current setting for returning the index keys associated with the query results,
@@ -479,9 +541,10 @@ class MONGOCXX_API find {
     ///   Whether index keys associated with the query results are returned, instead of the actual
     ///   query results themselves.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bool>& return_key() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&) return_key() const;
 
     ///
     /// Sets whether to include the record identifier for each document in the query results.
@@ -493,9 +556,10 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& show_record_id(bool show_record_id);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) show_record_id(bool show_record_id);
 
     ///
     /// Gets the current setting for whether the record identifier is returned for each document in
@@ -504,9 +568,10 @@ class MONGOCXX_API find {
     /// @return
     ///   Whether the record identifier is included.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bool>& show_record_id() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&) show_record_id() const;
 
     ///
     /// Sets the number of documents to skip before returning results.
@@ -518,18 +583,20 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& skip(std::int64_t skip);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) skip(std::int64_t skip);
 
     ///
     /// Gets the current number of documents to skip.
     ///
     /// @return The number of documents to skip.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<std::int64_t>& skip() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<std::int64_t>&) skip() const;
 
     ///
     /// The order in which to return matching documents. If $orderby also exists in the modifiers
@@ -542,41 +609,46 @@ class MONGOCXX_API find {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    find& sort(bsoncxx::document::view_or_value ordering);
+    MONGOCXX_ABI_EXPORT_CDECL(find&) sort(bsoncxx::v_noabi::document::view_or_value ordering);
 
     ///
     /// Gets the current sort ordering for this query.
     ///
     /// @return The current sort ordering.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/find/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/find/
     ///
-    const stdx::optional<bsoncxx::document::view_or_value>& sort() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&)
+    sort() const;
 
    private:
-    stdx::optional<bool> _allow_disk_use;
-    stdx::optional<bool> _allow_partial_results;
-    stdx::optional<std::int32_t> _batch_size;
-    stdx::optional<bsoncxx::document::view_or_value> _collation;
-    stdx::optional<bsoncxx::string::view_or_value> _comment;
-    stdx::optional<cursor::type> _cursor_type;
-    stdx::optional<class hint> _hint;
-    stdx::optional<bsoncxx::document::view_or_value> _let;
-    stdx::optional<bsoncxx::types::bson_value::view_or_value> _comment_option;
-    stdx::optional<std::int64_t> _limit;
-    stdx::optional<bsoncxx::document::view_or_value> _max;
-    stdx::optional<std::chrono::milliseconds> _max_await_time;
-    stdx::optional<std::chrono::milliseconds> _max_time;
-    stdx::optional<bsoncxx::document::view_or_value> _min;
-    stdx::optional<bool> _no_cursor_timeout;
-    stdx::optional<bsoncxx::document::view_or_value> _projection;
-    stdx::optional<class read_preference> _read_preference;
-    stdx::optional<bool> _return_key;
-    stdx::optional<bool> _show_record_id;
-    stdx::optional<std::int64_t> _skip;
-    stdx::optional<bsoncxx::document::view_or_value> _ordering;
+    bsoncxx::v_noabi::stdx::optional<bool> _allow_disk_use;
+    bsoncxx::v_noabi::stdx::optional<bool> _allow_partial_results;
+    bsoncxx::v_noabi::stdx::optional<std::int32_t> _batch_size;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> _collation;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> _comment;
+    bsoncxx::v_noabi::stdx::optional<cursor::type> _cursor_type;
+    bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::hint> _hint;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> _let;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>
+        _comment_option;
+    bsoncxx::v_noabi::stdx::optional<std::int64_t> _limit;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> _max;
+    bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds> _max_await_time;
+    bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds> _max_time;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> _min;
+    bsoncxx::v_noabi::stdx::optional<bool> _no_cursor_timeout;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> _projection;
+    bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_preference> _read_preference;
+    bsoncxx::v_noabi::stdx::optional<bool> _return_key;
+    bsoncxx::v_noabi::stdx::optional<bool> _show_record_id;
+    bsoncxx::v_noabi::stdx::optional<std::int64_t> _skip;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> _ordering;
 };
 
 }  // namespace options
@@ -584,3 +656,8 @@ class MONGOCXX_API find {
 }  // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::options::find.
+///
