@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -22,9 +22,9 @@
 #include <bsoncxx/document/view_or_value.hpp>
 #include <bsoncxx/stdx/optional.hpp>
 #include <bsoncxx/types/bson_value/view_or_value.hpp>
+
 #include <mongocxx/hint.hpp>
 #include <mongocxx/options/find_one_common_options.hpp>
-#include <mongocxx/stdx.hpp>
 #include <mongocxx/write_concern.hpp>
 
 #include <mongocxx/config/prelude.hpp>
@@ -47,9 +47,11 @@ class find_one_and_replace {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    find_one_and_replace& collation(bsoncxx::v_noabi::document::view_or_value collation);
+    MONGOCXX_ABI_EXPORT_CDECL(find_one_and_replace&)
+    collation(bsoncxx::v_noabi::document::view_or_value collation);
 
     ///
     /// Retrieves the current collation for this operation.
@@ -57,9 +59,12 @@ class find_one_and_replace {
     /// @return
     ///   The current collation.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& collation() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&)
+    collation() const;
 
     ///
     /// Whether or not to bypass document validation for this operation.
@@ -75,18 +80,22 @@ class find_one_and_replace {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    find_one_and_replace& bypass_document_validation(bool bypass_document_validation);
+    MONGOCXX_ABI_EXPORT_CDECL(find_one_and_replace&)
+    bypass_document_validation(bool bypass_document_validation);
 
     ///
     /// The current setting for bypassing document validation.
     ///
     /// @return the current bypass document validation setting.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    const stdx::optional<bool>& bypass_document_validation() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&)
+    bypass_document_validation() const;
 
     ///
     /// Sets the index to use for this operation.
@@ -101,14 +110,15 @@ class find_one_and_replace {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    find_one_and_replace& hint(mongocxx::v_noabi::hint index_hint);
+    MONGOCXX_ABI_EXPORT_CDECL(find_one_and_replace&) hint(mongocxx::v_noabi::hint index_hint);
 
     ///
     /// Gets the current hint.
     ///
     /// @return The current hint, if one is set.
     ///
-    const stdx::optional<mongocxx::v_noabi::hint>& hint() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::hint>&)
+    hint() const;
 
     ///
     /// Set the value of the let option.
@@ -120,7 +130,8 @@ class find_one_and_replace {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    find_one_and_replace& let(bsoncxx::v_noabi::document::view_or_value let);
+    MONGOCXX_ABI_EXPORT_CDECL(find_one_and_replace&)
+    let(bsoncxx::v_noabi::document::view_or_value let);
 
     ///
     /// Gets the current value of the let option.
@@ -128,7 +139,9 @@ class find_one_and_replace {
     /// @return
     ///  The current let option.
     ///
-    const stdx::optional<bsoncxx::v_noabi::document::view_or_value> let() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>)
+    let() const;
 
     ///
     /// Set the value of the comment option.
@@ -140,7 +153,8 @@ class find_one_and_replace {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    find_one_and_replace& comment(bsoncxx::v_noabi::types::bson_value::view_or_value comment);
+    MONGOCXX_ABI_EXPORT_CDECL(find_one_and_replace&)
+    comment(bsoncxx::v_noabi::types::bson_value::view_or_value comment);
 
     ///
     /// Gets the current value of the comment option.
@@ -148,7 +162,9 @@ class find_one_and_replace {
     /// @return
     ///  The current comment option.
     ///
-    const stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value> comment() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>)
+    comment() const;
 
     ///
     /// Sets the maximum amount of time for this operation to run (server-side) in milliseconds.
@@ -160,18 +176,21 @@ class find_one_and_replace {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    find_one_and_replace& max_time(std::chrono::milliseconds max_time);
+    MONGOCXX_ABI_EXPORT_CDECL(find_one_and_replace&) max_time(std::chrono::milliseconds max_time);
 
     ///
     /// The current max_time setting.
     ///
     /// @return the current max allowed running time (in milliseconds).
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    const stdx::optional<std::chrono::milliseconds>& max_time() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds>&)
+    max_time() const;
 
     ///
     /// Sets a projection, which limits the fields to return.
@@ -183,18 +202,23 @@ class find_one_and_replace {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    find_one_and_replace& projection(bsoncxx::v_noabi::document::view_or_value projection);
+    MONGOCXX_ABI_EXPORT_CDECL(find_one_and_replace&)
+    projection(bsoncxx::v_noabi::document::view_or_value projection);
 
     ///
     /// Gets the current projection for this operation.
     ///
     /// @return The current projection.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& projection() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&)
+    projection() const;
 
     ///
     /// Set the desired version of the replaced document to return, either the original
@@ -207,20 +231,25 @@ class find_one_and_replace {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
-    /// @see mongocxx::v_noabi::options::return_document
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// - @ref mongocxx::v_noabi::options::return_document
     ///
-    find_one_and_replace& return_document(return_document return_document);
+    MONGOCXX_ABI_EXPORT_CDECL(find_one_and_replace&)
+    return_document(return_document return_document);
 
     ///
     /// Which version of the replaced document to return.
     ///
     /// @return Version of document to return, either original or replacement.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
-    /// @see mongocxx::v_noabi::options::return_document
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// - @ref mongocxx::v_noabi::options::return_document
     ///
-    const stdx::optional<mongocxx::v_noabi::options::return_document>& return_document() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::options::return_document>&)
+    return_document() const;
 
     ///
     /// Sets the order by which to search the collection for a matching document.
@@ -235,18 +264,23 @@ class find_one_and_replace {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    find_one_and_replace& sort(bsoncxx::v_noabi::document::view_or_value ordering);
+    MONGOCXX_ABI_EXPORT_CDECL(find_one_and_replace&)
+    sort(bsoncxx::v_noabi::document::view_or_value ordering);
 
     ///
     /// Gets the current sort ordering.
     ///
     /// @return The current sort ordering.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& sort() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&)
+    sort() const;
 
     ///
     /// Sets the upsert flag on the operation. When @c true, the operation creates a new document if
@@ -260,18 +294,20 @@ class find_one_and_replace {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    find_one_and_replace& upsert(bool upsert);
+    MONGOCXX_ABI_EXPORT_CDECL(find_one_and_replace&) upsert(bool upsert);
 
     ///
     /// Gets the current upsert setting.
     ///
     /// @return The current upsert setting.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    const stdx::optional<bool>& upsert() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&) upsert() const;
 
     ///
     /// Sets the write concern for this operation.
@@ -284,9 +320,10 @@ class find_one_and_replace {
     ///   method chaining.
     ///
     /// @see
-    ///   https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    find_one_and_replace& write_concern(mongocxx::v_noabi::write_concern write_concern);
+    MONGOCXX_ABI_EXPORT_CDECL(find_one_and_replace&)
+    write_concern(mongocxx::v_noabi::write_concern write_concern);
 
     ///
     /// Gets the current write concern.
@@ -295,22 +332,24 @@ class find_one_and_replace {
     ///   The current write concern.
     ///
     /// @see
-    ///   https://www.mongodb.com/docs/manual/reference/command/findAndModify/
+    /// - https://www.mongodb.com/docs/manual/reference/command/findAndModify/
     ///
-    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>&)
+    write_concern() const;
 
    private:
-    stdx::optional<bool> _bypass_document_validation;
-    stdx::optional<bsoncxx::v_noabi::document::view_or_value> _collation;
-    stdx::optional<mongocxx::v_noabi::hint> _hint;
-    stdx::optional<bsoncxx::v_noabi::document::view_or_value> _let;
-    stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value> _comment;
-    stdx::optional<std::chrono::milliseconds> _max_time;
-    stdx::optional<bsoncxx::v_noabi::document::view_or_value> _projection;
-    stdx::optional<mongocxx::v_noabi::options::return_document> _return_document;
-    stdx::optional<bsoncxx::v_noabi::document::view_or_value> _ordering;
-    stdx::optional<bool> _upsert;
-    stdx::optional<mongocxx::v_noabi::write_concern> _write_concern;
+    bsoncxx::v_noabi::stdx::optional<bool> _bypass_document_validation;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> _collation;
+    bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::hint> _hint;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> _let;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value> _comment;
+    bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds> _max_time;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> _projection;
+    bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::options::return_document> _return_document;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> _ordering;
+    bsoncxx::v_noabi::stdx::optional<bool> _upsert;
+    bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern> _write_concern;
 };
 
 }  // namespace options
@@ -318,3 +357,8 @@ class find_one_and_replace {
 }  // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::options::find_one_and_replace.
+///
