@@ -1,4 +1,4 @@
-// Copyright 2023 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@ namespace v_noabi {
 namespace options {
 namespace gridfs {
 
-class MONGOCXX_API upload;
+class upload;
 
 }  // namespace gridfs
 }  // namespace options
@@ -39,3 +39,23 @@ using ::mongocxx::v_noabi::options::gridfs::upload;
 }  // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Declares @ref mongocxx::v_noabi::options::gridfs::upload.
+///
+
+#if defined(MONGOCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
+
+namespace mongocxx {
+namespace options {
+namespace gridfs {
+
+/// @ref mongocxx::v_noabi::options::gridfs::upload
+class upload {};
+
+}  // namespace gridfs
+}  // namespace options
+}  // namespace mongocxx
+
+#endif  // defined(MONGOCXX_PRIVATE_DOXYGEN_PREPROCESSOR)
