@@ -1,4 +1,4 @@
-// Copyright 2015 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,69 +17,96 @@
 #include <chrono>
 #include <memory>
 
+#include <mongocxx/collection-fwd.hpp>
+#include <mongocxx/options/index-fwd.hpp>
+
 #include <bsoncxx/document/value.hpp>
 #include <bsoncxx/document/view.hpp>
 #include <bsoncxx/document/view_or_value.hpp>
 #include <bsoncxx/stdx/optional.hpp>
 #include <bsoncxx/string/view_or_value.hpp>
-#include <mongocxx/stdx.hpp>
+
+#include <bsoncxx/config/prelude.hpp>
 
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
-class collection;
-
+namespace v_noabi {
 namespace options {
 
 ///
 /// Class representing the optional arguments to a MongoDB create index operation.
 ///
-/// @see https://www.mongodb.com/docs/manual/reference/command/createIndexes
+/// @see
+/// - https://www.mongodb.com/docs/manual/reference/command/createIndexes
 ///
-class MONGOCXX_API index {
+class index {
    public:
+    BSONCXX_PUSH_WARNINGS();
+    BSONCXX_DISABLE_WARNING(MSVC(4251));
+    BSONCXX_DISABLE_WARNING(MSVC(4275));
+
     ///
     /// Base class representing the optional storage engine options for indexes.
     ///
-    class MONGOCXX_API base_storage_options {
+    class MONGOCXX_ABI_EXPORT base_storage_options {
        public:
         virtual ~base_storage_options();
 
+        base_storage_options(base_storage_options&&) = default;
+        base_storage_options& operator=(base_storage_options&&) = default;
+        base_storage_options(const base_storage_options&) = default;
+        base_storage_options& operator=(const base_storage_options&) = default;
+
+        base_storage_options() = default;
+
        private:
-        friend class options::index;
-        MONGOCXX_PRIVATE virtual int type() const = 0;
+        friend ::mongocxx::v_noabi::options::index;
+
+        virtual int type() const = 0;
     };
 
     ///
     /// Class representing the optional WiredTiger storage engine options for indexes.
     ///
-    class MONGOCXX_API wiredtiger_storage_options final : public base_storage_options {
+    class MONGOCXX_ABI_EXPORT wiredtiger_storage_options final : public base_storage_options {
        public:
         ~wiredtiger_storage_options() override;
 
+        wiredtiger_storage_options(wiredtiger_storage_options&&) = default;
+        wiredtiger_storage_options& operator=(wiredtiger_storage_options&&) = default;
+        wiredtiger_storage_options(const wiredtiger_storage_options&) = default;
+        wiredtiger_storage_options& operator=(const wiredtiger_storage_options&) = default;
+
+        wiredtiger_storage_options() = default;
+
         ///
         /// Set the WiredTiger configuration string.
         ///
         /// @param config_string
         ///   The WiredTiger configuration string.
         ///
-        void config_string(bsoncxx::string::view_or_value config_string);
+        void config_string(bsoncxx::v_noabi::string::view_or_value config_string);
 
         ///
         /// The current config_string setting.
         ///
         /// @return The current config_string.
         ///
-        const stdx::optional<bsoncxx::string::view_or_value>& config_string() const;
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value>&
+        config_string() const;
 
        private:
-        friend collection;
-        MONGOCXX_PRIVATE int type() const override;
-        stdx::optional<bsoncxx::string::view_or_value> _config_string;
+        friend ::mongocxx::v_noabi::collection;
+
+        MONGOCXX_ABI_NO_EXPORT int type() const override;
+
+        bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> _config_string;
     };
 
-    index();
+    BSONCXX_POP_WARNINGS();
+
+    MONGOCXX_ABI_EXPORT_CDECL() index();
 
     ///
     /// Whether or not to build the index in the background so that building the index does not
@@ -92,16 +119,17 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/tutorial/build-indexes-in-the-background/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/tutorial/build-indexes-in-the-background/
     ///
-    index& background(bool background);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) background(bool background);
 
     ///
     /// The current background setting.
     ///
     /// @return The current background.
     ///
-    const stdx::optional<bool>& background() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&) background() const;
 
     ///
     /// Whether or not to create a unique index so that the collection will not accept insertion of
@@ -114,16 +142,17 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/core/index-unique/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/core/index-unique/
     ///
-    index& unique(bool unique);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) unique(bool unique);
 
     ///
     /// The current unique setting.
     ///
     /// @return The current unique.
     ///
-    const stdx::optional<bool>& unique() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&) unique() const;
 
     ///
     /// Whether or not the index is hidden from the query planner. A hidden index is not evaluated
@@ -136,16 +165,17 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/core/index-hidden/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/core/index-hidden/
     ///
-    index& hidden(bool hidden);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) hidden(bool hidden);
 
     ///
     /// The current hidden setting.
     ///
     /// @return The current hidden.
     ///
-    const stdx::optional<bool>& hidden() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&) hidden() const;
 
     ///
     /// The name of the index.
@@ -157,14 +187,16 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    index& name(bsoncxx::string::view_or_value name);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) name(bsoncxx::v_noabi::string::view_or_value name);
 
     ///
     /// The current name setting.
     ///
     /// @return The current name.
     ///
-    const stdx::optional<bsoncxx::string::view_or_value>& name() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value>&)
+    name() const;
 
     ///
     /// Sets the collation for this index.
@@ -177,9 +209,9 @@ class MONGOCXX_API index {
     ///   method chaining.
     ///
     /// @see
-    ///   https://www.mongodb.com/docs/manual/reference/collation/
+    /// - https://www.mongodb.com/docs/manual/reference/collation/
     ///
-    index& collation(bsoncxx::document::view collation);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) collation(bsoncxx::v_noabi::document::view collation);
 
     ///
     /// Retrieves the current collation for this index.
@@ -188,9 +220,11 @@ class MONGOCXX_API index {
     ///   The current collation.
     ///
     /// @see
-    ///   https://www.mongodb.com/docs/manual/reference/collation/
+    /// - https://www.mongodb.com/docs/manual/reference/collation/
     ///
-    const stdx::optional<bsoncxx::document::view>& collation() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view>&)
+    collation() const;
 
     ///
     /// Whether or not to create a sparse index. Sparse indexes only reference documents with the
@@ -203,16 +237,17 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/core/index-sparse/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/core/index-sparse/
     ///
-    index& sparse(bool sparse);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) sparse(bool sparse);
 
     ///
     /// The current sparse setting.
     ///
     /// @return The current sparse setting.
     ///
-    const stdx::optional<bool>& sparse() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&) sparse() const;
 
     ///
     /// Optionally used only in MongoDB 3.0.0 and higher. Specifies the storage engine options for
@@ -225,7 +260,8 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    index& storage_options(std::unique_ptr<base_storage_options> storage_options);
+    MONGOCXX_ABI_EXPORT_CDECL(index&)
+    storage_options(std::unique_ptr<base_storage_options> storage_options);
 
     ///
     /// Optionally used only in MongoDB 3.0.0 and higher. Specifies the WiredTiger-specific storage
@@ -234,7 +270,8 @@ class MONGOCXX_API index {
     /// @param storage_options
     ///   The storage engine options for the index.
     ///
-    index& storage_options(std::unique_ptr<wiredtiger_storage_options> storage_options);
+    MONGOCXX_ABI_EXPORT_CDECL(index&)
+    storage_options(std::unique_ptr<wiredtiger_storage_options> storage_options);
 
     ///
     /// Set a value, in seconds, as a TTL to control how long MongoDB retains documents in this
@@ -247,16 +284,18 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/core/index-ttl/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/core/index-ttl/
     ///
-    index& expire_after(std::chrono::seconds seconds);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) expire_after(std::chrono::seconds seconds);
 
     ///
     /// The current expire_after setting.
     ///
     /// @return The current expire_after value.
     ///
-    const stdx::optional<std::chrono::seconds>& expire_after() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<std::chrono::seconds>&)
+    expire_after() const;
 
     ///
     /// Sets the index version.
@@ -268,14 +307,15 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    index& version(std::int32_t v);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) version(std::int32_t v);
 
     ///
     /// The current index version.
     ///
     /// @return The current index version.
     ///
-    const stdx::optional<std::int32_t>& version() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<std::int32_t>&)
+    version() const;
 
     ///
     /// For text indexes, sets the weight document. The weight document contains field and weight
@@ -288,14 +328,16 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    index& weights(bsoncxx::document::view weights);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) weights(bsoncxx::v_noabi::document::view weights);
 
     ///
     /// The current weights setting.
     ///
     /// @return The current weights.
     ///
-    const stdx::optional<bsoncxx::document::view>& weights() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view>&)
+    weights() const;
 
     ///
     /// For text indexes, the language that determines the list of stop words and the rules for the
@@ -308,14 +350,17 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    index& default_language(bsoncxx::string::view_or_value default_language);
+    MONGOCXX_ABI_EXPORT_CDECL(index&)
+    default_language(bsoncxx::v_noabi::string::view_or_value default_language);
 
     ///
     /// The current default_language setting.
     ///
     /// @return The current default_language.
     ///
-    const stdx::optional<bsoncxx::string::view_or_value>& default_language() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value>&)
+    default_language() const;
 
     ///
     /// For text indexes, the name of the field, in the collection’s documents, that contains the
@@ -328,14 +373,17 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    index& language_override(bsoncxx::string::view_or_value language_override);
+    MONGOCXX_ABI_EXPORT_CDECL(index&)
+    language_override(bsoncxx::v_noabi::string::view_or_value language_override);
 
     ///
     /// The current name of the field that contains the override language for text indexes.
     ///
     /// @return The name of the field that contains the override language for text indexes.
     ///
-    const stdx::optional<bsoncxx::string::view_or_value>& language_override() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value>&)
+    language_override() const;
 
     ///
     /// Sets the document for the partial filter expression for partial indexes.
@@ -347,14 +395,17 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    index& partial_filter_expression(bsoncxx::document::view partial_filter_expression);
+    MONGOCXX_ABI_EXPORT_CDECL(index&)
+    partial_filter_expression(bsoncxx::v_noabi::document::view partial_filter_expression);
 
     ///
     /// The current partial_filter_expression setting.
     ///
     /// @return The current partial_filter_expression.
     ///
-    const stdx::optional<bsoncxx::document::view>& partial_filter_expression() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view>&)
+    partial_filter_expression() const;
 
     ///
     /// For 2dsphere indexes, the 2dsphere index version number. Version can be either 1 or 2.
@@ -366,14 +417,15 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    index& twod_sphere_version(std::uint8_t twod_sphere_version);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) twod_sphere_version(std::uint8_t twod_sphere_version);
 
     ///
     /// The current twod_sphere_version setting.
     ///
     /// @return The current twod_sphere_version.
     ///
-    const stdx::optional<std::uint8_t>& twod_sphere_version() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<std::uint8_t>&)
+    twod_sphere_version() const;
 
     ///
     /// For 2d indexes, the precision of the stored geohash value of the location data.
@@ -385,14 +437,15 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    index& twod_bits_precision(std::uint8_t twod_bits_precision);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) twod_bits_precision(std::uint8_t twod_bits_precision);
 
     ///
     /// The current precision of the stored geohash value of the location data.
     ///
     /// @return The precision of the stored geohash value of the location data.
     ///
-    const stdx::optional<std::uint8_t>& twod_bits_precision() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<std::uint8_t>&)
+    twod_bits_precision() const;
 
     ///
     /// For 2d indexes, the lower inclusive boundary for the longitude and latitude values.
@@ -404,14 +457,15 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    index& twod_location_min(double twod_location_min);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) twod_location_min(double twod_location_min);
 
     ///
     /// The current lower inclusive boundary for the longitude and latitude values.
     ///
     /// @return The lower inclusive boundary for the longitude and latitude values.
     ///
-    const stdx::optional<double>& twod_location_min() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<double>&)
+    twod_location_min() const;
 
     ///
     /// For 2d indexes, the upper inclusive boundary for the longitude and latitude values.
@@ -423,21 +477,23 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    index& twod_location_max(double twod_location_max);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) twod_location_max(double twod_location_max);
 
     ///
     /// The current upper inclusive boundary for the longitude and latitude values.
     ///
     /// @return The upper inclusive boundary for the longitude and latitude values.
     ///
-    const stdx::optional<double>& twod_location_max() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<double>&)
+    twod_location_max() const;
 
     ///
     /// For geoHaystack indexes, specify the number of units within which to group the location
     /// values; i.e. group in the same bucket those location values that are within the specified
     /// number of units to each other.
     ///
-    /// @see https://www.mongodb.com/docs/manual/core/geohaystack/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/core/geohaystack/
     ///
     /// @param haystack_bucket_size
     ///   The geoHaystack bucket size.
@@ -449,8 +505,9 @@ class MONGOCXX_API index {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    MONGOCXX_DEPRECATED index& haystack_bucket_size(double haystack_bucket_size);
-    index& haystack_bucket_size_deprecated(double haystack_bucket_size);
+    MONGOCXX_DEPRECATED MONGOCXX_ABI_EXPORT_CDECL(index&)
+        haystack_bucket_size(double haystack_bucket_size);
+    MONGOCXX_ABI_EXPORT_CDECL(index&) haystack_bucket_size_deprecated(double haystack_bucket_size);
 
     ///
     /// The current haystack_bucket_size setting.
@@ -460,39 +517,42 @@ class MONGOCXX_API index {
     /// @deprecated
     ///   This method is deprecated.
     ///
-    MONGOCXX_DEPRECATED const stdx::optional<double>& haystack_bucket_size() const;
-    const stdx::optional<double>& haystack_bucket_size_deprecated() const;
+    MONGOCXX_DEPRECATED MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<double>&)
+        haystack_bucket_size() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<double>&)
+    haystack_bucket_size_deprecated() const;
 
     ///
     /// Conversion operator that provides a view of the options in document form.
     ///
-    /// @exception mongocxx::logic_error if an invalid expireAfterSeconds field is provided.
+    /// @exception mongocxx::v_noabi::logic_error if an invalid expireAfterSeconds field is
+    /// provided.
     ///
     /// @return A view of the current builder contents.
     ///
-    operator bsoncxx::document::view_or_value();
+    MONGOCXX_ABI_EXPORT_CDECL() operator bsoncxx::v_noabi::document::view_or_value();
 
    private:
-    friend collection;
+    friend ::mongocxx::v_noabi::collection;
 
-    stdx::optional<bool> _background;
-    stdx::optional<bool> _unique;
-    stdx::optional<bool> _hidden;
-    stdx::optional<bsoncxx::string::view_or_value> _name;
-    stdx::optional<bsoncxx::document::view> _collation;
-    stdx::optional<bool> _sparse;
+    bsoncxx::v_noabi::stdx::optional<bool> _background;
+    bsoncxx::v_noabi::stdx::optional<bool> _unique;
+    bsoncxx::v_noabi::stdx::optional<bool> _hidden;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> _name;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view> _collation;
+    bsoncxx::v_noabi::stdx::optional<bool> _sparse;
     std::unique_ptr<base_storage_options> _storage_options;
-    stdx::optional<std::chrono::seconds> _expire_after;
-    stdx::optional<std::int32_t> _version;
-    stdx::optional<bsoncxx::document::view> _weights;
-    stdx::optional<bsoncxx::string::view_or_value> _default_language;
-    stdx::optional<bsoncxx::string::view_or_value> _language_override;
-    stdx::optional<bsoncxx::document::view> _partial_filter_expression;
-    stdx::optional<std::uint8_t> _twod_sphere_version;
-    stdx::optional<std::uint8_t> _twod_bits_precision;
-    stdx::optional<double> _twod_location_min;
-    stdx::optional<double> _twod_location_max;
-    stdx::optional<double> _haystack_bucket_size;
+    bsoncxx::v_noabi::stdx::optional<std::chrono::seconds> _expire_after;
+    bsoncxx::v_noabi::stdx::optional<std::int32_t> _version;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view> _weights;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> _default_language;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> _language_override;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view> _partial_filter_expression;
+    bsoncxx::v_noabi::stdx::optional<std::uint8_t> _twod_sphere_version;
+    bsoncxx::v_noabi::stdx::optional<std::uint8_t> _twod_bits_precision;
+    bsoncxx::v_noabi::stdx::optional<double> _twod_location_min;
+    bsoncxx::v_noabi::stdx::optional<double> _twod_location_max;
+    bsoncxx::v_noabi::stdx::optional<double> _haystack_bucket_size;
 
     //
     // Return the current storage_options setting.
@@ -504,4 +564,11 @@ class MONGOCXX_API index {
 }  // namespace v_noabi
 }  // namespace mongocxx
 
+#include <bsoncxx/config/postlude.hpp>
+
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::options::index.
+///
