@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@
 #include <bsoncxx/document/view.hpp>
 #include <bsoncxx/stdx/optional.hpp>
 #include <bsoncxx/types/bson_value/view_or_value.hpp>
-#include <mongocxx/stdx.hpp>
+
 #include <mongocxx/write_concern.hpp>
 
 #include <mongocxx/config/prelude.hpp>
@@ -48,14 +48,15 @@ class insert {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    insert& bypass_document_validation(bool bypass_document_validation);
+    MONGOCXX_ABI_EXPORT_CDECL(insert&) bypass_document_validation(bool bypass_document_validation);
 
     ///
     /// Gets the current value of the bypass_document_validation option.
     ///
     /// @return The optional value of the bypass_document_validation option.
     ///
-    const stdx::optional<bool>& bypass_document_validation() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&)
+    bypass_document_validation() const;
 
     ///
     /// Sets the write_concern for this operation.
@@ -63,22 +64,26 @@ class insert {
     /// @param wc
     ///   The new write_concern.
     ///
-    /// @see https://www.mongodb.com/docs/manual/core/write-concern/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/core/write-concern/
     ///
     /// @return
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    insert& write_concern(mongocxx::v_noabi::write_concern wc);
+    MONGOCXX_ABI_EXPORT_CDECL(insert&) write_concern(mongocxx::v_noabi::write_concern wc);
 
     ///
     /// The current write_concern for this operation.
     ///
     /// @return The current write_concern.
     ///
-    /// @see https://www.mongodb.com/docs/manual/core/write-concern/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/core/write-concern/
     ///
-    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>&)
+    write_concern() const;
 
     ///
     /// @note: This applies only to insert_many and is ignored for insert_one.
@@ -95,18 +100,20 @@ class insert {
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/insert/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/insert/
     ///
-    insert& ordered(bool ordered);
+    MONGOCXX_ABI_EXPORT_CDECL(insert&) ordered(bool ordered);
 
     ///
     /// The current ordered value for this operation.
     ///
     /// @return The current ordered value.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/insert/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/insert/
     ///
-    const stdx::optional<bool>& ordered() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const bsoncxx::v_noabi::stdx::optional<bool>&) ordered() const;
 
     ///
     /// Sets the comment for this operation.
@@ -114,28 +121,33 @@ class insert {
     /// @param comment
     ///   The new comment.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/insert/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/insert/
     ///
     /// @return
     ///   A reference to the object on which this member function is being called.  This facilitates
     ///   method chaining.
     ///
-    insert& comment(bsoncxx::v_noabi::types::bson_value::view_or_value comment);
+    MONGOCXX_ABI_EXPORT_CDECL(insert&)
+    comment(bsoncxx::v_noabi::types::bson_value::view_or_value comment);
 
     ///
     /// The current comment for this operation.
     ///
     /// @return The current comment.
     ///
-    /// @see https://www.mongodb.com/docs/manual/reference/command/insert/
+    /// @see
+    /// - https://www.mongodb.com/docs/manual/reference/command/insert/
     ///
-    const stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>& comment() const;
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>&)
+    comment() const;
 
    private:
-    stdx::optional<mongocxx::v_noabi::write_concern> _write_concern;
-    stdx::optional<bool> _ordered;
-    stdx::optional<bool> _bypass_document_validation;
-    stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value> _comment;
+    bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern> _write_concern;
+    bsoncxx::v_noabi::stdx::optional<bool> _ordered;
+    bsoncxx::v_noabi::stdx::optional<bool> _bypass_document_validation;
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value> _comment;
 };
 
 }  // namespace options
@@ -143,3 +155,8 @@ class insert {
 }  // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::options::insert.
+///
