@@ -1,4 +1,4 @@
-// Copyright 2016 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,19 +14,21 @@
 
 #pragma once
 
+#include <mongocxx/options/pool-fwd.hpp>
+
 #include <mongocxx/options/client.hpp>
 
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace options {
 
 ///
 /// Class representing the optional arguments to a MongoDB driver pool object. Pool options
 /// logically extend client options.
 ///
-class MONGOCXX_API pool {
+class pool {
    public:
     ///
     /// Constructs a new pool options object. Note that options::pool is implictly convertible from
@@ -35,14 +37,14 @@ class MONGOCXX_API pool {
     /// @param client_opts
     ///   The client options.
     ///
-    pool(client client_opts = client());
+    MONGOCXX_ABI_EXPORT_CDECL() pool(client client_opts = client());
 
     ///
     /// The current client options.
     ///
     /// @return The client options.
     ///
-    const client& client_opts() const;
+    MONGOCXX_ABI_EXPORT_CDECL(const client&) client_opts() const;
 
    private:
     client _client_opts;
@@ -53,3 +55,8 @@ class MONGOCXX_API pool {
 }  // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::options::pool.
+///
