@@ -1,4 +1,4 @@
-// Copyright 2023 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,32 +14,38 @@
 
 #pragma once
 
+#include <mongocxx/result/rewrap_many_datakey-fwd.hpp>
+
 #include <bsoncxx/document/value.hpp>
 #include <bsoncxx/stdx/optional.hpp>
+
 #include <mongocxx/bulk_write.hpp>
 
 #include <mongocxx/config/prelude.hpp>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace result {
 
 /// Class representing the result of a MongoDB rewrap_many_datakey operation.
-class MONGOCXX_API rewrap_many_datakey {
+class rewrap_many_datakey {
    public:
     rewrap_many_datakey() = default;
 
-    explicit rewrap_many_datakey(mongocxx::result::bulk_write bulk_write_result_doc);
+    explicit MONGOCXX_ABI_EXPORT_CDECL()
+        rewrap_many_datakey(mongocxx::v_noabi::result::bulk_write bulk_write_result_doc);
 
     ///
     /// Returns the bulk write result for this rewrap_many_datakey operation.
     ///
     /// @return The raw bulk write result.
     ///
-    const bsoncxx::stdx::optional<mongocxx::result::bulk_write>& result();
+    MONGOCXX_ABI_EXPORT_CDECL(
+        const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::result::bulk_write>&)
+    result();
 
    private:
-    bsoncxx::stdx::optional<mongocxx::result::bulk_write> _result;
+    bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::result::bulk_write> _result;
 };
 
 }  // namespace result
@@ -47,3 +53,8 @@ class MONGOCXX_API rewrap_many_datakey {
 }  // namespace mongocxx
 
 #include <mongocxx/config/postlude.hpp>
+
+///
+/// @file
+/// Provides @ref mongocxx::v_noabi::result::rewrap_many_datakey.
+///
