@@ -1,4 +1,4 @@
-// Copyright 2014-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,7 +14,8 @@
 
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
-#include <bsoncxx/stdx/make_unique.hpp>
+#include <bsoncxx/private/make_unique.hh>
+
 #include <mongocxx/bulk_write.hpp>
 #include <mongocxx/collection.hpp>
 #include <mongocxx/exception/bulk_write_exception.hpp>
@@ -40,6 +41,10 @@ bulk_write& bulk_write::operator=(bulk_write&&) noexcept = default;
 
 bulk_write::~bulk_write() = default;
 
+bool bulk_write::empty() const noexcept {
+    return _impl->is_empty;
+}
+
 bulk_write& bulk_write::append(const model::write& operation) {
     switch (operation.type()) {
         case write_type::k_insert_one: {
@@ -172,10 +177,12 @@ bulk_write& bulk_write::append(const model::write& operation) {
         }
     }
 
+    _impl->is_empty = false;
+
     return *this;
 }
 
-stdx::optional<result::bulk_write> bulk_write::execute() const {
+bsoncxx::v_noabi::stdx::optional<result::bulk_write> bulk_write::execute() const {
     mongoc_bulk_operation_t* b = _impl->operation_t;
     scoped_bson_t reply;
     bson_error_t error;
@@ -186,12 +193,12 @@ stdx::optional<result::bulk_write> bulk_write::execute() const {
 
     // Reply is empty for unacknowledged writes, so return disengaged optional.
     if (reply.view().empty()) {
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
 
     result::bulk_write result(reply.steal());
 
-    return stdx::optional<result::bulk_write>(std::move(result));
+    return bsoncxx::v_noabi::stdx::optional<result::bulk_write>(std::move(result));
 }
 
 bulk_write::bulk_write(const collection& coll,
@@ -218,9 +225,9 @@ bulk_write::bulk_write(const collection& coll,
     }
 
     scoped_bson_t bson_options(options_builder.extract());
-    _impl =
-        stdx::make_unique<bulk_write::impl>(libmongoc::collection_create_bulk_operation_with_opts(
-            coll._get_impl().collection_t, bson_options.bson()));
+    _impl = bsoncxx::make_unique<bulk_write::impl>(
+        libmongoc::collection_create_bulk_operation_with_opts(coll._get_impl().collection_t,
+                                                              bson_options.bson()));
 
     if (auto validation = options.bypass_document_validation()) {
         libmongoc::bulk_operation_set_bypass_document_validation(_impl->operation_t, *validation);
