@@ -1,4 +1,4 @@
-// Copyright 2017-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,7 +12,8 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#include <bsoncxx/stdx/make_unique.hpp>
+#include <bsoncxx/private/make_unique.hh>
+
 #include <mongocxx/exception/exception.hpp>
 #include <mongocxx/exception/private/mongoc_error.hh>
 #include <mongocxx/private/client.hh>
@@ -26,7 +27,7 @@ namespace v_noabi {
 // Private constructors.
 client_session::client_session(const mongocxx::v_noabi::client* client,
                                const mongocxx::v_noabi::options::client_session& options)
-    : _impl(stdx::make_unique<impl>(client, options)) {}
+    : _impl(bsoncxx::make_unique<impl>(client, options)) {}
 
 client_session::client_session(client_session&&) noexcept = default;
 
@@ -68,7 +69,7 @@ void client_session::advance_operation_time(
 }
 
 void client_session::start_transaction(
-    const stdx::optional<options::transaction>& transaction_opts) {
+    const bsoncxx::v_noabi::stdx::optional<options::transaction>& transaction_opts) {
     _impl->start_transaction(transaction_opts);
 }
 
