@@ -1,4 +1,4 @@
-// Copyright 2014-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -26,9 +26,10 @@
 #include <bsoncxx/exception/exception.hpp>
 #include <bsoncxx/private/helpers.hh>
 #include <bsoncxx/private/libbson.hh>
-#include <bsoncxx/stdx/make_unique.hpp>
+#include <bsoncxx/private/make_unique.hh>
 #include <bsoncxx/stdx/optional.hpp>
 #include <bsoncxx/types.hpp>
+
 #include <mongocxx/bulk_write.hpp>
 #include <mongocxx/client.hpp>
 #include <mongocxx/collection.hpp>
@@ -69,7 +70,6 @@ using bsoncxx::v_noabi::document::view_or_value;
 
 namespace {
 
-using bsoncxx::v_noabi::stdx::make_unique;
 using mongocxx::libbson::scoped_bson_t;
 
 const char* get_collection_name(mongoc_collection_t* collection) {
@@ -81,18 +81,17 @@ void destroy_fam_opts(mongoc_find_and_modify_opts_t* opts) {
 }
 
 template <typename T>
-mongocxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> find_and_modify(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> find_and_modify(
     mongoc_collection_t* collection_t,
     const mongoc_client_session_t* session_t,
     view_or_value filter,
     view_or_value* update,
     mongoc_find_and_modify_flags_t flags,
     bool bypass,
-    mongocxx::v_noabi::stdx::optional<bsoncxx::v_noabi::array::view_or_value> array_filters,
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::array::view_or_value> array_filters,
     const T& options) {
-    using unique_opts =
-        std::unique_ptr<mongoc_find_and_modify_opts_t,
-                        std::function<void MONGOCXX_CALL(mongoc_find_and_modify_opts_t*)>>;
+    using unique_opts = std::unique_ptr<mongoc_find_and_modify_opts_t,
+                                        std::function<void(mongoc_find_and_modify_opts_t*)>>;
 
     auto opts = unique_opts(mongocxx::libmongoc::find_and_modify_opts_new(), destroy_fam_opts);
 
@@ -191,7 +190,7 @@ mongocxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> find_and_mo
     const auto value = reply_view["value"];
 
     if (!value || value.type() == bsoncxx::v_noabi::type::k_null) {
-        return mongocxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>{};
+        return bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>{};
     }
 
     return bsoncxx::v_noabi::document::value{reply_view["value"].get_document().view()};
@@ -213,7 +212,7 @@ collection::operator bool() const noexcept {
     return static_cast<bool>(_impl);
 }
 
-stdx::string_view collection::name() const {
+bsoncxx::v_noabi::stdx::string_view collection::name() const {
     return {get_collection_name(_get_impl().collection_t)};
 }
 
@@ -265,20 +264,20 @@ void collection::rename(
 
 collection::collection(const database& database,
                        bsoncxx::v_noabi::string::view_or_value collection_name)
-    : _impl(stdx::make_unique<impl>(
+    : _impl(bsoncxx::make_unique<impl>(
           libmongoc::database_get_collection(database._get_impl().database_t,
                                              collection_name.terminated().data()),
           database.name(),
           database._get_impl().client_impl)) {}
 
 collection::collection(const database& database, void* collection)
-    : _impl(stdx::make_unique<impl>(static_cast<mongoc_collection_t*>(collection),
-                                    database.name(),
-                                    database._get_impl().client_impl)) {}
+    : _impl(bsoncxx::make_unique<impl>(static_cast<mongoc_collection_t*>(collection),
+                                       database.name(),
+                                       database._get_impl().client_impl)) {}
 
 collection::collection(const collection& c) {
     if (c) {
-        _impl = stdx::make_unique<impl>(c._get_impl());
+        _impl = bsoncxx::make_unique<impl>(c._get_impl());
     }
 }
 
@@ -286,7 +285,7 @@ collection& collection::operator=(const collection& c) {
     if (!c) {
         _impl.reset();
     } else if (!*this) {
-        _impl = stdx::make_unique<impl>(c._get_impl());
+        _impl = bsoncxx::make_unique<impl>(c._get_impl());
     } else {
         *_impl = c._get_impl();
     }
@@ -326,10 +325,10 @@ bsoncxx::v_noabi::builder::basic::document build_find_options_document(
     }
 
     // Prioritize new comment option over old $comment modifier.
-    if (const auto& comment = options.comment_option()) {
-        options_builder.append(kvp("comment", *comment));
-    } else if (const auto& comment = options.comment()) {
-        options_builder.append(kvp("comment", *comment));
+    if (const auto& new_comment = options.comment_option()) {
+        options_builder.append(kvp("comment", *new_comment));
+    } else if (const auto& old_comment = options.comment()) {
+        options_builder.append(kvp("comment", *old_comment));
     }
 
     if (const auto& cursor_type = options.cursor_type()) {
@@ -403,7 +402,7 @@ cursor collection::_find(const client_session* session,
                          const options::find& options) {
     scoped_bson_t filter_bson{std::move(filter)};
 
-    const mongoc_read_prefs_t* rp_ptr = NULL;
+    const mongoc_read_prefs_t* rp_ptr = nullptr;
     if (options.read_preference()) {
         rp_ptr = options.read_preference()->_impl->read_preference_t;
     }
@@ -444,7 +443,7 @@ cursor collection::find(const client_session& session,
     return _find(&session, std::move(filter), options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::_find_one(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> collection::_find_one(
     const client_session* session, view_or_value filter, const options::find& options) {
     options::find copy(options);
     copy.limit(1);
@@ -452,18 +451,18 @@ stdx::optional<bsoncxx::v_noabi::document::value> collection::_find_one(
         session ? find(*session, std::move(filter), copy) : find(std::move(filter), copy);
     cursor::iterator it = cursor.begin();
     if (it == cursor.end()) {
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
-    return stdx::optional<bsoncxx::v_noabi::document::value>(
+    return bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>(
         bsoncxx::v_noabi::document::value{*it});
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one(
     view_or_value filter, const options::find& options) {
     return _find_one(nullptr, std::move(filter), options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one(
     const client_session& session, view_or_value filter, const options::find& options) {
     return _find_one(&session, std::move(filter), options);
 }
@@ -483,7 +482,7 @@ cursor collection::_aggregate(const client_session* session,
 
     scoped_bson_t options_bson(b.view());
 
-    const ::mongoc_read_prefs_t* rp_ptr = NULL;
+    const ::mongoc_read_prefs_t* rp_ptr = nullptr;
 
     if (options.read_preference()) {
         rp_ptr = options.read_preference()->_impl->read_preference_t;
@@ -506,9 +505,8 @@ cursor collection::aggregate(const client_session& session,
     return _aggregate(&session, pipeline, options);
 }
 
-stdx::optional<result::insert_one> collection::_insert_one(const client_session* session,
-                                                           view_or_value document,
-                                                           const options::insert& options) {
+bsoncxx::v_noabi::stdx::optional<result::insert_one> collection::_insert_one(
+    const client_session* session, view_or_value document, const options::insert& options) {
     // TODO: We should consider making it possible to convert from an options::insert into
     // an options::bulk_write at the type level, removing the need to re-iterate this code
     // many times here and below.
@@ -545,42 +543,44 @@ stdx::optional<result::insert_one> collection::_insert_one(const client_session*
 
     auto result = bulk_op.execute();
     if (!result) {
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
 
-    return stdx::optional<result::insert_one>(
-        result::insert_one(std::move(result.value()), std::move(oid.get_value())));
+    return bsoncxx::v_noabi::stdx::optional<result::insert_one>(
+        result::insert_one(std::move(result.value()), oid.get_value()));
 }
 
-stdx::optional<result::insert_one> collection::insert_one(view_or_value document,
-                                                          const options::insert& options) {
+bsoncxx::v_noabi::stdx::optional<result::insert_one> collection::insert_one(
+    view_or_value document, const options::insert& options) {
     return _insert_one(nullptr, document, options);
 }
 
-stdx::optional<result::insert_one> collection::insert_one(const client_session& session,
-                                                          view_or_value document,
-                                                          const options::insert& options) {
+bsoncxx::v_noabi::stdx::optional<result::insert_one> collection::insert_one(
+    const client_session& session, view_or_value document, const options::insert& options) {
     return _insert_one(&session, document, options);
 }
 
-stdx::optional<result::replace_one> collection::_replace_one(const client_session* session,
-                                                             const options::bulk_write& bulk_opts,
-                                                             const model::replace_one& replace_op) {
+bsoncxx::v_noabi::stdx::optional<result::replace_one> collection::_replace_one(
+    const client_session* session,
+    const options::bulk_write& bulk_opts,
+    const model::replace_one& replace_op) {
     auto bulk_op = session ? create_bulk_write(*session, bulk_opts) : create_bulk_write(bulk_opts);
     bulk_op.append(replace_op);
 
     auto result = bulk_op.execute();
     if (!result) {
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
 
-    return stdx::optional<result::replace_one>(result::replace_one(std::move(result.value())));
+    return bsoncxx::v_noabi::stdx::optional<result::replace_one>(
+        result::replace_one(std::move(result.value())));
 }
 
-stdx::optional<result::replace_one> collection::_replace_one(const client_session* session,
-                                                             view_or_value filter,
-                                                             view_or_value replacement,
-                                                             const options::replace& options) {
+bsoncxx::v_noabi::stdx::optional<result::replace_one> collection::_replace_one(
+    const client_session* session,
+    view_or_value filter,
+    view_or_value replacement,
+    const options::replace& options) {
     options::bulk_write bulk_opts;
 
     if (const auto& bdv = options.bypass_document_validation()) {
@@ -616,23 +616,24 @@ stdx::optional<result::replace_one> collection::_replace_one(const client_sessio
     return _replace_one(session, bulk_opts, replace_op);
 }
 
-stdx::optional<result::replace_one> collection::replace_one(view_or_value filter,
-                                                            view_or_value replacement,
-                                                            const options::replace& options) {
+bsoncxx::v_noabi::stdx::optional<result::replace_one> collection::replace_one(
+    view_or_value filter, view_or_value replacement, const options::replace& options) {
     return _replace_one(nullptr, std::move(filter), replacement, options);
 }
 
-stdx::optional<result::replace_one> collection::replace_one(const client_session& session,
-                                                            view_or_value filter,
-                                                            view_or_value replacement,
-                                                            const options::replace& options) {
+bsoncxx::v_noabi::stdx::optional<result::replace_one> collection::replace_one(
+    const client_session& session,
+    view_or_value filter,
+    view_or_value replacement,
+    const options::replace& options) {
     return _replace_one(&session, std::move(filter), replacement, options);
 }
 
-stdx::optional<result::update> collection::_update_many(const client_session* session,
-                                                        view_or_value filter,
-                                                        view_or_value update,
-                                                        const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::_update_many(
+    const client_session* session,
+    view_or_value filter,
+    view_or_value update,
+    const options::update& options) {
     options::bulk_write bulk_opts;
 
     if (const auto& bdv = options.bypass_document_validation()) {
@@ -675,59 +676,61 @@ stdx::optional<result::update> collection::_update_many(const client_session* se
 
     auto result = bulk_op.execute();
     if (!result) {
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
 
-    return stdx::optional<result::update>(result::update(std::move(result.value())));
+    return bsoncxx::v_noabi::stdx::optional<result::update>(
+        result::update(std::move(result.value())));
 }
 
-stdx::optional<result::update> collection::update_many(view_or_value filter,
-                                                       view_or_value update,
-                                                       const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_many(
+    view_or_value filter, view_or_value update, const options::update& options) {
     return _update_many(nullptr, std::move(filter), update, options);
 }
 
-stdx::optional<result::update> collection::update_many(view_or_value filter,
-                                                       const pipeline& update,
-                                                       const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_many(
+    view_or_value filter, const pipeline& update, const options::update& options) {
     return _update_many(
         nullptr, std::move(filter), bsoncxx::v_noabi::document::view(update.view_array()), options);
 }
 
-stdx::optional<result::update> collection::update_many(view_or_value filter,
-                                                       std::initializer_list<_empty_doc_tag>,
-                                                       const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_many(
+    view_or_value filter, std::initializer_list<_empty_doc_tag>, const options::update& options) {
     return _update_many(nullptr, std::move(filter), bsoncxx::v_noabi::document::view{}, options);
 }
 
-stdx::optional<result::update> collection::update_many(const client_session& session,
-                                                       view_or_value filter,
-                                                       view_or_value update,
-                                                       const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_many(
+    const client_session& session,
+    view_or_value filter,
+    view_or_value update,
+    const options::update& options) {
     return _update_many(&session, std::move(filter), update, options);
 }
 
-stdx::optional<result::update> collection::update_many(const client_session& session,
-                                                       view_or_value filter,
-                                                       const pipeline& update,
-                                                       const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_many(
+    const client_session& session,
+    view_or_value filter,
+    const pipeline& update,
+    const options::update& options) {
     return _update_many(&session,
                         std::move(filter),
                         bsoncxx::v_noabi::document::view(update.view_array()),
                         options);
 }
 
-stdx::optional<result::update> collection::update_many(const client_session& session,
-                                                       view_or_value filter,
-                                                       std::initializer_list<_empty_doc_tag>,
-                                                       const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_many(
+    const client_session& session,
+    view_or_value filter,
+    std::initializer_list<_empty_doc_tag>,
+    const options::update& options) {
     return _update_many(&session, std::move(filter), bsoncxx::v_noabi::document::view{}, options);
 }
 
-stdx::optional<result::update> collection::_update_one(const client_session* session,
-                                                       view_or_value filter,
-                                                       view_or_value update,
-                                                       const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::_update_one(
+    const client_session* session,
+    view_or_value filter,
+    view_or_value update,
+    const options::update& options) {
     options::bulk_write bulk_opts;
 
     if (const auto& bdv = options.bypass_document_validation()) {
@@ -770,56 +773,57 @@ stdx::optional<result::update> collection::_update_one(const client_session* ses
 
     auto result = bulk_op.execute();
     if (!result) {
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
 
-    return stdx::optional<result::update>(result::update(std::move(result.value())));
+    return bsoncxx::v_noabi::stdx::optional<result::update>(
+        result::update(std::move(result.value())));
 }
 
-stdx::optional<result::update> collection::update_one(view_or_value filter,
-                                                      view_or_value update,
-                                                      const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_one(
+    view_or_value filter, view_or_value update, const options::update& options) {
     return _update_one(nullptr, std::move(filter), update, options);
 }
 
-stdx::optional<result::update> collection::update_one(view_or_value filter,
-                                                      const pipeline& update,
-                                                      const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_one(
+    view_or_value filter, const pipeline& update, const options::update& options) {
     return _update_one(
         nullptr, std::move(filter), bsoncxx::v_noabi::document::view(update.view_array()), options);
 }
 
-stdx::optional<result::update> collection::update_one(view_or_value filter,
-                                                      std::initializer_list<_empty_doc_tag>,
-                                                      const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_one(
+    view_or_value filter, std::initializer_list<_empty_doc_tag>, const options::update& options) {
     return _update_one(nullptr, std::move(filter), bsoncxx::v_noabi::document::view{}, options);
 }
 
-stdx::optional<result::update> collection::update_one(const client_session& session,
-                                                      view_or_value filter,
-                                                      view_or_value update,
-                                                      const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_one(
+    const client_session& session,
+    view_or_value filter,
+    view_or_value update,
+    const options::update& options) {
     return _update_one(&session, std::move(filter), update, options);
 }
 
-stdx::optional<result::update> collection::update_one(const client_session& session,
-                                                      view_or_value filter,
-                                                      const pipeline& update,
-                                                      const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_one(
+    const client_session& session,
+    view_or_value filter,
+    const pipeline& update,
+    const options::update& options) {
     return _update_one(&session,
                        std::move(filter),
                        bsoncxx::v_noabi::document::view(update.view_array()),
                        options);
 }
 
-stdx::optional<result::update> collection::update_one(const client_session& session,
-                                                      view_or_value filter,
-                                                      std::initializer_list<_empty_doc_tag>,
-                                                      const options::update& options) {
+bsoncxx::v_noabi::stdx::optional<result::update> collection::update_one(
+    const client_session& session,
+    view_or_value filter,
+    std::initializer_list<_empty_doc_tag>,
+    const options::update& options) {
     return _update_one(&session, std::move(filter), bsoncxx::v_noabi::document::view{}, options);
 }
 
-stdx::optional<result::delete_result> collection::_delete_many(
+bsoncxx::v_noabi::stdx::optional<result::delete_result> collection::_delete_many(
     const client_session* session, view_or_value filter, const options::delete_options& options) {
     options::bulk_write bulk_opts;
 
@@ -851,23 +855,24 @@ stdx::optional<result::delete_result> collection::_delete_many(
 
     auto result = bulk_op.execute();
     if (!result) {
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
 
-    return stdx::optional<result::delete_result>(result::delete_result(std::move(result.value())));
+    return bsoncxx::v_noabi::stdx::optional<result::delete_result>(
+        result::delete_result(std::move(result.value())));
 }
 
-stdx::optional<result::delete_result> collection::delete_many(
+bsoncxx::v_noabi::stdx::optional<result::delete_result> collection::delete_many(
     view_or_value filter, const options::delete_options& options) {
     return _delete_many(nullptr, std::move(filter), options);
 }
 
-stdx::optional<result::delete_result> collection::delete_many(
+bsoncxx::v_noabi::stdx::optional<result::delete_result> collection::delete_many(
     const client_session& session, view_or_value filter, const options::delete_options& options) {
     return _delete_many(&session, std::move(filter), options);
 }
 
-stdx::optional<result::delete_result> collection::_delete_one(
+bsoncxx::v_noabi::stdx::optional<result::delete_result> collection::_delete_one(
     const client_session* session, view_or_value filter, const options::delete_options& options) {
     options::bulk_write bulk_opts;
 
@@ -899,34 +904,36 @@ stdx::optional<result::delete_result> collection::_delete_one(
 
     auto result = bulk_op.execute();
     if (!result) {
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
 
-    return stdx::optional<result::delete_result>(result::delete_result(std::move(result.value())));
+    return bsoncxx::v_noabi::stdx::optional<result::delete_result>(
+        result::delete_result(std::move(result.value())));
 }
 
-stdx::optional<result::delete_result> collection::delete_one(
+bsoncxx::v_noabi::stdx::optional<result::delete_result> collection::delete_one(
     view_or_value filter, const options::delete_options& options) {
     return _delete_one(nullptr, std::move(filter), options);
 }
 
-stdx::optional<result::delete_result> collection::delete_one(
+bsoncxx::v_noabi::stdx::optional<result::delete_result> collection::delete_one(
     const client_session& session, view_or_value filter, const options::delete_options& options) {
     return _delete_one(&session, std::move(filter), options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::_find_one_and_replace(
-    const client_session* session,
-    view_or_value filter,
-    view_or_value replacement,
-    const options::find_one_and_replace& options) {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>
+collection::_find_one_and_replace(const client_session* session,
+                                  view_or_value filter,
+                                  view_or_value replacement,
+                                  const options::find_one_and_replace& options) {
     mongoc_find_and_modify_flags_t flags = MONGOC_FIND_AND_MODIFY_NONE;
     if (options.upsert().value_or(false)) {
-        flags = (mongoc_find_and_modify_flags_t)(flags | MONGOC_FIND_AND_MODIFY_UPSERT);
+        flags = static_cast<mongoc_find_and_modify_flags_t>(flags | MONGOC_FIND_AND_MODIFY_UPSERT);
     }
 
     if (options.return_document() == options::return_document::k_after) {
-        flags = (mongoc_find_and_modify_flags_t)(flags | MONGOC_FIND_AND_MODIFY_RETURN_NEW);
+        flags =
+            static_cast<mongoc_find_and_modify_flags_t>(flags | MONGOC_FIND_AND_MODIFY_RETURN_NEW);
     }
 
     return find_and_modify(_get_impl().collection_t,
@@ -935,35 +942,38 @@ stdx::optional<bsoncxx::v_noabi::document::value> collection::_find_one_and_repl
                            &replacement,
                            flags,
                            options.bypass_document_validation().value_or(false),
-                           stdx::nullopt,
+                           bsoncxx::v_noabi::stdx::nullopt,
                            options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_replace(
-    view_or_value filter, view_or_value replacement, const options::find_one_and_replace& options) {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>
+collection::find_one_and_replace(view_or_value filter,
+                                 view_or_value replacement,
+                                 const options::find_one_and_replace& options) {
     return _find_one_and_replace(nullptr, std::move(filter), replacement, options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_replace(
-    const client_session& session,
-    view_or_value filter,
-    view_or_value replacement,
-    const options::find_one_and_replace& options) {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>
+collection::find_one_and_replace(const client_session& session,
+                                 view_or_value filter,
+                                 view_or_value replacement,
+                                 const options::find_one_and_replace& options) {
     return _find_one_and_replace(&session, std::move(filter), replacement, options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::_find_one_and_update(
-    const client_session* session,
-    view_or_value filter,
-    view_or_value update,
-    const options::find_one_and_update& options) {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>
+collection::_find_one_and_update(const client_session* session,
+                                 view_or_value filter,
+                                 view_or_value update,
+                                 const options::find_one_and_update& options) {
     mongoc_find_and_modify_flags_t flags = MONGOC_FIND_AND_MODIFY_NONE;
     if (options.upsert().value_or(false)) {
-        flags = (mongoc_find_and_modify_flags_t)(flags | MONGOC_FIND_AND_MODIFY_UPSERT);
+        flags = static_cast<mongoc_find_and_modify_flags_t>(flags | MONGOC_FIND_AND_MODIFY_UPSERT);
     }
 
     if (options.return_document() == options::return_document::k_after) {
-        flags = (mongoc_find_and_modify_flags_t)(flags | MONGOC_FIND_AND_MODIFY_RETURN_NEW);
+        flags =
+            static_cast<mongoc_find_and_modify_flags_t>(flags | MONGOC_FIND_AND_MODIFY_RETURN_NEW);
     }
 
     return find_and_modify(_get_impl().collection_t,
@@ -976,18 +986,18 @@ stdx::optional<bsoncxx::v_noabi::document::value> collection::_find_one_and_upda
                            options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
     view_or_value filter, view_or_value update, const options::find_one_and_update& options) {
     return _find_one_and_update(nullptr, std::move(filter), update, options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
     view_or_value filter, const pipeline& update, const options::find_one_and_update& options) {
     return _find_one_and_update(
         nullptr, std::move(filter), bsoncxx::v_noabi::document::view(update.view_array()), options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
     view_or_value filter,
     std::initializer_list<_empty_doc_tag>,
     const options::find_one_and_update& options) {
@@ -995,7 +1005,7 @@ stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_updat
         nullptr, std::move(filter), bsoncxx::v_noabi::document::view{}, options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
     const client_session& session,
     view_or_value filter,
     view_or_value update,
@@ -1003,7 +1013,7 @@ stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_updat
     return _find_one_and_update(&session, std::move(filter), update, options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
     const client_session& session,
     view_or_value filter,
     const pipeline& update,
@@ -1014,7 +1024,7 @@ stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_updat
                                 options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_update(
     const client_session& session,
     view_or_value filter,
     std::initializer_list<_empty_doc_tag>,
@@ -1023,26 +1033,26 @@ stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_updat
         &session, std::move(filter), bsoncxx::v_noabi::document::view{}, options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::_find_one_and_delete(
-    const client_session* session,
-    view_or_value filter,
-    const options::find_one_and_delete& options) {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>
+collection::_find_one_and_delete(const client_session* session,
+                                 view_or_value filter,
+                                 const options::find_one_and_delete& options) {
     return find_and_modify(_get_impl().collection_t,
                            session ? session->_get_impl().get_session_t() : nullptr,
                            filter,
                            nullptr,
                            MONGOC_FIND_AND_MODIFY_REMOVE,
                            false,
-                           stdx::nullopt,
+                           bsoncxx::v_noabi::stdx::nullopt,
                            options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_delete(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_delete(
     view_or_value filter, const options::find_one_and_delete& options) {
     return _find_one_and_delete(nullptr, std::move(filter), options);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_delete(
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value> collection::find_one_and_delete(
     const client_session& session,
     view_or_value filter,
     const options::find_one_and_delete& options) {
@@ -1055,7 +1065,7 @@ std::int64_t collection::_count_documents(const client_session* session,
     scoped_bson_t bson_filter{filter};
     scoped_bson_t reply;
     bson_error_t error;
-    const mongoc_read_prefs_t* read_prefs = NULL;
+    const mongoc_read_prefs_t* read_prefs = nullptr;
 
     if (const auto& rp = options.read_preference()) {
         read_prefs = rp->_impl->read_preference_t;
@@ -1120,7 +1130,7 @@ std::int64_t collection::estimated_document_count(
     scoped_bson_t reply;
     bson_error_t error;
 
-    const mongoc_read_prefs_t* read_prefs = NULL;
+    const mongoc_read_prefs_t* read_prefs = nullptr;
 
     if (const auto& rp = options.read_preference()) {
         read_prefs = rp->_impl->read_preference_t;
@@ -1208,7 +1218,7 @@ cursor collection::_distinct(const client_session* session,
             bsoncxx::v_noabi::builder::concatenate_doc{session->_get_impl().to_document()});
     }
 
-    const mongoc_read_prefs_t* rp_ptr = NULL;
+    const mongoc_read_prefs_t* rp_ptr = nullptr;
     if (const auto& rp = options.read_preference()) {
         rp_ptr = rp->_impl->read_preference_t;
     }
@@ -1293,7 +1303,7 @@ cursor collection::list_indexes(const client_session& session) const {
 }
 
 void collection::_drop(const client_session* session,
-                       const stdx::optional<mongocxx::v_noabi::write_concern>& wc,
+                       const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& wc,
                        bsoncxx::v_noabi::document::view_or_value collection_options) {
     bson_error_t error;
 
@@ -1319,18 +1329,19 @@ void collection::_drop(const client_session* session,
     // collection. We check for this failure using 'code', but we fall back to checking 'message'
     // for old server versions (3.0 and earlier) that do not send a code with the command response.
     if (!result && !(error.code == ::MONGOC_ERROR_COLLECTION_DOES_NOT_EXIST ||
-                     stdx::string_view{error.message} == stdx::string_view{"ns not found"})) {
+                     bsoncxx::v_noabi::stdx::string_view{error.message} ==
+                         bsoncxx::v_noabi::stdx::string_view{"ns not found"})) {
         throw_exception<operation_exception>(error);
     }
 }
 
-void collection::drop(const stdx::optional<mongocxx::v_noabi::write_concern>& wc,
+void collection::drop(const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& wc,
                       bsoncxx::v_noabi::document::view_or_value collection_options) {
     return _drop(nullptr, wc, collection_options);
 }
 
 void collection::drop(const client_session& session,
-                      const stdx::optional<mongocxx::v_noabi::write_concern>& wc,
+                      const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& wc,
                       bsoncxx::v_noabi::document::view_or_value collection_options) {
     return _drop(&session, wc, collection_options);
 }
@@ -1341,7 +1352,7 @@ void collection::read_concern(mongocxx::v_noabi::read_concern rc) {
 
 mongocxx::v_noabi::read_concern collection::read_concern() const {
     auto rc = libmongoc::collection_get_read_concern(_get_impl().collection_t);
-    return {stdx::make_unique<read_concern::impl>(libmongoc::read_concern_copy(rc))};
+    return {bsoncxx::make_unique<read_concern::impl>(libmongoc::read_concern_copy(rc))};
 }
 
 void collection::read_preference(mongocxx::v_noabi::read_preference rp) {
@@ -1350,7 +1361,7 @@ void collection::read_preference(mongocxx::v_noabi::read_preference rp) {
 
 mongocxx::v_noabi::read_preference collection::read_preference() const {
     mongocxx::v_noabi::read_preference rp(
-        stdx::make_unique<read_preference::impl>(libmongoc::read_prefs_copy(
+        bsoncxx::make_unique<read_preference::impl>(libmongoc::read_prefs_copy(
             libmongoc::collection_get_read_prefs(_get_impl().collection_t))));
     return rp;
 }
@@ -1361,7 +1372,7 @@ void collection::write_concern(mongocxx::v_noabi::write_concern wc) {
 
 mongocxx::v_noabi::write_concern collection::write_concern() const {
     mongocxx::v_noabi::write_concern wc(
-        stdx::make_unique<write_concern::impl>(libmongoc::write_concern_copy(
+        bsoncxx::make_unique<write_concern::impl>(libmongoc::write_concern_copy(
             libmongoc::collection_get_write_concern(_get_impl().collection_t))));
     return wc;
 }
@@ -1456,11 +1467,11 @@ void collection::_insert_many_doc_handler(mongocxx::v_noabi::bulk_write& writes,
     inserted_ids.append(id_doc.view());
 }
 
-stdx::optional<result::insert_many> collection::_exec_insert_many(
+bsoncxx::v_noabi::stdx::optional<result::insert_many> collection::_exec_insert_many(
     mongocxx::v_noabi::bulk_write& writes, bsoncxx::v_noabi::builder::basic::array& inserted_ids) {
     auto result = writes.execute();
     if (!result) {
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
 
     return result::insert_many{std::move(result.value()), inserted_ids.extract()};
