@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,8 +17,9 @@
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
 #include <bsoncxx/builder/concatenate.hpp>
-#include <bsoncxx/stdx/make_unique.hpp>
+#include <bsoncxx/private/make_unique.hh>
 #include <bsoncxx/string/to_string.hpp>
+
 #include <mongocxx/client.hpp>
 #include <mongocxx/database.hpp>
 #include <mongocxx/exception/error_code.hpp>
@@ -49,15 +50,21 @@ class collection_names {
    public:
     explicit collection_names(char** names) {
         _names = names;
-    };
+    }
 
     ~collection_names() {
         bson_strfreev(_names);
     }
 
+    collection_names(collection_names&&) noexcept = delete;
+    collection_names& operator=(collection_names&&) noexcept = delete;
+
+    collection_names(const collection_names&) = delete;
+    collection_names& operator=(const collection_names&) = delete;
+
     const char* operator[](const std::size_t i) const {
         return _names[i];
-    };
+    }
 
     bool operator!() const {
         return _names == nullptr;
@@ -80,14 +87,14 @@ database::~database() = default;
 
 database::database(const mongocxx::v_noabi::client& client,
                    bsoncxx::v_noabi::string::view_or_value name)
-    : _impl(stdx::make_unique<impl>(
+    : _impl(bsoncxx::make_unique<impl>(
           libmongoc::client_get_database(client._get_impl().client_t, name.terminated().data()),
           &client._get_impl(),
           name.terminated().data())) {}
 
 database::database(const database& d) {
     if (d) {
-        _impl = stdx::make_unique<impl>(d._get_impl());
+        _impl = bsoncxx::make_unique<impl>(d._get_impl());
     }
 }
 
@@ -95,7 +102,7 @@ database& database::operator=(const database& d) {
     if (!d) {
         _impl.reset();
     } else if (!*this) {
-        _impl = stdx::make_unique<impl>(d._get_impl());
+        _impl = bsoncxx::make_unique<impl>(d._get_impl());
     } else {
         *_impl = d._get_impl();
     }
@@ -122,7 +129,7 @@ cursor database::_aggregate(const client_session* session,
 
     scoped_bson_t options_bson(b.view());
 
-    const ::mongoc_read_prefs_t* rp_ptr = NULL;
+    const ::mongoc_read_prefs_t* rp_ptr = nullptr;
 
     if (options.read_preference()) {
         rp_ptr = options.read_preference()->_impl->read_preference_t;
@@ -205,7 +212,7 @@ std::vector<std::string> database::list_collection_names(
     return _list_collection_names(&session, filter);
 }
 
-stdx::string_view database::name() const {
+bsoncxx::v_noabi::stdx::string_view database::name() const {
     return _get_impl().name;
 }
 
@@ -224,7 +231,7 @@ bsoncxx::v_noabi::document::value database::_run_command(
     scoped_bson_t options_bson(options_builder.extract());
     auto result = libmongoc::database_command_with_opts(_get_impl().database_t,
                                                         command_bson.bson(),
-                                                        NULL,
+                                                        nullptr,
                                                         options_bson.bson(),
                                                         reply_bson.bson_for_init(),
                                                         &error);
@@ -270,9 +277,9 @@ bsoncxx::v_noabi::document::value database::run_command(
 
 collection database::_create_collection(
     const client_session* session,
-    stdx::string_view name,
+    bsoncxx::v_noabi::stdx::string_view name,
     bsoncxx::v_noabi::document::view_or_value collection_options,
-    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
+    const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
     bsoncxx::v_noabi::builder::basic::document options_builder;
     bson_error_t error;
 
@@ -301,110 +308,21 @@ collection database::_create_collection(
     return mongocxx::v_noabi::collection(*this, result);
 }
 
-collection database::_create_collection_deprecated(
-    const client_session* session,
-    bsoncxx::v_noabi::string::view_or_value name,
-    const options::create_collection_deprecated& collection_options,
-    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
-    bsoncxx::v_noabi::builder::basic::document options_builder;
-
-    if (collection_options.capped()) {
-        options_builder.append(kvp("capped", *collection_options.capped()));
-    }
-
-    if (collection_options.collation()) {
-        options_builder.append(kvp("collation", *collection_options.collation()));
-    }
-
-    if (collection_options.max()) {
-        options_builder.append(kvp("max", *collection_options.max()));
-    }
-
-    if (collection_options.no_padding()) {
-        options_builder.append(kvp("flags", (*collection_options.no_padding() ? 0x10 : 0x00)));
-    }
-
-    if (collection_options.size()) {
-        options_builder.append(kvp("size", *collection_options.size()));
-    }
-
-    if (collection_options.storage_engine()) {
-        options_builder.append(kvp("storageEngine", *collection_options.storage_engine()));
-    }
-
-    if (collection_options.validation_criteria()) {
-        auto validation_level_to_string = [](validation_criteria::validation_level level) {
-            switch (level) {
-                case validation_criteria::validation_level::k_off:
-                    return "off";
-                case validation_criteria::validation_level::k_moderate:
-                    return "moderate";
-                case validation_criteria::validation_level::k_strict:
-                    return "strict";
-            }
-            MONGOCXX_UNREACHABLE;
-        };
-
-        auto validation_action_to_string = [](validation_criteria::validation_action action) {
-            switch (action) {
-                case validation_criteria::validation_action::k_warn:
-                    return "warn";
-                case validation_criteria::validation_action::k_error:
-                    return "error";
-            }
-            MONGOCXX_UNREACHABLE;
-        };
-
-        auto validation_criteria = *collection_options.validation_criteria();
-
-        if (validation_criteria.rule()) {
-            options_builder.append(kvp("validator", *validation_criteria.rule()));
-        }
-
-        if (validation_criteria.level()) {
-            options_builder.append(
-                kvp("validationLevel", validation_level_to_string(*validation_criteria.level())));
-        }
-
-        if (validation_criteria.action()) {
-            options_builder.append(kvp("validationAction",
-                                       validation_action_to_string(*validation_criteria.action())));
-        }
-    }
-
-    return _create_collection(session, name, options_builder.view(), write_concern);
-}
-
 mongocxx::v_noabi::collection database::create_collection(
-    stdx::string_view name,
+    bsoncxx::v_noabi::stdx::string_view name,
     bsoncxx::v_noabi::document::view_or_value collection_options,
-    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
+    const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
     return _create_collection(nullptr, name, collection_options, write_concern);
 }
 
 mongocxx::v_noabi::collection database::create_collection(
     const client_session& session,
-    stdx::string_view name,
+    bsoncxx::v_noabi::stdx::string_view name,
     bsoncxx::v_noabi::document::view_or_value collection_options,
-    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
+    const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
     return _create_collection(&session, name, collection_options, write_concern);
 }
 
-mongocxx::v_noabi::collection database::create_collection_deprecated(
-    bsoncxx::v_noabi::string::view_or_value name,
-    const options::create_collection_deprecated& collection_options,
-    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
-    return _create_collection_deprecated(nullptr, name, collection_options, write_concern);
-}
-
-mongocxx::v_noabi::collection database::create_collection_deprecated(
-    const client_session& session,
-    bsoncxx::v_noabi::string::view_or_value name,
-    const options::create_collection_deprecated& collection_options,
-    const stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
-    return _create_collection_deprecated(&session, name, collection_options, write_concern);
-}
-
 void database::_drop(
     const client_session* session,
     const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& write_concern) {
@@ -444,7 +362,7 @@ void database::read_concern(mongocxx::v_noabi::read_concern rc) {
 
 mongocxx::v_noabi::read_concern database::read_concern() const {
     auto rc = libmongoc::database_get_read_concern(_get_impl().database_t);
-    return {stdx::make_unique<read_concern::impl>(libmongoc::read_concern_copy(rc))};
+    return {bsoncxx::make_unique<read_concern::impl>(libmongoc::read_concern_copy(rc))};
 }
 
 void database::read_preference(mongocxx::v_noabi::read_preference rp) {
@@ -463,7 +381,7 @@ bool database::has_collection(bsoncxx::v_noabi::string::view_or_value name) cons
 }
 
 mongocxx::v_noabi::read_preference database::read_preference() const {
-    mongocxx::v_noabi::read_preference rp(stdx::make_unique<read_preference::impl>(
+    mongocxx::v_noabi::read_preference rp(bsoncxx::make_unique<read_preference::impl>(
         libmongoc::read_prefs_copy(libmongoc::database_get_read_prefs(_get_impl().database_t))));
     return rp;
 }
@@ -474,7 +392,7 @@ void database::write_concern(mongocxx::v_noabi::write_concern wc) {
 
 mongocxx::v_noabi::write_concern database::write_concern() const {
     mongocxx::v_noabi::write_concern wc(
-        stdx::make_unique<write_concern::impl>(libmongoc::write_concern_copy(
+        bsoncxx::make_unique<write_concern::impl>(libmongoc::write_concern_copy(
             libmongoc::database_get_write_concern(_get_impl().database_t))));
     return wc;
 }
