@@ -1,4 +1,4 @@
-// Copyright 2017 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,8 +17,9 @@
 #include <cstring>
 #include <sstream>
 
-#include <bsoncxx/stdx/make_unique.hpp>
+#include <bsoncxx/private/make_unique.hh>
 #include <bsoncxx/types.hpp>
+
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/gridfs/downloader.hpp>
@@ -31,12 +32,12 @@ namespace mongocxx {
 namespace v_noabi {
 namespace gridfs {
 
-downloader::downloader(stdx::optional<cursor> chunks,
+downloader::downloader(bsoncxx::v_noabi::stdx::optional<cursor> chunks,
                        chunks_and_bytes_offset start,
                        std::int32_t chunk_size,
                        std::int64_t file_len,
                        bsoncxx::v_noabi::document::value files_doc)
-    : _impl{stdx::make_unique<impl>(
+    : _impl{bsoncxx::make_unique<impl>(
           std::move(chunks), start, chunk_size, file_len, std::move(files_doc))} {}
 
 downloader::downloader() noexcept = default;
