@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,7 +17,8 @@
 #include <type_traits>
 #include <utility>
 
-#include <bsoncxx/stdx/make_unique.hpp>
+#include <bsoncxx/private/make_unique.hh>
+
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/instance.hpp>
@@ -63,8 +64,8 @@ void user_log_handler(::mongoc_log_level_t mongoc_log_level,
                       const char* message,
                       void* user_data) {
     (*static_cast<logger*>(user_data))(convert_log_level(mongoc_log_level),
-                                       stdx::string_view{log_domain},
-                                       stdx::string_view{message});
+                                       bsoncxx::v_noabi::stdx::string_view{log_domain},
+                                       bsoncxx::v_noabi::stdx::string_view{message});
 }
 
 // A region of memory that acts as a sentintel value indicating that an instance object is being
@@ -126,6 +127,12 @@ class instance::impl {
 #endif
     }
 
+    impl(impl&&) noexcept = delete;
+    impl& operator=(impl&&) noexcept = delete;
+
+    impl(const impl&) = delete;
+    impl& operator=(const impl&) = delete;
+
     const std::unique_ptr<logger> _user_logger;
 };
 
@@ -138,7 +145,7 @@ instance::instance(std::unique_ptr<logger> logger) {
         throw logic_error{error_code::k_cannot_recreate_instance};
     }
 
-    _impl = stdx::make_unique<impl>(std::move(logger));
+    _impl = bsoncxx::make_unique<impl>(std::move(logger));
 }
 
 instance::instance(instance&&) noexcept = default;
