@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -13,6 +13,7 @@
 // limitations under the License.
 
 #include <bsoncxx/builder/basic/document.hpp>
+
 #include <mongocxx/options/aggregate.hpp>
 #include <mongocxx/private/append_aggregate_options.hh>
 #include <mongocxx/private/read_preference.hh>
@@ -84,48 +85,53 @@ aggregate& aggregate::comment(bsoncxx::v_noabi::types::bson_value::view_or_value
     return *this;
 }
 
-const stdx::optional<bool>& aggregate::allow_disk_use() const {
+const bsoncxx::v_noabi::stdx::optional<bool>& aggregate::allow_disk_use() const {
     return _allow_disk_use;
 }
 
-const stdx::optional<std::int32_t>& aggregate::batch_size() const {
+const bsoncxx::v_noabi::stdx::optional<std::int32_t>& aggregate::batch_size() const {
     return _batch_size;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& aggregate::collation() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&
+aggregate::collation() const {
     return _collation;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& aggregate::let() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>& aggregate::let()
+    const {
     return _let;
 }
 
-const stdx::optional<std::chrono::milliseconds>& aggregate::max_time() const {
+const bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds>& aggregate::max_time() const {
     return _max_time;
 }
 
-const stdx::optional<mongocxx::v_noabi::read_preference>& aggregate::read_preference() const {
+const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_preference>&
+aggregate::read_preference() const {
     return _read_preference;
 }
 
-const stdx::optional<bool>& aggregate::bypass_document_validation() const {
+const bsoncxx::v_noabi::stdx::optional<bool>& aggregate::bypass_document_validation() const {
     return _bypass_document_validation;
 }
 
-const stdx::optional<mongocxx::v_noabi::hint>& aggregate::hint() const {
+const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::hint>& aggregate::hint() const {
     return _hint;
 }
 
-const stdx::optional<mongocxx::v_noabi::read_concern>& aggregate::read_concern() const {
+const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_concern>& aggregate::read_concern()
+    const {
     return _read_concern;
 }
 
-const stdx::optional<mongocxx::v_noabi::write_concern>& aggregate::write_concern() const {
+const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& aggregate::write_concern()
+    const {
     return _write_concern;
 }
 
-const stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>& aggregate::comment()
-    const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>&
+aggregate::comment() const {
     return _comment;
 }
 
