@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -36,7 +36,8 @@ bulk_write& bulk_write::write_concern(mongocxx::v_noabi::write_concern wc) {
     return *this;
 }
 
-const stdx::optional<mongocxx::v_noabi::write_concern>& bulk_write::write_concern() const {
+const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>&
+bulk_write::write_concern() const {
     return _write_concern;
 }
 
@@ -45,7 +46,7 @@ bulk_write& bulk_write::bypass_document_validation(bool bypass_document_validati
     return *this;
 }
 
-const stdx::optional<bool> bulk_write::bypass_document_validation() const {
+const bsoncxx::v_noabi::stdx::optional<bool> bulk_write::bypass_document_validation() const {
     return _bypass_document_validation;
 }
 
@@ -54,7 +55,8 @@ bulk_write& bulk_write::let(bsoncxx::v_noabi::document::view_or_value let) {
     return *this;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value> bulk_write::let() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> bulk_write::let()
+    const {
     return _let;
 }
 
@@ -63,8 +65,8 @@ bulk_write& bulk_write::comment(bsoncxx::v_noabi::types::bson_value::view_or_val
     return *this;
 }
 
-const stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value> bulk_write::comment()
-    const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>
+bulk_write::comment() const {
     return _comment;
 }
 
