@@ -1,4 +1,4 @@
-// Copyright 2020 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -29,7 +29,8 @@ client_encryption& client_encryption::key_vault_client(mongocxx::v_noabi::client
     return *this;
 }
 
-const stdx::optional<mongocxx::v_noabi::client*>& client_encryption::key_vault_client() const {
+const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::client*>&
+client_encryption::key_vault_client() const {
     return _key_vault_client;
 }
 
@@ -38,7 +39,8 @@ client_encryption& client_encryption::key_vault_namespace(client_encryption::ns_
     return *this;
 }
 
-const stdx::optional<client_encryption::ns_pair>& client_encryption::key_vault_namespace() const {
+const bsoncxx::v_noabi::stdx::optional<client_encryption::ns_pair>&
+client_encryption::key_vault_namespace() const {
     return _key_vault_namespace;
 }
 
@@ -48,8 +50,8 @@ client_encryption& client_encryption::kms_providers(
     return *this;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& client_encryption::kms_providers()
-    const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&
+client_encryption::kms_providers() const {
     return _kms_providers;
 }
 
@@ -58,8 +60,8 @@ client_encryption& client_encryption::tls_opts(bsoncxx::v_noabi::document::view_
     return *this;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& client_encryption::tls_opts()
-    const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&
+client_encryption::tls_opts() const {
     return _tls_opts;
 }
 
