@@ -1,4 +1,4 @@
-// Copyright 2020 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -27,7 +27,8 @@ data_key& data_key::master_key(bsoncxx::v_noabi::document::view_or_value master_
     return *this;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& data_key::master_key() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&
+data_key::master_key() const {
     return _master_key;
 }
 
@@ -52,7 +53,7 @@ void* data_key::convert() const {
 
     if (!_key_alt_names.empty()) {
         auto altnames = _key_alt_names;
-        char** names = (char**)bson_malloc(sizeof(char*) * altnames.size());
+        auto names = static_cast<char**>(bson_malloc(sizeof(char*) * altnames.size()));
         uint32_t i = 0;
 
         for (auto&& name : altnames) {
@@ -78,7 +79,7 @@ data_key& data_key::key_material(data_key::key_material_type key_material) {
     return *this;
 }
 
-const stdx::optional<data_key::key_material_type>& data_key::key_material() {
+const bsoncxx::v_noabi::stdx::optional<data_key::key_material_type>& data_key::key_material() {
     return _key_material;
 }
 
