@@ -1,4 +1,4 @@
-// Copyright 2018-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -38,16 +38,18 @@ estimated_document_count& estimated_document_count::comment(
     return *this;
 }
 
-const stdx::optional<std::chrono::milliseconds>& estimated_document_count::max_time() const {
+const bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds>&
+estimated_document_count::max_time() const {
     return _max_time;
 }
 
-const stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>&
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>&
 estimated_document_count::comment() const {
     return _comment;
 }
 
-const stdx::optional<read_preference>& estimated_document_count::read_preference() const {
+const bsoncxx::v_noabi::stdx::optional<read_preference>& estimated_document_count::read_preference()
+    const {
     return _read_preference;
 }
 
