@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -126,88 +126,96 @@ find& find::sort(bsoncxx::v_noabi::document::view_or_value ordering) {
     return *this;
 }
 
-const stdx::optional<bool>& find::allow_disk_use() const {
+const bsoncxx::v_noabi::stdx::optional<bool>& find::allow_disk_use() const {
     return _allow_disk_use;
 }
 
-const stdx::optional<bool>& find::allow_partial_results() const {
+const bsoncxx::v_noabi::stdx::optional<bool>& find::allow_partial_results() const {
     return _allow_partial_results;
 }
 
-const stdx::optional<std::int32_t>& find::batch_size() const {
+const bsoncxx::v_noabi::stdx::optional<std::int32_t>& find::batch_size() const {
     return _batch_size;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& find::collation() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>& find::collation()
+    const {
     return _collation;
 }
 
-const stdx::optional<bsoncxx::v_noabi::string::view_or_value>& find::comment() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value>& find::comment()
+    const {
     return _comment;
 }
 
-const stdx::optional<cursor::type>& find::cursor_type() const {
+const bsoncxx::v_noabi::stdx::optional<cursor::type>& find::cursor_type() const {
     return _cursor_type;
 }
 
-const stdx::optional<mongocxx::v_noabi::hint>& find::hint() const {
+const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::hint>& find::hint() const {
     return _hint;
 }
 
-const stdx::optional<std::int64_t>& find::limit() const {
+const bsoncxx::v_noabi::stdx::optional<std::int64_t>& find::limit() const {
     return _limit;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value> find::let() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value> find::let()
+    const {
     return _let;
 }
 
-const stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>& find::comment_option()
-    const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>&
+find::comment_option() const {
     return _comment_option;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& find::max() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>& find::max()
+    const {
     return _max;
 }
 
-const stdx::optional<std::chrono::milliseconds>& find::max_await_time() const {
+const bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds>& find::max_await_time() const {
     return _max_await_time;
 }
 
-const stdx::optional<std::chrono::milliseconds>& find::max_time() const {
+const bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds>& find::max_time() const {
     return _max_time;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& find::min() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>& find::min()
+    const {
     return _min;
 }
 
-const stdx::optional<bool>& find::no_cursor_timeout() const {
+const bsoncxx::v_noabi::stdx::optional<bool>& find::no_cursor_timeout() const {
     return _no_cursor_timeout;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& find::projection() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&
+find::projection() const {
     return _projection;
 }
 
-const stdx::optional<bool>& find::return_key() const {
+const bsoncxx::v_noabi::stdx::optional<bool>& find::return_key() const {
     return _return_key;
 }
 
-const stdx::optional<bool>& find::show_record_id() const {
+const bsoncxx::v_noabi::stdx::optional<bool>& find::show_record_id() const {
     return _show_record_id;
 }
 
-const stdx::optional<std::int64_t>& find::skip() const {
+const bsoncxx::v_noabi::stdx::optional<std::int64_t>& find::skip() const {
     return _skip;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& find::sort() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>& find::sort()
+    const {
     return _ordering;
 }
 
-const stdx::optional<mongocxx::v_noabi::read_preference>& find::read_preference() const {
+const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::read_preference>& find::read_preference()
+    const {
     return _read_preference;
 }
 
