@@ -1,4 +1,4 @@
-// Copyright 2017 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -13,6 +13,7 @@
 // limitations under the License.
 
 #include <bsoncxx/view_or_value.hpp>
+
 #include <mongocxx/options/gridfs/upload.hpp>
 
 #include <mongocxx/config/private/prelude.hh>
@@ -27,7 +28,7 @@ upload& upload::chunk_size_bytes(std::int32_t chunk_size_bytes) {
     return *this;
 }
 
-const stdx::optional<std::int32_t>& upload::chunk_size_bytes() const {
+const bsoncxx::v_noabi::stdx::optional<std::int32_t>& upload::chunk_size_bytes() const {
     return _chunk_size_bytes;
 }
 
@@ -36,7 +37,8 @@ upload& upload::metadata(bsoncxx::v_noabi::document::view_or_value metadata) {
     return *this;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::view_or_value>& upload::metadata() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view_or_value>&
+upload::metadata() const {
     return _metadata;
 }
 
