@@ -1,4 +1,4 @@
-// Copyright 2017 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
 #include <bsoncxx/types.hpp>
+
 #include <mongocxx/options/index_view.hpp>
 
 #include <mongocxx/config/private/prelude.hh>
@@ -37,7 +38,8 @@ const bsoncxx::v_noabi::stdx::optional<std::chrono::milliseconds>& index_view::m
     return _max_time;
 }
 
-const stdx::optional<bsoncxx::v_noabi::document::value> index_view::commit_quorum() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::value>
+index_view::commit_quorum() const {
     return _commit_quorum;
 }
 
@@ -52,13 +54,13 @@ index_view& index_view::write_concern(mongocxx::v_noabi::write_concern write_con
 }
 
 index_view& index_view::commit_quorum(int commit_quorum) {
-    _commit_quorum = stdx::make_optional<bsoncxx::v_noabi::document::value>(
+    _commit_quorum = bsoncxx::v_noabi::stdx::make_optional<bsoncxx::v_noabi::document::value>(
         make_document(kvp("commitQuorum", bsoncxx::v_noabi::types::b_int32{commit_quorum})));
     return *this;
 }
 
 index_view& index_view::commit_quorum(std::string commit_quorum) {
-    _commit_quorum = stdx::make_optional<bsoncxx::v_noabi::document::value>(
+    _commit_quorum = bsoncxx::v_noabi::stdx::make_optional<bsoncxx::v_noabi::document::value>(
         make_document(kvp("commitQuorum", commit_quorum)));
     return *this;
 }
