@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -40,19 +40,21 @@ insert& insert::comment(bsoncxx::v_noabi::types::bson_value::view_or_value comme
     return *this;
 }
 
-const stdx::optional<bool>& insert::bypass_document_validation() const {
+const bsoncxx::v_noabi::stdx::optional<bool>& insert::bypass_document_validation() const {
     return _bypass_document_validation;
 }
 
-const stdx::optional<mongocxx::v_noabi::write_concern>& insert::write_concern() const {
+const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::write_concern>& insert::write_concern()
+    const {
     return _write_concern;
 }
 
-const stdx::optional<bool>& insert::ordered() const {
+const bsoncxx::v_noabi::stdx::optional<bool>& insert::ordered() const {
     return _ordered;
 }
 
-const stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>& insert::comment() const {
+const bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::types::bson_value::view_or_value>&
+insert::comment() const {
     return _comment;
 }
 
