@@ -1,4 +1,4 @@
-// Copyright 2021 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -15,11 +15,11 @@
 #include <system_error>
 
 #include <bsoncxx/stdx/string_view.hpp>
+
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/options/server_api.hpp>
 #include <mongocxx/private/libmongoc.hh>
-#include <mongocxx/stdx.hpp>
 
 #include <mongocxx/config/private/prelude.hh>
 
@@ -37,8 +37,8 @@ std::string server_api::version_to_string(server_api::version version) {
     }
 }
 
-server_api::version server_api::version_from_string(stdx::string_view version) {
-    if (!version.compare("1")) {
+server_api::version server_api::version_from_string(bsoncxx::v_noabi::stdx::string_view version) {
+    if (version == "1") {
         return server_api::version::k_version_1;
     }
     throw mongocxx::v_noabi::logic_error{mongocxx::v_noabi::error_code::k_invalid_parameter,
@@ -52,7 +52,7 @@ server_api& server_api::strict(bool strict) {
     return *this;
 }
 
-const stdx::optional<bool>& server_api::strict() const {
+const bsoncxx::v_noabi::stdx::optional<bool>& server_api::strict() const {
     return _strict;
 }
 
@@ -61,7 +61,7 @@ server_api& server_api::deprecation_errors(bool deprecation_errors) {
     return *this;
 }
 
-const stdx::optional<bool>& server_api::deprecation_errors() const {
+const bsoncxx::v_noabi::stdx::optional<bool>& server_api::deprecation_errors() const {
     return _deprecation_errors;
 }
 
