@@ -1,4 +1,4 @@
-// Copyright 2015 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,7 +14,8 @@
 
 #include <utility>
 
-#include <bsoncxx/stdx/make_unique.hpp>
+#include <bsoncxx/private/make_unique.hh>
+
 #include <mongocxx/client.hpp>
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/exception.hpp>
@@ -55,7 +56,7 @@ void pool::_release(client* client) {
 pool::~pool() = default;
 
 pool::pool(const uri& uri, const options::pool& options)
-    : _impl{stdx::make_unique<impl>(construct_client_pool(uri._impl->uri_t))} {
+    : _impl{bsoncxx::make_unique<impl>(construct_client_pool(uri._impl->uri_t))} {
 #if defined(MONGOCXX_ENABLE_SSL) && defined(MONGOC_ENABLE_SSL)
     if (options.client_opts().tls_opts()) {
         if (!uri.tls())
@@ -131,14 +132,20 @@ pool::entry::operator bool() const noexcept {
 pool::entry::entry(pool::entry::unique_client p) : _client(std::move(p)) {}
 
 pool::entry pool::acquire() {
-    return entry(entry::unique_client(new client(libmongoc::client_pool_pop(_impl->client_pool_t)),
-                                      [this](client* client) { _release(client); }));
+    auto cli = libmongoc::client_pool_pop(_impl->client_pool_t);
+    if (!cli)
+        throw exception{
+            error_code::k_pool_wait_queue_timeout,
+            "failed to acquire client, possibly due to parameter 'waitQueueTimeoutMS' limits."};
+
+    return entry(
+        entry::unique_client(new client(cli), [this](client* client) { _release(client); }));
 }
 
-stdx::optional<pool::entry> pool::try_acquire() {
+bsoncxx::v_noabi::stdx::optional<pool::entry> pool::try_acquire() {
     auto cli = libmongoc::client_pool_try_pop(_impl->client_pool_t);
     if (!cli)
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
 
     return entry(
         entry::unique_client(new client(cli), [this](client* client) { _release(client); }));
