@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -56,7 +56,8 @@ void scoped_bson_t::init_from_static(bsoncxx::document::value doc) {
     this->init_from_static(bsoncxx::document::view_or_value(std::move(doc)));
 }
 
-scoped_bson_t::scoped_bson_t(bsoncxx::stdx::optional<bsoncxx::document::view_or_value> doc) {
+scoped_bson_t::scoped_bson_t(
+    bsoncxx::v_noabi::stdx::optional<bsoncxx::document::view_or_value> doc) {
     if (doc) {
         this->init_from_static(std::move(*doc));
     }
