@@ -1,4 +1,4 @@
-// Copyright 2023 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -19,14 +19,16 @@
 #include <mongocxx/config/private/prelude.hh>
 
 namespace mongocxx {
-inline namespace v_noabi {
+namespace v_noabi {
 namespace result {
 
-rewrap_many_datakey::rewrap_many_datakey(mongocxx::result::bulk_write bulk_write_result_doc) {
+rewrap_many_datakey::rewrap_many_datakey(
+    mongocxx::v_noabi::result::bulk_write bulk_write_result_doc) {
     _result = std::move(bulk_write_result_doc);
 }
 
-const bsoncxx::stdx::optional<mongocxx::result::bulk_write>& rewrap_many_datakey::result() {
+const bsoncxx::v_noabi::stdx::optional<mongocxx::v_noabi::result::bulk_write>&
+rewrap_many_datakey::result() {
     return _result;
 }
 
