@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -37,17 +37,17 @@ std::int32_t update::upserted_count() const {
     return _result.upserted_count();
 }
 
-stdx::optional<bsoncxx::v_noabi::document::element> update::upserted_id() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::element> update::upserted_id() const {
     if (_result.upserted_ids().size() == 0) {
-        return stdx::nullopt;
+        return bsoncxx::v_noabi::stdx::nullopt;
     }
     return _result.upserted_ids()[0];
 }
 
-bool MONGOCXX_CALL operator==(const update& lhs, const update& rhs) {
+bool operator==(const update& lhs, const update& rhs) {
     return lhs.result() == rhs.result();
 }
-bool MONGOCXX_CALL operator!=(const update& lhs, const update& rhs) {
+bool operator!=(const update& lhs, const update& rhs) {
     return !(lhs == rhs);
 }
 
