@@ -1,4 +1,5 @@
-#include <bsoncxx/stdx/make_unique.hpp>
+#include <bsoncxx/private/make_unique.hh>
+
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/private/search_index_model.hh>
@@ -10,17 +11,17 @@ namespace mongocxx {
 namespace v_noabi {
 
 search_index_model::search_index_model(bsoncxx::v_noabi::document::view_or_value definition)
-    : _impl{bsoncxx::v_noabi::stdx::make_unique<impl>(definition)} {}
+    : _impl{bsoncxx::make_unique<impl>(definition)} {}
 search_index_model::search_index_model(bsoncxx::v_noabi::string::view_or_value name,
                                        bsoncxx::v_noabi::document::view_or_value definition)
-    : _impl{bsoncxx::v_noabi::stdx::make_unique<impl>(name, definition)} {}
+    : _impl{bsoncxx::make_unique<impl>(name, definition)} {}
 
 search_index_model::search_index_model(search_index_model&&) noexcept = default;
 
 search_index_model& search_index_model::operator=(search_index_model&&) noexcept = default;
 
 search_index_model::search_index_model(const search_index_model& other)
-    : _impl(bsoncxx::v_noabi::stdx::make_unique<impl>(other._get_impl())) {}
+    : _impl(bsoncxx::make_unique<impl>(other._get_impl())) {}
 
 search_index_model& search_index_model::operator=(const search_index_model& other) {
     _get_impl() = other._get_impl();
@@ -38,6 +39,16 @@ bsoncxx::v_noabi::document::view search_index_model::definition() const {
     return _get_impl()._definition.view();
 }
 
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::string::view_or_value> search_index_model::type()
+    const {
+    return _get_impl()._type;
+}
+
+search_index_model& search_index_model::type(bsoncxx::v_noabi::string::view_or_value type) {
+    _get_impl()._type = type;
+    return *this;
+}
+
 const search_index_model::impl& search_index_model::_get_impl() const {
     if (!_impl) {
         throw logic_error{error_code::k_invalid_search_index_model};
