@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,8 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#include <bsoncxx/stdx/make_unique.hpp>
+#include <bsoncxx/private/make_unique.hh>
 #include <bsoncxx/types.hpp>
+
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/private/libmongoc.hh>
@@ -50,7 +51,7 @@ uri::uri(std::unique_ptr<impl>&& implementation) {
 uri::uri(bsoncxx::v_noabi::string::view_or_value uri_string) {
     bson_error_t error;
 
-    _impl = stdx::make_unique<impl>(
+    _impl = bsoncxx::make_unique<impl>(
         libmongoc::uri_new_with_error(uri_string.terminated().data(), &error));
 
     if (_impl->uri_t == nullptr) {
@@ -98,13 +99,13 @@ std::string uri::password() const {
 mongocxx::v_noabi::read_concern uri::read_concern() const {
     auto rc = libmongoc::uri_get_read_concern(_impl->uri_t);
     return mongocxx::v_noabi::read_concern(
-        stdx::make_unique<read_concern::impl>(libmongoc::read_concern_copy(rc)));
+        bsoncxx::make_unique<read_concern::impl>(libmongoc::read_concern_copy(rc)));
 }
 
 mongocxx::v_noabi::read_preference uri::read_preference() const {
     auto rp = libmongoc::uri_get_read_prefs_t(_impl->uri_t);
-    return (mongocxx::v_noabi::read_preference)(
-        stdx::make_unique<read_preference::impl>(libmongoc::read_prefs_copy(rp)));
+    return mongocxx::v_noabi::read_preference(
+        bsoncxx::make_unique<read_preference::impl>(libmongoc::read_prefs_copy(rp)));
 }
 
 std::string uri::replica_set() const {
@@ -130,21 +131,23 @@ std::string uri::username() const {
 mongocxx::v_noabi::write_concern uri::write_concern() const {
     auto wc = libmongoc::uri_get_write_concern(_impl->uri_t);
     return mongocxx::v_noabi::write_concern(
-        stdx::make_unique<write_concern::impl>(libmongoc::write_concern_copy(wc)));
+        bsoncxx::make_unique<write_concern::impl>(libmongoc::write_concern_copy(wc)));
 }
 
-static stdx::optional<stdx::string_view> _string_option(mongoc_uri_t* uri, std::string opt_name) {
+static bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::stdx::string_view> _string_option(
+    mongoc_uri_t* uri, std::string opt_name) {
     const char* value;
 
-    value = libmongoc::uri_get_option_as_utf8(uri, opt_name.c_str(), NULL);
+    value = libmongoc::uri_get_option_as_utf8(uri, opt_name.c_str(), nullptr);
     if (!value) {
         return {};
     }
 
-    return stdx::string_view{value};
+    return bsoncxx::v_noabi::stdx::string_view{value};
 }
 
-static stdx::optional<std::int32_t> _int32_option(mongoc_uri_t* uri, std::string opt_name) {
+static bsoncxx::v_noabi::stdx::optional<std::int32_t> _int32_option(mongoc_uri_t* uri,
+                                                                    std::string opt_name) {
     bson_iter_t iter;
     const bson_t* options_bson = libmongoc::uri_get_options(uri);
 
@@ -155,7 +158,8 @@ static stdx::optional<std::int32_t> _int32_option(mongoc_uri_t* uri, std::string
     return bson_iter_int32(&iter);
 }
 
-static stdx::optional<bool> _bool_option(mongoc_uri_t* uri, std::string opt_name) {
+static bsoncxx::v_noabi::stdx::optional<bool> _bool_option(mongoc_uri_t* uri,
+                                                           std::string opt_name) {
     bson_iter_t iter;
     const bson_t* options_bson = libmongoc::uri_get_options(uri);
 
@@ -166,19 +170,19 @@ static stdx::optional<bool> _bool_option(mongoc_uri_t* uri, std::string opt_name
     return bson_iter_bool(&iter);
 }
 
-stdx::optional<bsoncxx::v_noabi::document::view> uri::credentials() {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view> uri::credentials() {
     const bson_t* options_bson = libmongoc::uri_get_credentials(_impl->uri_t);
     const uint8_t* data = bson_get_data(options_bson);
 
     return bsoncxx::v_noabi::document::view(data, options_bson->len);
 }
 
-stdx::optional<std::int32_t> uri::srv_max_hosts() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> uri::srv_max_hosts() const {
     return _int32_option(_impl->uri_t, MONGOC_URI_SRVMAXHOSTS);
 }
 
-static stdx::optional<bsoncxx::v_noabi::document::view> _credential_document_option(
-    mongoc_uri_t* uri, std::string opt_name) {
+static bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view>
+_credential_document_option(mongoc_uri_t* uri, std::string opt_name) {
     bson_iter_t iter;
     const uint8_t* data;
     uint32_t len;
@@ -192,18 +196,19 @@ static stdx::optional<bsoncxx::v_noabi::document::view> _credential_document_opt
     return bsoncxx::v_noabi::document::view(data, len);
 }
 
-stdx::optional<stdx::string_view> uri::appname() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::stdx::string_view> uri::appname() const {
     return _string_option(_impl->uri_t, "appname");
 }
 
 // Special case. authMechanismProperties are stored as part of libmongoc's credentials.
-stdx::optional<bsoncxx::v_noabi::document::view> uri::auth_mechanism_properties() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::document::view> uri::auth_mechanism_properties()
+    const {
     return _credential_document_option(_impl->uri_t, "authMechanismProperties");
 }
 
-std::vector<stdx::string_view> uri::compressors() const {
+std::vector<bsoncxx::v_noabi::stdx::string_view> uri::compressors() const {
     const bson_t* compressors;
-    std::vector<stdx::string_view> result;
+    std::vector<bsoncxx::v_noabi::stdx::string_view> result;
     bson_iter_t iter;
 
     compressors = libmongoc::uri_get_compressors(_impl->uri_t);
@@ -214,88 +219,91 @@ std::vector<stdx::string_view> uri::compressors() const {
     }
     bson_iter_init(&iter, compressors);
     while (bson_iter_next(&iter)) {
-        result.push_back(stdx::string_view{bson_iter_key(&iter), bson_iter_key_len(&iter)});
+        result.push_back(
+            bsoncxx::v_noabi::stdx::string_view{bson_iter_key(&iter), bson_iter_key_len(&iter)});
     }
     return result;
 }
 
-stdx::optional<std::int32_t> uri::connect_timeout_ms() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> uri::connect_timeout_ms() const {
     return _int32_option(_impl->uri_t, "connectTimeoutMS");
 }
 
-stdx::optional<bool> uri::direct_connection() const {
+bsoncxx::v_noabi::stdx::optional<bool> uri::direct_connection() const {
     return _bool_option(_impl->uri_t, "directConnection");
 }
 
-stdx::optional<std::int32_t> uri::heartbeat_frequency_ms() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> uri::heartbeat_frequency_ms() const {
     return _int32_option(_impl->uri_t, "heartbeatFrequencyMS");
 }
 
-stdx::optional<std::int32_t> uri::local_threshold_ms() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> uri::local_threshold_ms() const {
     return _int32_option(_impl->uri_t, "localThresholdMS");
 }
 
-stdx::optional<std::int32_t> uri::max_pool_size() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> uri::max_pool_size() const {
     return _int32_option(_impl->uri_t, "maxPoolSize");
 }
 
-stdx::optional<bool> uri::retry_reads() const {
+bsoncxx::v_noabi::stdx::optional<bool> uri::retry_reads() const {
     return _bool_option(_impl->uri_t, "retryReads");
 }
 
-stdx::optional<bool> uri::retry_writes() const {
+bsoncxx::v_noabi::stdx::optional<bool> uri::retry_writes() const {
     return _bool_option(_impl->uri_t, "retryWrites");
 }
 
-stdx::optional<std::int32_t> uri::server_selection_timeout_ms() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> uri::server_selection_timeout_ms() const {
     return _int32_option(_impl->uri_t, "serverSelectionTimeoutMS");
 }
 
-stdx::optional<bool> uri::server_selection_try_once() const {
+bsoncxx::v_noabi::stdx::optional<bool> uri::server_selection_try_once() const {
     return _bool_option(_impl->uri_t, "serverSelectionTryOnce");
 }
 
-stdx::optional<std::int32_t> uri::socket_timeout_ms() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> uri::socket_timeout_ms() const {
     return _int32_option(_impl->uri_t, "socketTimeoutMS");
 }
 
-stdx::optional<bool> uri::tls_allow_invalid_certificates() const {
+bsoncxx::v_noabi::stdx::optional<bool> uri::tls_allow_invalid_certificates() const {
     return _bool_option(_impl->uri_t, "tlsAllowInvalidCertificates");
 }
 
-stdx::optional<bool> uri::tls_allow_invalid_hostnames() const {
+bsoncxx::v_noabi::stdx::optional<bool> uri::tls_allow_invalid_hostnames() const {
     return _bool_option(_impl->uri_t, "tlsAllowInvalidHostnames");
 }
 
-stdx::optional<stdx::string_view> uri::tls_ca_file() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::stdx::string_view> uri::tls_ca_file() const {
     return _string_option(_impl->uri_t, "tlsCAFile");
 }
 
-stdx::optional<stdx::string_view> uri::tls_certificate_key_file() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::stdx::string_view>
+uri::tls_certificate_key_file() const {
     return _string_option(_impl->uri_t, "tlsCertificateKeyFile");
 }
 
-stdx::optional<stdx::string_view> uri::tls_certificate_key_file_password() const {
+bsoncxx::v_noabi::stdx::optional<bsoncxx::v_noabi::stdx::string_view>
+uri::tls_certificate_key_file_password() const {
     return _string_option(_impl->uri_t, "tlsCertificateKeyFilePassword");
 }
 
-stdx::optional<bool> uri::tls_disable_certificate_revocation_check() const {
+bsoncxx::v_noabi::stdx::optional<bool> uri::tls_disable_certificate_revocation_check() const {
     return _bool_option(_impl->uri_t, "tlsDisableCertificateRevocationCheck");
 }
 
-stdx::optional<bool> uri::tls_disable_ocsp_endpoint_check() const {
+bsoncxx::v_noabi::stdx::optional<bool> uri::tls_disable_ocsp_endpoint_check() const {
     return _bool_option(_impl->uri_t, "tlsDisableOCSPEndpointCheck");
 }
 
-stdx::optional<bool> uri::tls_insecure() const {
+bsoncxx::v_noabi::stdx::optional<bool> uri::tls_insecure() const {
     return _bool_option(_impl->uri_t, "tlsInsecure");
 }
 
-stdx::optional<std::int32_t> uri::wait_queue_timeout_ms() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> uri::wait_queue_timeout_ms() const {
     return _int32_option(_impl->uri_t, "waitQueueTimeoutMS");
 }
 
-stdx::optional<std::int32_t> uri::zlib_compression_level() const {
+bsoncxx::v_noabi::stdx::optional<std::int32_t> uri::zlib_compression_level() const {
     return _int32_option(_impl->uri_t, "zlibCompressionLevel");
 }
 
