@@ -1,4 +1,4 @@
-// Copyright 2016 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -30,16 +30,21 @@
 #include <bsoncxx/string/to_string.hpp>
 #include <bsoncxx/types.hpp>
 #include <bsoncxx/types/bson_value/view_or_value.hpp>
+
 #include <mongocxx/client.hpp>
 #include <mongocxx/exception/error_code.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/exception/operation_exception.hpp>
 #include <mongocxx/private/libmongoc.hh>
-#include <mongocxx/test/client_helpers.hh>
-#include <third_party/catch/include/catch.hpp>
+
+#include <bsoncxx/config/prelude.hpp>
 
 #include <mongocxx/config/private/prelude.hh>
 
+#include <bsoncxx/test/catch.hh>
+
+#include <mongocxx/test/client_helpers.hh>
+
 namespace mongocxx {
 namespace test_util {
 
@@ -62,9 +67,9 @@ document::value get_server_status(const client& client) {
     return status;
 }
 
-stdx::optional<document::value> get_shards(const client& client) {
+bsoncxx::stdx::optional<document::value> get_shards(const client& client) {
     static auto shards = client["config"]["shards"].find_one({});
-    return (shards) ? shards.value() : stdx::optional<document::value>{};
+    return (shards) ? shards.value() : bsoncxx::stdx::optional<document::value>{};
 }
 }  // namespace
 
@@ -91,7 +96,7 @@ bsoncxx::array::value transform_array(bsoncxx::array::view view,
 
     for (auto&& element : view) {
         // Array elements are passed with disengaged key.
-        auto transformed = fcn({stdx::nullopt, element.get_value()}, context);
+        auto transformed = fcn({bsoncxx::stdx::nullopt, element.get_value()}, context);
 
         // Omit element if transformed is disengaged.
         if (!transformed) {
@@ -111,6 +116,25 @@ bsoncxx::array::value transform_array(bsoncxx::array::view view,
                 builder.append(transform_array(v.get_array().value, fcn, context));
                 break;
 
+            case bsoncxx::type::k_double:
+            case bsoncxx::type::k_string:
+            case bsoncxx::type::k_binary:
+            case bsoncxx::type::k_undefined:
+            case bsoncxx::type::k_oid:
+            case bsoncxx::type::k_bool:
+            case bsoncxx::type::k_date:
+            case bsoncxx::type::k_null:
+            case bsoncxx::type::k_regex:
+            case bsoncxx::type::k_dbpointer:
+            case bsoncxx::type::k_code:
+            case bsoncxx::type::k_symbol:
+            case bsoncxx::type::k_codewscope:
+            case bsoncxx::type::k_int32:
+            case bsoncxx::type::k_timestamp:
+            case bsoncxx::type::k_int64:
+            case bsoncxx::type::k_decimal128:
+            case bsoncxx::type::k_maxkey:
+            case bsoncxx::type::k_minkey:
             default:
                 builder.append(v);
                 break;
@@ -154,6 +178,25 @@ bsoncxx::document::value transform_document_recursive(bsoncxx::document::view vi
                     k, transform_array(v.get_array().value, fcn, context)));
                 break;
 
+            case bsoncxx::type::k_double:
+            case bsoncxx::type::k_string:
+            case bsoncxx::type::k_binary:
+            case bsoncxx::type::k_undefined:
+            case bsoncxx::type::k_oid:
+            case bsoncxx::type::k_bool:
+            case bsoncxx::type::k_date:
+            case bsoncxx::type::k_null:
+            case bsoncxx::type::k_regex:
+            case bsoncxx::type::k_dbpointer:
+            case bsoncxx::type::k_code:
+            case bsoncxx::type::k_symbol:
+            case bsoncxx::type::k_codewscope:
+            case bsoncxx::type::k_int32:
+            case bsoncxx::type::k_timestamp:
+            case bsoncxx::type::k_int64:
+            case bsoncxx::type::k_decimal128:
+            case bsoncxx::type::k_maxkey:
+            case bsoncxx::type::k_minkey:
             default:
                 builder.append(bsoncxx::builder::basic::kvp(k, v));
                 break;
@@ -185,12 +228,12 @@ bool newer_than(const client& client, std::string version) {
     return (compare_versions(server_version, version) >= 0);
 }
 
-std::basic_string<std::uint8_t> convert_hex_string_to_bytes(stdx::string_view hex) {
+std::basic_string<std::uint8_t> convert_hex_string_to_bytes(bsoncxx::stdx::string_view hex) {
     std::basic_string<std::uint8_t> bytes;
 
     // Convert each pair of hexadecimal digits into a number and store it in the array.
     for (std::size_t i = 0; i < hex.size(); i += 2) {
-        stdx::string_view sub = hex.substr(i, 2);
+        bsoncxx::stdx::string_view sub = hex.substr(i, 2);
         bytes.push_back(
             static_cast<std::uint8_t>(std::stoi(bsoncxx::string::to_string(sub), nullptr, 16)));
     }
@@ -257,7 +300,7 @@ static bool is_sharded_cluster(document::view reply) {
         return false;
     }
 
-    return msg.get_string().value.compare("isdbgrid") == 0;
+    return msg.get_string().value == "isdbgrid";
 }
 
 bool is_sharded_cluster(const client& client) {
@@ -285,7 +328,7 @@ std::string get_topology(const client& client) {
     return "single";
 }
 
-stdx::optional<bsoncxx::document::value> parse_test_file(std::string path) {
+bsoncxx::stdx::optional<bsoncxx::document::value> parse_test_file(std::string path) {
     std::stringstream stream;
     std::ifstream test_file{path};
 
@@ -297,10 +340,6 @@ stdx::optional<bsoncxx::document::value> parse_test_file(std::string path) {
     return bsoncxx::from_json(stream.str());
 }
 
-bool supports_collation(const client& client) {
-    return get_max_wire_version(client) >= 5;
-}
-
 bsoncxx::document::value transform_document(bsoncxx::document::view view, const xformer_t& fcn) {
     bsoncxx::builder::basic::array context;
 
@@ -327,12 +366,12 @@ bool is_numeric(types::bson_value::view value) {
            value.type() == type::k_double;
 }
 
-stdx::optional<type> is_type_operator(types::bson_value::view value) {
+static bsoncxx::stdx::optional<type> is_type_operator(types::bson_value::view value) {
     if (value.type() == type::k_document && value.get_document().value["$$type"]) {
         auto t = value.get_document().value["$$type"].get_string().value;
-        if (t.compare("binData") == 0) {
+        if (t == "binData") {
             return {type::k_binary};
-        } else if (t.compare("long") == 0) {
+        } else if (t == "long") {
             return {type::k_int64};
         }
         throw std::logic_error{"unsupported type for $$type"};
@@ -347,7 +386,10 @@ bool matches(types::bson_value::view main,
         return t == main.type();
     }
 
-    if (is_numeric(pattern) && as_double(pattern) == 42) {
+    BSONCXX_PUSH_WARNINGS();
+    BSONCXX_DISABLE_WARNING(GNU("-Wfloat-equal"));
+
+    if (is_numeric(pattern) && as_double(pattern) == 42.0) {
         return true;
     }
 
@@ -356,9 +398,11 @@ bool matches(types::bson_value::view main,
         return true;
     }
 
+    BSONCXX_POP_WARNINGS();
+
     if (main.type() == type::k_document) {
         // the value '42' acts as placeholders for "any value"
-        if (pattern.type() == type::k_string && 0 == pattern.get_string().value.compare("42")) {
+        if (pattern.type() == type::k_string && pattern.get_string().value == "42") {
             return true;
         }
 
@@ -366,7 +410,7 @@ bool matches(types::bson_value::view main,
         for (auto&& el : pattern.get_document().value) {
             match_action action = match_action::k_proceed;
             if (visitor_fn) {
-                stdx::optional<types::bson_value::view> main_value;
+                bsoncxx::stdx::optional<types::bson_value::view> main_value;
                 if (main_view.find(el.key()) != main_view.end()) {
                     main_value = main_view[el.key()].get_value();
                 }
@@ -382,14 +426,14 @@ bool matches(types::bson_value::view main,
             }
 
             // For write errors, only check for existence.
-            if (el.key().compare("writeErrors") == 0) {
+            if (el.key() == "writeErrors") {
                 if (main_view.find(el.key()) == main_view.end()) {
                     return false;
                 }
                 continue;
             }
             // The C++ driver does not include insertedIds as part of the bulk write result.
-            if (el.key().compare("insertedIds") == 0) {
+            if (el.key() == "insertedIds") {
                 if (main_view.find(el.key()) == main_view.end()) {
                     return false;
                 }
@@ -432,7 +476,7 @@ bool matches(document::view doc, document::view pattern, match_visitor visitor_f
                    visitor_fn);
 }
 
-std::string tolowercase(stdx::string_view view) {
+std::string tolowercase(bsoncxx::stdx::string_view view) {
     std::string out;
     out.reserve(view.size());
     for (size_t i = 0; i < view.length(); i++) {
@@ -489,7 +533,7 @@ void check_outcome_collection(mongocxx::collection* coll, bsoncxx::document::vie
     REQUIRE(begin(actual) == end(actual));
 }
 
-bool server_has_sessions(const client& conn) {
+bool server_has_sessions_impl(const client& conn) {
     auto result = get_is_master(conn);
     auto result_view = result.view();
 
@@ -497,51 +541,45 @@ bool server_has_sessions(const client& conn) {
         return true;
     }
 
-    WARN("skip: server does not support sessions");
     return false;
 }
 
-bool should_run_client_side_encryption_test(void) {
-#ifndef MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION
-    WARN("linked libmongoc does not support client side encryption - skipping tests");
-    return false;
-#endif
+#if defined(MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION)
 
-    std::vector<const char*> vars{
-        "MONGOCXX_TEST_AWS_SECRET_ACCESS_KEY",
-        "MONGOCXX_TEST_AWS_ACCESS_KEY_ID",
-        "MONGOCXX_TEST_AZURE_TENANT_ID",
-        "MONGOCXX_TEST_AZURE_CLIENT_ID",
-        "MONGOCXX_TEST_AZURE_CLIENT_SECRET",
-        "MONGOCXX_TEST_CSFLE_TLS_CA_FILE",
-        "MONGOCXX_TEST_CSFLE_TLS_CERTIFICATE_KEY_FILE",
-        "MONGOCXX_TEST_GCP_EMAIL",
-        "MONGOCXX_TEST_GCP_PRIVATEKEY",
-    };
+cseeos_result client_side_encryption_enabled_or_skip_impl() {
+    static const cseeos_result result = [] {
+        std::vector<const char*> vars{
+            "MONGOCXX_TEST_AWS_SECRET_ACCESS_KEY",
+            "MONGOCXX_TEST_AWS_ACCESS_KEY_ID",
+            "MONGOCXX_TEST_AZURE_TENANT_ID",
+            "MONGOCXX_TEST_AZURE_CLIENT_ID",
+            "MONGOCXX_TEST_AZURE_CLIENT_SECRET",
+            "MONGOCXX_TEST_CSFLE_TLS_CA_FILE",
+            "MONGOCXX_TEST_CSFLE_TLS_CERTIFICATE_KEY_FILE",
+            "MONGOCXX_TEST_GCP_EMAIL",
+            "MONGOCXX_TEST_GCP_PRIVATEKEY",
+        };
 
-    std::ostringstream os;
-    os << "Please set environment variables to enable client side encryption tests:\n";
-    std::copy(std::begin(vars), std::end(vars), std::ostream_iterator<const char*>(os, "\n"));
+        const auto is_set = [](const char* var) -> bool { return std::getenv(var) != nullptr; };
 
-    if (std::none_of(std::begin(vars), std::end(vars), std::getenv)) {
-        os << "Skipping client side encryption tests.\n";
+        const auto count = std::count_if(vars.begin(), vars.end(), is_set);
 
-        WARN(os.str());
+        if (count == 0) {
+            return cseeos_result::skip;
+        }
 
-        return false;
-    }
+        if (static_cast<std::size_t>(count) < vars.size()) {
+            return cseeos_result::fail;
+        }
 
-    if (!std::all_of(std::begin(vars), std::end(vars), std::getenv)) {
-        os << "Failing client side encryption tests (some environment variables were not set).\n";
+        return cseeos_result::enable;
+    }();
 
-        FAIL(os.str());
-
-        return false;
-    }
-
-    return true;
+    return result;
 }
 
+#endif  // defined(MONGOC_ENABLE_CLIENT_SIDE_ENCRYPTION)
+
 std::string getenv_or_fail(const std::string env_name) {
     auto val = std::getenv(env_name.c_str());
     if (!val) {
