@@ -1,4 +1,4 @@
-// Copyright 2014 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -21,7 +21,7 @@
 #include <bsoncxx/private/helpers.hh>
 #include <bsoncxx/private/libbson.hh>
 #include <bsoncxx/stdx/optional.hpp>
-#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/client.hpp>
 #include <mongocxx/collection.hpp>
 #include <mongocxx/database.hpp>
@@ -34,7 +34,10 @@
 #include <mongocxx/private/libbson.hh>
 #include <mongocxx/private/libmongoc.hh>
 #include <mongocxx/read_preference.hpp>
-#include <third_party/catch/include/helpers.hpp>
+
+#include <bsoncxx/test/catch.hh>
+
+#include <mongocxx/test/catch_helpers.hh>
 
 namespace {
 using namespace mongocxx;
@@ -57,12 +60,12 @@ TEST_CASE("Collection", "[collection]") {
     const std::string collection_name("dummy_collection");
     const std::string database_name("mocked_collection");
 
-    MOCK_CLIENT
-    MOCK_DATABASE
-    MOCK_COLLECTION
-    MOCK_FAM
-    MOCK_BULK
-    MOCK_CURSOR
+    MOCK_CLIENT;
+    MOCK_DATABASE;
+    MOCK_COLLECTION;
+    MOCK_FAM;
+    MOCK_BULK;
+    MOCK_CURSOR;
 
     client mongo_client{uri{}};
     write_concern concern;
@@ -213,7 +216,7 @@ TEST_CASE("Collection", "[collection]") {
                     REQUIRE(o.find("writeConcern") == o.end());
                 }
 
-                return NULL;
+                return nullptr;
             });
 
         pipe.match(make_document(kvp("foo", "bar")));
@@ -268,7 +271,7 @@ TEST_CASE("Collection", "[collection]") {
             if (expected_opts) {
                 bson_t opts_without_skip_or_limit = BSON_INITIALIZER;
                 bson_copy_to_excluding_noinit(
-                    opts, &opts_without_skip_or_limit, "skip", "limit", NULL);
+                    opts, &opts_without_skip_or_limit, "skip", "limit", nullptr);
                 REQUIRE(bson_equal(&opts_without_skip_or_limit, expected_opts));
                 bson_destroy(&opts_without_skip_or_limit);
             }
@@ -391,13 +394,13 @@ TEST_CASE("Collection", "[collection]") {
         auto collection_find_called = false;
         auto find_doc = make_document(kvp("a", 1));
         auto doc = find_doc.view();
-        mongocxx::stdx::optional<bool> expected_allow_partial_results;
-        mongocxx::stdx::optional<bsoncxx::stdx::string_view> expected_comment{};
-        mongocxx::stdx::optional<mongocxx::cursor::type> expected_cursor_type{};
-        mongocxx::stdx::optional<bsoncxx::types::bson_value::view> expected_hint{};
-        mongocxx::stdx::optional<bool> expected_no_cursor_timeout;
-        mongocxx::stdx::optional<bsoncxx::document::view> expected_sort{};
-        mongocxx::stdx::optional<read_preference> expected_read_preference{};
+        bsoncxx::stdx::optional<bool> expected_allow_partial_results;
+        bsoncxx::stdx::optional<bsoncxx::stdx::string_view> expected_comment{};
+        bsoncxx::stdx::optional<mongocxx::cursor::type> expected_cursor_type{};
+        bsoncxx::stdx::optional<bsoncxx::types::bson_value::view> expected_hint{};
+        bsoncxx::stdx::optional<bool> expected_no_cursor_timeout;
+        bsoncxx::stdx::optional<bsoncxx::document::view> expected_sort{};
+        bsoncxx::stdx::optional<read_preference> expected_read_preference{};
 
         collection_find_with_opts->interpose([&](mongoc_collection_t*,
                                                  const bson_t* filter,
@@ -454,7 +457,7 @@ TEST_CASE("Collection", "[collection]") {
                         libmongoc::conversions::read_mode_t_from_read_mode(
                             mongo_coll.read_preference().mode()));
 
-            mongoc_cursor_t* cursor = NULL;
+            mongoc_cursor_t* cursor = nullptr;
             return cursor;
         });
 
@@ -533,7 +536,7 @@ TEST_CASE("Collection", "[collection]") {
         auto expected_order_setting = false;
         auto expect_set_bypass_document_validation_called = false;
         auto expected_bypass_document_validation = false;
-        mongocxx::stdx::optional<bsoncxx::types::bson_value::view> expected_hint{};
+        bsoncxx::stdx::optional<bsoncxx::types::bson_value::view> expected_hint{};
 
         auto modification_doc = make_document(kvp("cool", "wow"), kvp("foo", "bar"));
 
