@@ -1,4 +1,4 @@
-// Copyright 2014-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/string/to_string.hpp>
-#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/client.hpp>
 #include <mongocxx/database.hpp>
 #include <mongocxx/exception/logic_error.hpp>
@@ -27,8 +27,13 @@
 #include <mongocxx/private/conversions.hh>
 #include <mongocxx/private/libbson.hh>
 #include <mongocxx/private/libmongoc.hh>
+
+#include <bsoncxx/test/catch.hh>
+
+#include <mongocxx/test/catch_helpers.hh>
 #include <mongocxx/test/client_helpers.hh>
-#include <third_party/catch/include/helpers.hpp>
+
+#include <catch2/generators/catch_generators.hpp>
 
 namespace {
 using namespace mongocxx;
@@ -36,7 +41,6 @@ using namespace mongocxx;
 using bsoncxx::builder::basic::kvp;
 using bsoncxx::builder::basic::make_array;
 using bsoncxx::builder::basic::make_document;
-using test_util::server_has_sessions;
 
 bool check_for_collections(cursor cursor, std::set<std::string> expected_colls) {
     for (auto&& coll : cursor) {
@@ -80,7 +84,7 @@ TEST_CASE("mongocxx::database copy constructor", "[database]") {
         database database_a = client["a"];
         database database_b{database_a};
         REQUIRE(database_b);
-        REQUIRE(database_b.name() == stdx::string_view{"a"});
+        REQUIRE(database_b.name() == bsoncxx::stdx::string_view{"a"});
     }
 
     SECTION("constructing from invalid") {
@@ -100,7 +104,7 @@ TEST_CASE("mongocxx::database copy assignment operator", "[database]") {
         database database_b = client["b1"];
         database_b = database_a;
         REQUIRE(database_b);
-        REQUIRE(database_b.name() == stdx::string_view{"a1"});
+        REQUIRE(database_b.name() == bsoncxx::stdx::string_view{"a1"});
     }
 
     SECTION("assigning invalid to valid") {
@@ -115,7 +119,7 @@ TEST_CASE("mongocxx::database copy assignment operator", "[database]") {
         database database_b;
         database_b = database_a;
         REQUIRE(database_b);
-        REQUIRE(database_b.name() == stdx::string_view{"a3"});
+        REQUIRE(database_b.name() == bsoncxx::stdx::string_view{"a3"});
     }
 
     SECTION("assigning invalid to invalid") {
@@ -127,9 +131,9 @@ TEST_CASE("mongocxx::database copy assignment operator", "[database]") {
 }
 
 TEST_CASE("A database", "[database]") {
-    stdx::string_view database_name{"database"};
-    MOCK_CLIENT
-    MOCK_DATABASE
+    bsoncxx::stdx::string_view database_name{"database"};
+    MOCK_CLIENT;
+    MOCK_DATABASE;
 
     instance::current();
 
@@ -139,7 +143,7 @@ TEST_CASE("A database", "[database]") {
         bool called = false;
         get_database->interpose([&](mongoc_client_t*, const char* d_name) {
             called = true;
-            REQUIRE(database_name == stdx::string_view{d_name});
+            REQUIRE(database_name == bsoncxx::stdx::string_view{d_name});
             return nullptr;
         });
 
@@ -180,7 +184,6 @@ TEST_CASE("A database", "[database]") {
         database_destroy->interpose([&](mongoc_database_t*) { destroy_called = true; });
 
         {
-            client mongo_client{uri{}, test_util::add_test_server_api()};
             database a = mongo_client[database_name];
 
             database b{std::move(a)};
@@ -286,8 +289,8 @@ TEST_CASE("A database", "[database]") {
     }
 
     SECTION("may create a collection") {
-        MOCK_COLLECTION
-        stdx::string_view collection_name{"dummy_collection"};
+        MOCK_COLLECTION;
+        bsoncxx::stdx::string_view collection_name{"dummy_collection"};
         database database = mongo_client[database_name];
         collection obtained_collection = database[collection_name];
         REQUIRE(obtained_collection.name() == collection_name);
@@ -322,7 +325,7 @@ TEST_CASE("Database integration tests", "[database]") {
     instance::current();
 
     client mongo_client{uri{}, test_util::add_test_server_api()};
-    stdx::string_view database_name{"database"};
+    bsoncxx::stdx::string_view database_name{"database"};
     database database = mongo_client[database_name];
 
     auto case_insensitive_collation = make_document(kvp("locale", "en_US"), kvp("strength", 2));
@@ -340,12 +343,10 @@ TEST_CASE("Database integration tests", "[database]") {
         };
 
         SECTION("listLocalSessions") {
-            if (!server_has_sessions(mongo_client)) {
-                return;
-            }
+            SERVER_HAS_SESSIONS_OR_SKIP(mongo_client);
 
-            // SERVER-79306: $listLocalSessions does not behave as expect if the database does not
-            // already exist on sharded clusters.
+            // SERVER-79306: Ensure the database exists for consistent behavior with sharded
+            // clusters.
             database.create_collection("dummy");
 
             auto session1 = mongo_client.start_session();
@@ -359,12 +360,13 @@ TEST_CASE("Database integration tests", "[database]") {
             auto results = get_results(std::move(cursor));
 
             REQUIRE(results.size() == 1);
-            REQUIRE(results[0].view()["name"].get_string().value == stdx::string_view("Jane"));
+            REQUIRE(results[0].view()["name"].get_string().value ==
+                    bsoncxx::stdx::string_view("Jane"));
         }
     }
 
     SECTION("A database may create a collection via create_collection") {
-        stdx::string_view collection_name{"collection_create_with_opts"};
+        bsoncxx::stdx::string_view collection_name{"collection_create_with_opts"};
 
         SECTION("without any options") {
             database[collection_name].drop();
@@ -388,23 +390,6 @@ TEST_CASE("Database integration tests", "[database]") {
             obtained_collection.drop();
         }
 
-        SECTION("with deprecated options") {
-            database[collection_name].drop();
-
-            options::create_collection_deprecated opts;
-            opts.capped(true);
-            opts.size(256);
-            opts.max(100);
-            opts.no_padding(false);
-
-            BSONCXX_SUPPRESS_DEPRECATION_WARNINGS_BEGIN
-            collection obtained_collection = database.create_collection(collection_name, opts);
-            BSONCXX_SUPPRESS_DEPRECATION_WARNINGS_END
-
-            REQUIRE(obtained_collection.name() == collection_name);
-            obtained_collection.drop();
-        }
-
         SECTION("verify that collection is created server side") {
             database[collection_name].drop();
 
@@ -424,7 +409,7 @@ TEST_CASE("Database integration tests", "[database]") {
     }
 
     SECTION("A database may be dropped") {
-        stdx::string_view collection_name{"collection_drop"};
+        bsoncxx::stdx::string_view collection_name{"collection_drop"};
         database[collection_name].drop();
 
         database.create_collection(collection_name);
@@ -457,7 +442,7 @@ TEST_CASE("Database integration tests", "[database]") {
     }
 
     SECTION("list_collections returns a correct result") {
-        class database db = mongo_client["list_collections"];
+        mongocxx::database db = mongo_client["list_collections"];
         db.drop();
 
         collection default_collection = db.create_collection("list_collections_default");
@@ -484,7 +469,7 @@ TEST_CASE("Database integration tests", "[database]") {
     }
 
     SECTION("list_collection_names returns a correct result") {
-        class database db = mongo_client["list_collection_names"];
+        mongocxx::database db = mongo_client["list_collection_names"];
         db.drop();
 
         std::set<std::string> expected_colls;
@@ -515,7 +500,7 @@ struct check_service_id {
     check_service_id(const bool expect_service_id) : expect_service_id(expect_service_id) {}
 
     void operator()(const EventT& event) {
-        INFO("checking for service_id()")
+        INFO("checking for service_id()");
         CAPTURE(event.command_name(), expect_service_id);
 
         auto service_id = event.service_id();
@@ -580,7 +565,7 @@ TEST_CASE("serviceId presence depends on load-balancing mode") {
     // Adding ?loadBalanced=true results in an error in the C driver because
     // the initial hello response from the server does not include serviceId.
     client mongo_client(uri("mongodb://localhost:27017/"), client_opts);
-    stdx::string_view database_name{"database"};
+    bsoncxx::stdx::string_view database_name{"database"};
     database database = mongo_client[database_name];
 
     // Run a command, triggering start and completion events:
