@@ -1,4 +1,4 @@
-// Copyright 2015 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,12 +14,14 @@
 
 #include <vector>
 
-#include <bsoncxx/stdx/make_unique.hpp>
-#include <bsoncxx/test/catch.hh>
+#include <bsoncxx/private/make_unique.hh>
+
 #include <mongocxx/instance.hpp>
 #include <mongocxx/logger.hpp>
 #include <mongocxx/private/libmongoc.hh>
 
+#include <bsoncxx/test/catch.hh>
+
 namespace {
 using namespace mongocxx;
 
@@ -30,8 +32,8 @@ class test_log_handler : public logger {
     test_log_handler(std::vector<event>* events) : _events(events) {}
 
     void operator()(log_level level,
-                    stdx::string_view domain,
-                    stdx::string_view message) noexcept final {
+                    bsoncxx::stdx::string_view domain,
+                    bsoncxx::stdx::string_view message) noexcept final {
         if (level == log_level::k_error)
             _events->emplace_back(level, std::string(domain), std::string(message));
     }
@@ -51,7 +53,7 @@ TEST_CASE("a user-provided log handler will be used for logging output", "[insta
     reset_log_handler_when_done rlhwd;
 
     std::vector<test_log_handler::event> events;
-    mongocxx::instance driver{stdx::make_unique<test_log_handler>(&events)};
+    mongocxx::instance driver{bsoncxx::make_unique<test_log_handler>(&events)};
 
     REQUIRE(&mongocxx::instance::current() == &driver);
 
