@@ -1,4 +1,4 @@
-// Copyright 2017 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -16,12 +16,14 @@
 #include <bsoncxx/builder/basic/kvp.hpp>
 #include <bsoncxx/oid.hpp>
 #include <bsoncxx/stdx/string_view.hpp>
-#include <bsoncxx/test/catch.hh>
 #include <bsoncxx/types.hpp>
 #include <bsoncxx/types/bson_value/view.hpp>
+
 #include <mongocxx/instance.hpp>
 #include <mongocxx/result/gridfs/upload.hpp>
 
+#include <bsoncxx/test/catch.hh>
+
 namespace {
 using namespace bsoncxx;
 using namespace mongocxx;
@@ -57,7 +59,7 @@ TEST_CASE("result::gridfs::upload owns id", "[result::gridfs::upload]") {
 
     // Because result::gridfs::upload owns its id, we should still be able to correctly read new
     // value for the id.
-    REQUIRE(res.id().get_string().value == stdx::string_view(bar));
+    REQUIRE(res.id().get_string().value == bsoncxx::stdx::string_view(bar));
 }
 
 TEST_CASE("result::gridfs::upload equals", "[result::gridfs::upload]") {
