@@ -1,4 +1,4 @@
-// Copyright 2018-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,14 +17,17 @@
 
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/json.hpp>
-#include <bsoncxx/test/to_string.hh>
+
 #include <mongocxx/exception/error_code.hpp>
+
+#include <mongocxx/config/private/prelude.hh>
+
+#include <bsoncxx/test/catch.hh>
+#include <bsoncxx/test/to_string.hh>
+
 #include <mongocxx/test/client_helpers.hh>
 #include <mongocxx/test/spec/monitoring.hh>
 #include <mongocxx/test/spec/unified_tests/assert.hh>
-#include <third_party/catch/include/catch.hpp>
-
-#include <mongocxx/config/private/prelude.hh>
 
 namespace mongocxx {
 namespace spec {
@@ -32,14 +35,15 @@ namespace spec {
 using namespace mongocxx;
 using bsoncxx::to_json;
 
-void remove_ignored_command_monitoring_events(apm_checker::event_vector& events,
-                                              const std::vector<std::string>& ignore) {
+static void remove_ignored_command_monitoring_events(apm_checker::event_vector& events,
+                                                     const std::vector<std::string>& ignore) {
     auto is_ignored = [&](bsoncxx::document::value v) {
-        return std::any_of(std::begin(ignore), std::end(ignore), [&](stdx::string_view key) {
-            return v.view()["commandStartedEvent"]["command"][key] ||
-                   v.view()["commandFailedEvent"]["command"][key] ||
-                   v.view()["commandSucceededEvent"]["command"][key];
-        });
+        return std::any_of(
+            std::begin(ignore), std::end(ignore), [&](bsoncxx::stdx::string_view key) {
+                return v.view()["commandStartedEvent"]["command"][key] ||
+                       v.view()["commandFailedEvent"]["command"][key] ||
+                       v.view()["commandSucceededEvent"]["command"][key];
+            });
     };
 
     events.erase(std::remove_if(events.begin(), events.end(), is_ignored), std::end(events));
@@ -59,7 +63,8 @@ void apm_checker::compare_unified(bsoncxx::array::view expectations,
 
         // Extra fields are only allowed in root-level documents. Here, each k in keys is treated
         // as its own root-level document, allowing extra fields.
-        auto match_events = [&](stdx::string_view event, std::initializer_list<std::string> keys) {
+        auto match_events = [&](bsoncxx::stdx::string_view event,
+                                std::initializer_list<std::string> keys) {
             for (auto&& k : keys)
                 if (exp[event][k])
                     assert::matches(actual[event][k].get_value(), exp[event][k].get_value(), map);
@@ -102,16 +107,17 @@ void apm_checker::compare(bsoncxx::array::view expectations,
         if (view["command_started_event"]["command"]["listCollections"]) {
             const auto db = view["command_started_event"]["command"]["$db"];
 
-            if (db && db.get_string().value == stdx::string_view("keyvault")) {
+            if (db && db.get_string().value == bsoncxx::stdx::string_view("keyvault")) {
                 return true;
             }
         }
 
-        return std::any_of(std::begin(_ignore), std::end(_ignore), [&](stdx::string_view key) {
-            return view["command_started_event"]["command"][key] ||
-                   view["command_failed_event"]["command"][key] ||
-                   view["command_succeeded_event"]["command"][key];
-        });
+        return std::any_of(
+            std::begin(_ignore), std::end(_ignore), [&](bsoncxx::stdx::string_view key) {
+                return view["command_started_event"]["command"][key] ||
+                       view["command_failed_event"]["command"][key] ||
+                       view["command_succeeded_event"]["command"][key];
+            });
     };
 
     auto events_iter = _events.begin();
@@ -145,10 +151,11 @@ void apm_checker::has(bsoncxx::array::view expectations) {
     }
 }
 
-bool apm_checker::should_ignore(stdx::string_view command_name) const {
-    return std::any_of(std::begin(_ignore),
-                       std::end(_ignore),
-                       [command_name](stdx::string_view cmp) { return command_name == cmp; });
+bool apm_checker::should_ignore(bsoncxx::stdx::string_view command_name) const {
+    return std::any_of(
+        std::begin(_ignore), std::end(_ignore), [command_name](bsoncxx::stdx::string_view cmp) {
+            return command_name == cmp;
+        });
 }
 
 std::string apm_checker::print_all() const {
@@ -165,9 +172,10 @@ std::string apm_checker::print_all() const {
 /// We don't have access to the original command definition here, but (at present) we can
 /// detect that it is sensitive by the mongoc library having removed the main body of the
 /// command events' requests and responses, thus we check for ".empty()" on that body.
-static bool is_hello_cmd_name(stdx::string_view name) {
-    return name == stdx::string_view("hello") || name == stdx::string_view("ismaster") ||
-           name == stdx::string_view("isMaster");
+static bool is_hello_cmd_name(bsoncxx::stdx::string_view name) {
+    return name == bsoncxx::stdx::string_view("hello") ||
+           name == bsoncxx::stdx::string_view("ismaster") ||
+           name == bsoncxx::stdx::string_view("isMaster");
 }
 static bool is_sensitive_hello_cmd_event(const events::command_started_event& event) {
     return event.command().empty();
@@ -184,13 +192,13 @@ static bool is_sensitive_hello_cmd_event(const events::command_failed_event& ev)
 /**
  * @brief Determine whether 'event' is one of the "sensitive" events.
  *
- * `event` must have a `command_name() const -> stdx::string_view` method. If the
+ * `event` must have a `command_name() const -> bsoncxx::stdx::string_view` method. If the
  * event is a 'hello' or 'isMaster' event, it is sensitive if it is a commandStartedEvent
  * and 'speculativeAuthenticate' is provided in the command (See is_sensitive_hello_cmd_event).
  */
 template <typename Ev>
 static bool is_sensitive_command(const Ev& event) noexcept {
-    static stdx::string_view sensitive_commands[] = {
+    static bsoncxx::stdx::string_view sensitive_commands[] = {
         "authenticate",
         "saslStart",
         "saslContinue",
