@@ -1,4 +1,4 @@
-// Copyright 2020 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -124,7 +124,7 @@ const std::type_info& map::type(const key_type& key) {
     return typeid(mongocxx::client);
 }
 
-database& map::get_database_by_name(stdx::string_view name) {
+database& map::get_database_by_name(bsoncxx::stdx::string_view name) {
     for (auto&& kvp : _database_map)
         if (name == kvp.second.name())
             return kvp.second;
