@@ -1,4 +1,4 @@
-// Copyright 2020 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,27 +12,31 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#include "assert.hh"
+#include "entity.hh"
+#include "operations.hh"
+
 #include <fstream>
 #include <numeric>
 #include <regex>
 #include <sstream>
 #include <unordered_set>
 
-#include "assert.hh"
-#include "entity.hh"
-#include "operations.hh"
 #include <bsoncxx/builder/basic/document.hpp>
 #include <bsoncxx/builder/basic/kvp.hpp>
 #include <bsoncxx/stdx/optional.hpp>
 #include <bsoncxx/stdx/string_view.hpp>
 #include <bsoncxx/string/to_string.hpp>
-#include <bsoncxx/test/catch.hh>
 #include <bsoncxx/types/bson_value/value.hpp>
+
 #include <mongocxx/client_encryption.hpp>
 #include <mongocxx/exception/bulk_write_exception.hpp>
 #include <mongocxx/exception/exception.hpp>
 #include <mongocxx/exception/operation_exception.hpp>
 #include <mongocxx/instance.hpp>
+
+#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/test/client_helpers.hh>
 #include <mongocxx/test/spec/monitoring.hh>
 #include <mongocxx/test/spec/util.hh>
@@ -86,7 +90,7 @@ bsoncxx::document::value get_kms_values() {
     char key_storage[96];
     memcpy(&(key_storage[0]), kLocalMasterKey, 96);
     const bsoncxx::types::b_binary local_master_key{
-        bsoncxx::binary_sub_type::k_binary, 96, (const uint8_t*)&key_storage};
+        bsoncxx::binary_sub_type::k_binary, 96, reinterpret_cast<const uint8_t*>(&key_storage)};
 
     auto kms_doc = make_document(
         kvp("aws",
@@ -143,9 +147,30 @@ bsoncxx::document::value parse_kms_doc(bsoncxx::document::view_or_value test_kms
                 case bsoncxx::type::k_string:
                     variables_doc.append(kvp(variable, actual_value.get_string()));
                     break;
+
                 case bsoncxx::type::k_binary:
                     variables_doc.append(kvp(variable, actual_value.get_binary()));
                     break;
+
+                case bsoncxx::type::k_double:
+                case bsoncxx::type::k_document:
+                case bsoncxx::type::k_array:
+                case bsoncxx::type::k_undefined:
+                case bsoncxx::type::k_oid:
+                case bsoncxx::type::k_bool:
+                case bsoncxx::type::k_date:
+                case bsoncxx::type::k_null:
+                case bsoncxx::type::k_regex:
+                case bsoncxx::type::k_dbpointer:
+                case bsoncxx::type::k_code:
+                case bsoncxx::type::k_symbol:
+                case bsoncxx::type::k_codewscope:
+                case bsoncxx::type::k_int32:
+                case bsoncxx::type::k_timestamp:
+                case bsoncxx::type::k_int64:
+                case bsoncxx::type::k_decimal128:
+                case bsoncxx::type::k_maxkey:
+                case bsoncxx::type::k_minkey:
                 default:
                     FAIL("FAIL: unexpected variable type in KMS doc: '"
                          << bsoncxx::to_string(actual_value.type()) << "'");
@@ -424,11 +449,11 @@ void add_observe_events(spec::apm_checker& apm, options::apm& apm_opts, document
 
     for (const auto& event : events) {
         const auto event_type = event.get_string().value;
-        if (event_type == mongocxx::stdx::string_view("commandStartedEvent")) {
+        if (event_type == bsoncxx::stdx::string_view("commandStartedEvent")) {
             apm.set_command_started_unified(apm_opts);
-        } else if (event_type == mongocxx::stdx::string_view("commandSucceededEvent")) {
+        } else if (event_type == bsoncxx::stdx::string_view("commandSucceededEvent")) {
             apm.set_command_succeeded_unified(apm_opts);
-        } else if (event_type == mongocxx::stdx::string_view("commandFailedEvent")) {
+        } else if (event_type == bsoncxx::stdx::string_view("commandFailedEvent")) {
             apm.set_command_failed_unified(apm_opts);
         } else {
             UNSCOPED_INFO("ignoring unsupported command monitoring event " << event_type);
@@ -480,7 +505,7 @@ read_preference get_read_preference(const document::element& opts) {
 
     const auto mode = read_pref["mode"].get_string().value;
 
-    if (mode.compare("secondaryPreferred") == 0) {
+    if (mode == "secondaryPreferred") {
         rp.mode(read_preference::read_mode::k_secondary_preferred);
     } else {
         FAIL("unhandled readPreference mode: " << mode);
@@ -492,9 +517,9 @@ read_preference get_read_preference(const document::element& opts) {
 write_concern get_write_concern(const document::element& opts) {
     auto wc = write_concern{};
     if (auto w = opts["writeConcern"]["w"]) {
-        if (w.type() == type::k_utf8) {
+        if (w.type() == type::k_string) {
             const auto strval = w.get_string().value;
-            if (0 == strval.compare("majority")) {
+            if (strval == "majority") {
                 wc.acknowledge_level(mongocxx::write_concern::level::k_majority);
             } else {
                 FAIL("Unsupported write concern string " << strval);
@@ -670,15 +695,12 @@ database create_database(document::view object) {
 client create_client(document::view object) {
     const auto conn = "mongodb://" + get_hostnames(object) + "/?" + uri_options_to_string(object);
     auto apm_opts = options::apm{};
-    auto client_opts = options::client{};
+    auto client_opts = test_util::add_test_server_api();
     // Use specified serverApi or default if none is provided.
     if (object["serverApi"]) {
         const auto server_api_opts = create_server_api(object);
         client_opts.server_api_opts(server_api_opts);
-    } else {
-        client_opts = test_util::add_test_server_api();
     }
-
     auto& apm = get_apm_map()[string::to_string(object["id"].get_string().value)];
 
     add_observe_events(apm, apm_opts, object);
@@ -844,46 +866,59 @@ void assert_error(const mongocxx::operation_exception& exception,
     }
 
     if (const auto is_client_error = expect_error["isClientError"]) {
-        if (std::strstr(exception.what(), "Snapshot reads require MongoDB 5.0 or later") !=
-            nullptr) {
-            // Original error: { MONGOC_ERROR_CLIENT, MONGOC_ERROR_CLIENT_SESSION_FAILURE }
-            // Do not assert a server-side error.
-            // The C++ driver throws this error as a server-side error operation_exception.
-            // Remove this special case as part of CXX-2377.
-            REQUIRE(is_client_error.get_bool());
-        } else if (std::strstr(exception.what(), "The selected server does not support hint for") !=
-                   nullptr) {
-            // Original error: { MONGOC_ERROR_COMMAND, MONGOC_ERROR_PROTOCOL_BAD_WIRE_VERSION }
-            // Do not assert a server-side error.
-            // The C++ driver throws this error as a server-side error operation_exception.
-            // Remove this special case as part of CXX-2377.
-            REQUIRE(is_client_error.get_bool());
-        } else if (std::strstr(exception.what(), "Error in KMS response") != nullptr) {
-            REQUIRE(is_client_error.get_bool());
-        } else if (std::strstr(exception.what(),
-                               "keyMaterial should have length 96, but has length 84") != nullptr) {
-            REQUIRE(is_client_error.get_bool());
-        } else if (std::strstr(exception.what(), "expected UTF-8 key") != nullptr) {
-            REQUIRE(is_client_error.get_bool());
-        } else if (std::strstr(exception.what(), "Unexpected field: 'invalid'") != nullptr) {
-            REQUIRE(is_client_error.get_bool());
-        } else if (std::strstr(exception.what(), "Failed to resolve kms.invalid.amazonaws.com") !=
-                   nullptr) {
-            REQUIRE(is_client_error.get_bool());
-        } else if (std::strstr(
-                       exception.what(),
-                       "The ciphertext refers to a customer master key that does not exist") !=
-                   nullptr) {
-            REQUIRE(is_client_error.get_bool());
-        } else if (std::strstr(exception.what(), "does not exist") != nullptr) {
-            REQUIRE(is_client_error.get_bool());
-        } else if (std::strstr(exception.what(),
-                               "Failed to resolve invalid-vault-csfle.vault.azure.net") !=
-                   nullptr) {
-            REQUIRE(is_client_error.get_bool());
-        } else if (is_client_error.get_bool()) {
-            // An operation_exception represents a server-side error.
-            REQUIRE(!is_client_error.get_bool());
+        // An explicit list of client-side errors. We do not yet have a reliable and consistent
+        // method to distinguish client-side errors from server-side errors. (CXX-2377)
+        static const bsoncxx::stdx::string_view patterns[] = {
+            // { MONGOC_ERROR_CLIENT, MONGOC_ERROR_CLIENT_SESSION_FAILURE }
+            // mongoc: mongoc_cmd_parts_assemble
+            "Snapshot reads require MongoDB 5.0 or later",
+
+            // { MONGOC_ERROR_COMMAND, MONGOC_ERROR_PROTOCOL_BAD_WIRE_VERSION }
+            // mongoc: mongoc_collection_find_and_modify_with_opts,
+            // _mongoc_write_command_execute_idl
+            "The selected server does not support hint for",
+
+            // { MONGOC_ERROR_STREAM, MONGOC_ERROR_STREAM_NAME_RESOLUTION }
+            // mongoc: mongoc_client_connect_tcp, mongoc_topology_scanner_node_setup_tcp
+            "Failed to resolve ",
+
+            // { MONGOCRYPT_STATUS_ERROR_CLIENT, MONGOCRYPT_GENERIC_ERROR_CODE }
+            // libmongocrypt: mongocrypt_kms_ctx_feed
+            "Error in KMS response",
+
+            // { MONGOCRYPT_STATUS_ERROR_CLIENT, MONGOCRYPT_GENERIC_ERROR_CODE }
+            // libmongocrypt: mongocrypt_ctx_setopt_key_material
+            "keyMaterial should have length 96, but has length 84",
+
+            // { MONGOCRYPT_STATUS_ERROR_CLIENT, MONGOCRYPT_GENERIC_ERROR_CODE }
+            // libmongocrypt: _mongocrypt_parse_optional_utf8, _mongocrypt_parse_required_utf8
+            "expected UTF-8 key",
+
+            // { MONGOCRYPT_STATUS_ERROR_CLIENT, MONGOCRYPT_GENERIC_ERROR_CODE }
+            // libmongocrypt: _mongocrypt_check_allowed_fields
+            "Unexpected field: 'invalid'",
+
+            // { MONGOCRYPT_STATUS_ERROR_CLIENT, MONGOCRYPT_GENERIC_ERROR_CODE }
+            // libmongocrypt: _kms_done
+            "key material not expected length",
+        };
+
+        const bsoncxx::stdx::string_view message = exception.what();
+
+        const auto iter = std::find_if(std::begin(patterns),
+                                       std::end(patterns),
+                                       [message](bsoncxx::stdx::string_view pattern) {
+                                           return message.find(pattern) != message.npos;
+                                       });
+
+        if (iter != std::end(patterns)) {
+            // Treat this as a client-side error.
+            const auto pattern = *iter;
+            CAPTURE(pattern);
+            REQUIRE(is_client_error.get_bool().value);
+        } else {
+            // Treat this as a server-side error.
+            REQUIRE(!is_client_error.get_bool().value);
         }
     }
 
@@ -920,7 +955,7 @@ void assert_error(const mongocxx::operation_exception& exception,
         // in assert_error():
         // See
         //
-    "https://github.com/mongodb/specifications/blob/master/source/unified-test-format/unified-test-format.rst#expectederror":
+    "https://github.com/mongodb/specifications/blob/master/source/unified-test-format/unified-test-format.md#expectederror":
         // A substring of the expected error message (e.g. "errmsg" field in a server error
         // document). The test runner MUST assert that the error message contains this string using
         // a case-insensitive match.
@@ -1063,9 +1098,9 @@ struct fail_point_guard_type {
     }
 };
 
-void disable_targeted_fail_point(mongocxx::stdx::string_view uri,
+void disable_targeted_fail_point(bsoncxx::stdx::string_view uri,
                                  std::uint32_t server_id,
-                                 mongocxx::stdx::string_view fail_point) {
+                                 bsoncxx::stdx::string_view fail_point) {
     const auto command_owner =
         make_document(kvp("configureFailPoint", fail_point), kvp("mode", "off"));
     const auto command = command_owner.view();
@@ -1115,8 +1150,8 @@ document::value bulk_write_result(const mongocxx::bulk_write_exception& e) {
 }
 
 // Match test cases that should be skipped by both test and case descriptions.
-const std::map<std::pair<mongocxx::stdx::string_view, mongocxx::stdx::string_view>,
-               mongocxx::stdx::string_view>
+const std::map<std::pair<bsoncxx::stdx::string_view, bsoncxx::stdx::string_view>,
+               bsoncxx::stdx::string_view>
     should_skip_test_cases = {
         {{"retryable reads handshake failures",
           "collection.findOne succeeds after retryable handshake network error"},
@@ -1134,32 +1169,29 @@ const std::map<std::pair<mongocxx::stdx::string_view, mongocxx::stdx::string_vie
          "collection.listIndexNames optional helper is not supported"},
 };
 
-void run_tests(mongocxx::stdx::string_view test_description, document::view test) {
+void run_tests(bsoncxx::stdx::string_view test_description, document::view test) {
     REQUIRE(test["tests"]);
 
     for (const auto& ele : test["tests"].get_array().value) {
         const auto description = string::to_string(ele["description"].get_string().value);
-        SECTION(description) {
+
+        DYNAMIC_SECTION(description) {
             {
                 const auto iter = should_skip_test_cases.find({test_description, description});
                 if (iter != should_skip_test_cases.end()) {
-                    WARN("test skipped: " << iter->second);
-                    continue;
+                    SKIP(test_description << ": " << description << ": unsupported test case");
                 }
             }
 
             if (!has_run_on_requirements(ele.get_document())) {
-                std::stringstream warning;
-                warning << "test skipped: "
-                        << "none of the runOnRequirements were met" << std::endl
-                        << to_json(ele["runOnRequirements"].get_array().value);
-                WARN(warning.str());
-                continue;
+                SKIP(test_description << ": " << description
+                                      << ": none of the runOnRequirements were met: "
+                                      << to_json(ele["runOnRequirements"].get_array().value));
             }
 
             if (ele["skipReason"]) {
-                WARN("Skip Reason: " + string::to_string(ele["skipReason"].get_string().value));
-                continue;
+                SKIP(test_description << ": " << description << ": "
+                                      << string::to_string(ele["skipReason"].get_string().value));
             }
 
             fail_point_guard_type fail_point_guard;
@@ -1264,12 +1296,8 @@ void run_tests_in_file(const std::string& test_path) {
     }
 
     if (!has_run_on_requirements(test_spec_view)) {
-        std::stringstream warning;
-        warning << "file skipped: " << test_path << std::endl
-                << "none of the runOnRequirements were met" << std::endl
-                << to_json(test_spec_view["runOnRequirements"].get_array().value);
-        WARN(warning.str());
-        return;
+        CAPTURE(to_json(test_spec_view["runOnRequirements"].get_array().value));
+        SKIP(test_path << ": none of the runOnRequirements were met");
     }
 
     const auto description = test_spec_view["description"].get_string().value;
@@ -1282,9 +1310,9 @@ void run_tests_in_file(const std::string& test_path) {
 // Check the environment for the specified variable; if present, extract it
 // as a directory and run all the tests contained in the magic "test_files.txt"
 // file:
-bool run_unified_format_tests_in_env_dir(
+void run_unified_format_tests_in_env_dir(
     const std::string& env_path,
-    const std::set<mongocxx::stdx::string_view>& unsupported_tests = {}) {
+    const std::set<bsoncxx::stdx::string_view>& unsupported_tests = {}) {
     const char* p = std::getenv(env_path.c_str());
 
     if (nullptr == p)
@@ -1302,72 +1330,67 @@ bool run_unified_format_tests_in_env_dir(
     instance::current();
 
     for (std::string file; std::getline(files, file);) {
-        SECTION(file) {
+        DYNAMIC_SECTION(file) {
             if (unsupported_tests.find(file) != unsupported_tests.end()) {
-                WARN("Skipping unsupported test file: " << file);
-            } else {
-                run_tests_in_file(base_path + '/' + file);
+                SKIP("unsupported test file: " << file);
             }
+
+            run_tests_in_file(base_path + '/' + file);
         }
     }
-
-    return true;
 }
 
-TEST_CASE("unified format spec automated tests", "[unified_format_spec]") {
-    const std::set<mongocxx::stdx::string_view> unsupported_tests = {
+TEST_CASE("unified format spec automated tests", "[unified_format_specs]") {
+    const std::set<bsoncxx::stdx::string_view> unsupported_tests = {
         // Waiting on CDRIVER-3525 and CXX-2166.
         "valid-pass/entity-client-cmap-events.json",
         // Waiting on CDRIVER-3525 and CXX-2166.
         "valid-pass/assertNumberConnectionsCheckedOut.json"};
 
-    CHECK(run_unified_format_tests_in_env_dir("UNIFIED_FORMAT_TESTS_PATH", unsupported_tests));
+    run_unified_format_tests_in_env_dir("UNIFIED_FORMAT_TESTS_PATH", unsupported_tests);
 }
 
-TEST_CASE("session unified format spec automated tests", "[unified_format_spec]") {
-    CHECK(run_unified_format_tests_in_env_dir("SESSION_UNIFIED_TESTS_PATH"));
+TEST_CASE("session unified format spec automated tests", "[unified_format_specs]") {
+    run_unified_format_tests_in_env_dir("SESSION_UNIFIED_TESTS_PATH");
 }
 
-TEST_CASE("CRUD unified format spec automated tests", "[unified_format_spec]") {
-    CHECK(run_unified_format_tests_in_env_dir("CRUD_UNIFIED_TESTS_PATH"));
+TEST_CASE("CRUD unified format spec automated tests", "[unified_format_specs]") {
+    run_unified_format_tests_in_env_dir("CRUD_UNIFIED_TESTS_PATH");
 }
 
-TEST_CASE("change streams unified format spec automated tests", "[unified_format_spec]") {
-    CHECK(run_unified_format_tests_in_env_dir("CHANGE_STREAMS_UNIFIED_TESTS_PATH"));
+TEST_CASE("change streams unified format spec automated tests", "[unified_format_specs]") {
+    run_unified_format_tests_in_env_dir("CHANGE_STREAMS_UNIFIED_TESTS_PATH");
 }
 
-TEST_CASE("retryable reads unified format spec automated tests", "[unified_format_spec]") {
-    CHECK(run_unified_format_tests_in_env_dir("RETRYABLE_READS_UNIFIED_TESTS_PATH"));
+TEST_CASE("retryable reads unified format spec automated tests", "[unified_format_specs]") {
+    run_unified_format_tests_in_env_dir("RETRYABLE_READS_UNIFIED_TESTS_PATH");
 }
 
-TEST_CASE("retryable writes unified format spec automated tests", "[unified_format_spec]") {
-    CHECK(run_unified_format_tests_in_env_dir("RETRYABLE_WRITES_UNIFIED_TESTS_PATH"));
+TEST_CASE("retryable writes unified format spec automated tests", "[unified_format_specs]") {
+    run_unified_format_tests_in_env_dir("RETRYABLE_WRITES_UNIFIED_TESTS_PATH");
 }
 
-TEST_CASE("transactions unified format spec automated tests", "[unified_format_spec]") {
-    CHECK(run_unified_format_tests_in_env_dir("TRANSACTIONS_UNIFIED_TESTS_PATH"));
+TEST_CASE("transactions unified format spec automated tests", "[unified_format_specs]") {
+    run_unified_format_tests_in_env_dir("TRANSACTIONS_UNIFIED_TESTS_PATH");
 }
 
-TEST_CASE("versioned API spec automated tests", "[unified_format_spec]") {
-    CHECK(run_unified_format_tests_in_env_dir("VERSIONED_API_TESTS_PATH"));
+TEST_CASE("versioned API spec automated tests", "[unified_format_specs]") {
+    run_unified_format_tests_in_env_dir("VERSIONED_API_TESTS_PATH");
 }
 
-TEST_CASE("collection management spec automated tests", "[unified_format_spec]") {
-    CHECK(run_unified_format_tests_in_env_dir("COLLECTION_MANAGEMENT_TESTS_PATH"));
+TEST_CASE("collection management spec automated tests", "[unified_format_specs]") {
+    run_unified_format_tests_in_env_dir("COLLECTION_MANAGEMENT_TESTS_PATH");
 }
 
-TEST_CASE("index management spec automated tests", "[unified_format_spec]") {
-    CHECK(run_unified_format_tests_in_env_dir("INDEX_MANAGEMENT_TESTS_PATH"));
+TEST_CASE("index management spec automated tests", "[unified_format_specs]") {
+    run_unified_format_tests_in_env_dir("INDEX_MANAGEMENT_TESTS_PATH");
 }
 
 // See:
-// https://github.com/mongodb/specifications/blob/master/source/client-side-encryption/client-side-encryption.rst
-TEST_CASE("client side encryption unified format spec automated tests", "[unified_format_spec]") {
-    if (!mongocxx::test_util::should_run_client_side_encryption_test()) {
-        WARN("Skipping - client side encryption unified tests");
-        return;
-    }
-    CHECK(run_unified_format_tests_in_env_dir("CLIENT_SIDE_ENCRYPTION_UNIFIED_TESTS_PATH"));
+// https://github.com/mongodb/specifications/blob/master/source/client-side-encryption/client-side-encryption.md
+TEST_CASE("client side encryption unified format spec automated tests", "[unified_format_specs]") {
+    CLIENT_SIDE_ENCRYPTION_ENABLED_OR_SKIP();
+    run_unified_format_tests_in_env_dir("CLIENT_SIDE_ENCRYPTION_UNIFIED_TESTS_PATH");
 }
 
 }  // namespace
