@@ -1,4 +1,4 @@
-// Copyright 2016 MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -15,11 +15,12 @@
 #include <cctype>
 #include <fstream>
 
-#include <bsoncxx/test/catch.hh>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/instance.hpp>
 #include <mongocxx/pool.hpp>
 
+#include <bsoncxx/test/catch.hh>
+
 namespace {
 
 struct URIOptionsTest {
@@ -33,17 +34,17 @@ struct URIOptionsTest {
         URIOptionsTest test;
 
         for (auto el : test_doc) {
-            if (0 == el.key().compare("description")) {
+            if (el.key() == "description") {
                 test.description = el.get_string().value;
-            } else if (0 == el.key().compare("uri")) {
+            } else if (el.key() == "uri") {
                 test.uri = el.get_string().value;
-            } else if (0 == el.key().compare("valid")) {
+            } else if (el.key() == "valid") {
                 test.valid = el.get_bool().value;
-            } else if (0 == el.key().compare("warning")) {
+            } else if (el.key() == "warning") {
                 test.warning = el.get_bool().value;
-            } else if (0 == el.key().compare("options")) {
+            } else if (el.key() == "options") {
                 test.options = el.get_document().value;
-            } else if ((0 == el.key().compare("hosts")) || ((0 == el.key().compare("auth")))) {
+            } else if (el.key() == "hosts" || el.key() == "auth") {
                 // hosts and auth will always be null are to be skipped as per the spec test
                 // description
             } else {
@@ -55,7 +56,7 @@ struct URIOptionsTest {
     }
 };
 
-static bsoncxx::document::value _doc_from_file(mongocxx::stdx::string_view sub_path) {
+static bsoncxx::document::value _doc_from_file(bsoncxx::stdx::string_view sub_path) {
     const char* test_path = std::getenv("URI_OPTIONS_TESTS_PATH");
     REQUIRE(test_path);
 
@@ -78,12 +79,33 @@ static void assert_elements_equal(bsoncxx::document::element expected_option,
         case bsoncxx::type::k_int32:
             REQUIRE(expected_option.get_int32() == my_option.get_int32());
             break;
+
         case bsoncxx::type::k_bool:
             REQUIRE(expected_option.get_bool() == my_option.get_bool());
             break;
+
         case bsoncxx::type::k_string:
             REQUIRE(expected_option.get_string() == my_option.get_string());
             break;
+
+        case bsoncxx::type::k_double:
+        case bsoncxx::type::k_document:
+        case bsoncxx::type::k_array:
+        case bsoncxx::type::k_binary:
+        case bsoncxx::type::k_undefined:
+        case bsoncxx::type::k_oid:
+        case bsoncxx::type::k_date:
+        case bsoncxx::type::k_null:
+        case bsoncxx::type::k_regex:
+        case bsoncxx::type::k_dbpointer:
+        case bsoncxx::type::k_code:
+        case bsoncxx::type::k_symbol:
+        case bsoncxx::type::k_codewscope:
+        case bsoncxx::type::k_timestamp:
+        case bsoncxx::type::k_int64:
+        case bsoncxx::type::k_decimal128:
+        case bsoncxx::type::k_maxkey:
+        case bsoncxx::type::k_minkey:
         default:
             std::string msg =
                 "option type not handled: " + bsoncxx::to_string(expected_option.type());
@@ -100,7 +122,8 @@ TEST_CASE("uri_options::test_srv_options", "[uri_options]") {
     for (const auto& it : tests) {
         auto doc = it.get_document().value;
         auto test = URIOptionsTest::parse(doc);
-        SECTION(std::string(test.description)) {
+
+        DYNAMIC_SECTION(test.description) {
             try {
                 mongocxx::uri my_uri{test.uri};
                 REQUIRE(test.valid);
@@ -114,6 +137,7 @@ TEST_CASE("uri_options::test_srv_options", "[uri_options]") {
                 }
             } catch (mongocxx::logic_error& e) {
                 bool should_throw = !test.valid || test.warning;
+                CAPTURE(e);
                 REQUIRE(should_throw);
             }
         }
