@@ -1,4 +1,4 @@
-// Copyright 2018-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,6 +12,8 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#include "mongocxx/test/client_helpers.hh"
+
 #include <fstream>
 #include <set>
 #include <string>
@@ -25,7 +27,7 @@
 #include <bsoncxx/json.hpp>
 #include <bsoncxx/stdx/optional.hpp>
 #include <bsoncxx/string/to_string.hpp>
-#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/client.hpp>
 #include <mongocxx/collection.hpp>
 #include <mongocxx/database.hpp>
@@ -38,11 +40,16 @@
 #include <mongocxx/pipeline.hpp>
 #include <mongocxx/result/delete.hpp>
 #include <mongocxx/result/insert_one.hpp>
+
+#include <mongocxx/config/private/prelude.hh>
+
+#include <bsoncxx/test/catch.hh>
+
 #include <mongocxx/test/spec/monitoring.hh>
 #include <mongocxx/test/spec/operation.hh>
 #include <mongocxx/test/spec/util.hh>
 
-#include <mongocxx/config/private/prelude.hh>
+#include <catch2/matchers/catch_matchers_string.hpp>
 
 namespace mongocxx {
 namespace spec {
@@ -59,27 +66,27 @@ using bsoncxx::stdx::string_view;
 static const int kMaxHelloFailCommands = 7;
 
 uint32_t error_code_from_name(string_view name) {
-    if (name.compare("CannotSatisfyWriteConcern") == 0) {
+    if (name == "CannotSatisfyWriteConcern") {
         return 100;
-    } else if (name.compare("DuplicateKey") == 0) {
+    } else if (name == "DuplicateKey") {
         return 11000;
-    } else if (name.compare("NoSuchTransaction") == 0) {
+    } else if (name == "NoSuchTransaction") {
         return 251;
-    } else if (name.compare("WriteConflict") == 0) {
+    } else if (name == "WriteConflict") {
         return 112;
-    } else if (name.compare("Interrupted") == 0) {
+    } else if (name == "Interrupted") {
         return 11601;
-    } else if (name.compare("MaxTimeMSExpired") == 0) {
+    } else if (name == "MaxTimeMSExpired") {
         return 50;
-    } else if (name.compare("UnknownReplWriteConcern") == 0) {
+    } else if (name == "UnknownReplWriteConcern") {
         return 79;
-    } else if (name.compare("UnsatisfiableWriteConcern") == 0) {
+    } else if (name == "UnsatisfiableWriteConcern") {
         return 100;
-    } else if (name.compare("OperationNotSupportedInTransaction") == 0) {
+    } else if (name == "OperationNotSupportedInTransaction") {
         return 263;
-    } else if (name.compare("APIStrictError") == 0) {
+    } else if (name == "APIStrictError") {
         return 323;
-    } else if (name.compare("ChangeStreamFatalError") == 0) {
+    } else if (name == "ChangeStreamFatalError") {
         return 280;
     }
 
@@ -87,8 +94,8 @@ uint32_t error_code_from_name(string_view name) {
 }
 
 /* Called with the entire test file and individual tests. */
-bool should_skip_spec_test(const client& client, document::view test) {
-    std::set<std::string> unsupported_tests = {
+bool check_if_skip_spec_test_impl(const client& client, document::view test, std::string& reason) {
+    static const std::set<std::string> unsupported_tests = {
         "CreateIndex and dropIndex omits default write concern",
         "MapReduce omits default write concern",
         "Deprecated count with empty collection",
@@ -101,41 +108,55 @@ bool should_skip_spec_test(const client& client, document::view test) {
         "run command fails with explicit secondary read preference",
     };
 
-    if (test["description"]) {
-        std::string description = std::string(test["description"].get_string().value);
-        if (unsupported_tests.find(description) != unsupported_tests.end()) {
-            UNSCOPED_INFO("Test skipped - " << description << "\n"
-                                            << "reason: unsupported in C++ driver");
+    if (const auto description = test["description"]) {
+        const auto desc = std::string(description.get_string().value);
+        if (unsupported_tests.find(desc) != unsupported_tests.end()) {
+            reason.append(desc);
+            reason.append(": not supported by the C++ Driver");
             return true;
         }
     }
 
-    if (test["skipReason"]) {
-        UNSCOPED_INFO("Test skipped - " << test["description"].get_string().value << "\n"
-                                        << "reason: " << test["skipReason"].get_string().value);
+    if (const auto skip_reason = test["skipReason"]) {
+        const auto desc = test["description"].get_string().value;
+        const auto str = skip_reason.get_string().value;
+
+        reason.append(desc.data(), desc.size());
+        reason.append(": ");
+        reason.append(str.data(), str.size());
+
         return true;
     }
 
-    auto run_mongohouse_tests = std::getenv("RUN_MONGOHOUSE_TESTS");
-    if (run_mongohouse_tests && std::string(run_mongohouse_tests) == "ON") {
-        // mongohoused does not return `version` field in response to serverStatus.
-        // Exit early to run the test.
-        return false;
+    {
+        const auto run_mongohouse_tests = std::getenv("RUN_MONGOHOUSE_TESTS");
+
+        if (run_mongohouse_tests && std::string(run_mongohouse_tests) == "ON") {
+            // mongohoused does not return `version` field in response to serverStatus.
+            // Exit early to run the test.
+            return false;
+        }
     }
 
-    std::string server_version = test_util::get_server_version(client);
+    const auto server_version = test_util::get_server_version(client);
 
-    std::string topology = test_util::get_topology(client);
+    const auto topology = test_util::get_topology(client);
 
     if (test["ignore_if_server_version_greater_than"]) {
-        std::string max_server_version = bsoncxx::string::to_string(
+        const auto max_server_version = bsoncxx::string::to_string(
             test["ignore_if_server_version_greater_than"].get_string().value);
+
         if (test_util::compare_versions(server_version, max_server_version) > 0) {
+            reason.append(server_version);
+            reason.append(" is greater than ");
+            reason.append(max_server_version);
             return true;
         }
     }
 
     auto should_skip = [&](document::view requirements) {
+        reason.clear();
+
         if (requirements["topology"]) {
             auto topologies = requirements["topology"].get_array().value;
             bool found = false;
@@ -146,22 +167,30 @@ bool should_skip_spec_test(const client& client, document::view test) {
                 }
             }
             if (!found) {
+                reason.append(topology);
+                reason.append(" is not present in the list of topologies");
                 return true;
             }
         }
 
         if (requirements["minServerVersion"]) {
-            auto min_server_version =
+            const auto min_server_version =
                 string::to_string(requirements["minServerVersion"].get_string().value);
             if (test_util::compare_versions(server_version, min_server_version) < 0) {
+                reason.append(server_version);
+                reason.append(" is greater than minimum server version ");
+                reason.append(min_server_version);
                 return true;
             }
         }
 
         if (requirements["maxServerVersion"]) {
-            auto max_server_version =
+            const auto max_server_version =
                 string::to_string(requirements["maxServerVersion"].get_string().value);
             if (test_util::compare_versions(server_version, max_server_version) > 0) {
+                reason.append(server_version);
+                reason.append(" is greater than max server version ");
+                reason.append(max_server_version);
                 return true;
             }
         }
@@ -175,13 +204,14 @@ bool should_skip_spec_test(const client& client, document::view test) {
                 return false;
             }
         }
-    } else if (!should_skip(test)) {
-        return false;
+
+        reason.clear();
+        reason.append("no runOn conditions are satisfied");
+
+        return true;
     }
 
-    UNSCOPED_INFO("Skipping - unsupported server version '" + server_version + "' with topology '" +
-                  topology + "'");
-    return true;
+    return should_skip(test);
 }
 
 void configure_fail_point(const client& client, document::view test) {
@@ -190,7 +220,7 @@ void configure_fail_point(const client& client, document::view test) {
     }
 }
 
-void disable_fail_point(const client& client, stdx::string_view fail_point) {
+void disable_fail_point(const client& client, bsoncxx::stdx::string_view fail_point) {
     /* Some transactions tests have a failCommand for "hello" repeat seven times. */
     for (int i = 0; i < kMaxHelloFailCommands; i++) {
         try {
@@ -225,12 +255,12 @@ struct fail_point_guard_type {
 
 void disable_fail_point(std::string uri_string,
                         options::client client_opts,
-                        stdx::string_view fail_point) {
+                        bsoncxx::stdx::string_view fail_point) {
     mongocxx::client client = {uri{uri_string}, client_opts};
     disable_fail_point(client, fail_point);
 }
 
-void disable_targeted_fail_point(std::uint32_t server_id) {
+static void disable_targeted_fail_point(std::uint32_t server_id) {
     const auto command_owner =
         make_document(kvp("configureFailPoint", "failCommand"), kvp("mode", "off"));
     const auto command = command_owner.view();
@@ -561,12 +591,12 @@ void run_tests_in_suite(std::string ev, test_runner cb, std::set<std::string> un
 
     std::string test_file;
     while (std::getline(test_files, test_file)) {
-        SECTION(test_file) {
+        DYNAMIC_SECTION(test_file) {
             if (unsupported_tests.find(test_file) != unsupported_tests.end()) {
-                WARN("Skipping unsupported test file: " << test_file);
-            } else {
-                cb(path + "/" + test_file);
+                SKIP("Skipping unsupported test file: " << test_file);
             }
+
+            cb(path + "/" + test_file);
         }
     }
 }
@@ -597,7 +627,7 @@ static void test_setup(document::view test, document::view test_spec) {
     configure_fail_point(client, test);
 }
 
-void parse_session_opts(document::view session_opts, options::client_session* out) {
+static void parse_session_opts(document::view session_opts, options::client_session* out) {
     options::transaction txn_opts;
     if (session_opts["defaultTransactionOptions"]) {
         if (auto rc =
@@ -627,15 +657,14 @@ void parse_session_opts(document::view session_opts, options::client_session* ou
     out->default_transaction_opts(txn_opts);
 }
 
-using bsoncxx::stdx::string_view;
-void run_transaction_operations(
+static void run_transaction_operations(
     document::view test,
     client* client,
     string_view db_name,
     string_view coll_name,
     client_session* session0,
     client_session* session1,
-    stdx::optional<targeted_fail_point_guard_type>* targeted_fail_point_guard,
+    bsoncxx::stdx::optional<targeted_fail_point_guard_type>* targeted_fail_point_guard,
     const apm_checker& apm_checker,
     bool throw_on_error = false) {
     auto operations = test["operations"].get_array().value;
@@ -655,14 +684,14 @@ void run_transaction_operations(
         const auto operation = op.get_document().value;
 
         // Handle with_transaction separately.
-        if (operation["name"].get_string().value.compare("withTransaction") == 0) {
+        if (operation["name"].get_string().value == "withTransaction") {
             const auto session = [&]() -> mongocxx::client_session* {
                 const auto object = operation["object"].get_string().value;
-                if (object.compare("session0") == 0) {
+                if (object == "session0") {
                     return session0;
                 }
 
-                if (object.compare("session1") == 0) {
+                if (object == "session1") {
                     return session1;
                 }
 
@@ -720,15 +749,15 @@ void run_transaction_operations(
                 // activating the disable guard. There is no harm attempting to disable a fail point
                 // that hasn't been set.
                 if (operation["name"] && operation["name"].get_string().value ==
-                                             stdx::string_view("targetedFailPoint")) {
+                                             bsoncxx::stdx::string_view("targetedFailPoint")) {
                     const auto arguments = operation["arguments"];
 
                     const auto session = [&]() -> mongocxx::client_session* {
                         const auto value = arguments["session"].get_string().value;
-                        if (value == stdx::string_view("session0")) {
+                        if (value == bsoncxx::stdx::string_view("session0")) {
                             return session0;
                         }
-                        if (value == stdx::string_view("session1")) {
+                        if (value == bsoncxx::stdx::string_view("session1")) {
                             return session1;
                         }
                         FAIL("unexpected session name: " << value);
@@ -738,7 +767,7 @@ void run_transaction_operations(
                     // We expect and assume the name of the fail point is always "failCommand". To
                     // date, *all* legacy spec tests use "failCommand" as the fail point name.
                     REQUIRE(arguments["failPoint"]["configureFailPoint"].get_string().value ==
-                            stdx::string_view("failCommand"));
+                            bsoncxx::stdx::string_view("failCommand"));
 
                     // We expect at most one targetedFailPoint operation per test case.
                     REQUIRE(!(*targeted_fail_point_guard));
@@ -776,7 +805,9 @@ void run_transaction_operations(
             auto error_contains =
                 test_util::tolowercase(op["result"]["errorContains"].get_string().value);
 
-            REQUIRE_THAT(error_msg, Catch::Contains(error_contains, Catch::CaseSensitive::No));
+            REQUIRE_THAT(
+                error_msg,
+                Catch::Matchers::ContainsSubstring(error_contains, Catch::CaseSensitive::No));
         }
 
         // "If the result document has an 'errorCodeName' field, verify that the method threw a
@@ -847,28 +878,23 @@ void run_transactions_tests_in_file(const std::string& test_path) {
     const auto tests = test_spec_view["tests"].get_array().value;
 
     /* we may not have a supported topology */
-    if (should_skip_spec_test({uri{}, test_util::add_test_server_api()}, test_spec_view)) {
-        WARN("File skipped - " + test_path);
-        return;
-    }
+    CHECK_IF_SKIP_SPEC_TEST((client{uri{}, test_util::add_test_server_api()}), test_spec_view);
 
     for (auto&& test : tests) {
         const auto description = string::to_string(test["description"].get_string().value);
 
-        SECTION(description) {
+        DYNAMIC_SECTION(description) {
             client setup_client{get_uri(test.get_document().value),
                                 test_util::add_test_server_api()};
 
             // Step 1: If the `skipReason` field is present, skip this test completely.
-            if (should_skip_spec_test(setup_client, test.get_document().value)) {
-                continue;
-            }
+            CHECK_IF_SKIP_SPEC_TEST(setup_client, test.get_document().value);
 
             // Steps 2-8.
             test_setup(test.get_document().value, test_spec_view);
 
             {
-                stdx::optional<fail_point_guard_type> fail_point_guard;
+                bsoncxx::stdx::optional<fail_point_guard_type> fail_point_guard;
                 if (test["failPoint"]) {
                     const auto fail_point_name = string::to_string(
                         test["failPoint"]["configureFailPoint"].get_string().value);
@@ -884,8 +910,8 @@ void run_transactions_tests_in_file(const std::string& test_path) {
                 apm_checker apm_checker;
                 client_opts.apm_opts(
                     apm_checker.get_apm_opts(true /* command_started_events_only */));
-                client_opts = test_util::add_test_server_api(client_opts);
-                client client = {get_uri(test.get_document().value), client_opts};
+                client client = {get_uri(test.get_document().value),
+                                 test_util::add_test_server_api(client_opts)};
 
                 options::client_session session0_opts;
                 options::client_session session1_opts;
@@ -923,7 +949,8 @@ void run_transactions_tests_in_file(const std::string& test_path) {
 
                     // If a test uses `targetedFailPoint`, disable the fail point after running all
                     // `operations` to avoid spurious failures in subsequent tests.
-                    stdx::optional<targeted_fail_point_guard_type> targeted_fail_point_guard;
+                    bsoncxx::stdx::optional<targeted_fail_point_guard_type>
+                        targeted_fail_point_guard;
 
                     // Step 11. Perform the operations.
                     run_transaction_operations(test.get_document().value,
@@ -947,12 +974,12 @@ void run_transactions_tests_in_file(const std::string& test_path) {
                     [&](bsoncxx::stdx::string_view key,
                         bsoncxx::stdx::optional<bsoncxx::types::bson_value::view> main,
                         bsoncxx::types::bson_value::view pattern) {
-                        if (key.compare("lsid") == 0) {
+                        if (key == "lsid") {
                             REQUIRE(pattern.type() == type::k_string);
                             REQUIRE(main);
                             REQUIRE(main->type() == type::k_document);
                             auto session_name = pattern.get_string().value;
-                            if (session_name.compare("session0") == 0) {
+                            if (session_name == "session0") {
                                 REQUIRE(
                                     test_util::matches(session_lsid0, main->get_document().value));
                             } else {
@@ -965,7 +992,7 @@ void run_transactions_tests_in_file(const std::string& test_path) {
                                 return test_util::match_action::k_not_equal;
                             }
                             return test_util::match_action::k_skip;
-                        } else if (key.compare("upsert") == 0 || key.compare("multi") == 0) {
+                        } else if (key == "upsert" || key == "multi") {
                             // libmongoc includes `multi: false` and `upsert: false`.
                             // Some tests do not include `multi: false` and `upsert: false`
                             // in expectations. See DRIVERS-2271 and DRIVERS-976.
@@ -1010,20 +1037,16 @@ void run_crud_tests_in_file(const std::string& test_path, uri test_uri) {
     options::client client_opts;
     apm_checker apm_checker;
     client_opts.apm_opts(apm_checker.get_apm_opts(true /* command_started_events_only */));
-    client_opts = test_util::add_test_server_api(client_opts);
-    client client{std::move(test_uri), client_opts};
+    client client{std::move(test_uri), test_util::add_test_server_api(client_opts)};
 
     document::view test_spec_view = test_spec->view();
-    if (should_skip_spec_test(client, test_spec_view)) {
-        return;
-    }
+    CHECK_IF_SKIP_SPEC_TEST(client, test_spec_view);
 
     for (auto&& test : test_spec_view["tests"].get_array().value) {
         auto description = test["description"].get_string().value;
-        SECTION(to_string(description)) {
-            if (should_skip_spec_test(client, test.get_document())) {
-                continue;
-            }
+
+        DYNAMIC_SECTION(to_string(description)) {
+            CHECK_IF_SKIP_SPEC_TEST(client, test.get_document());
 
             auto get_value_or_default = [&](std::string key, std::string default_str) {
                 if (test_spec_view[key]) {
@@ -1054,7 +1077,7 @@ void run_crud_tests_in_file(const std::string& test_path, uri test_uri) {
 
             configure_fail_point(client, test.get_document().value);
 
-            stdx::optional<fail_point_guard_type> fail_point_guard;
+            bsoncxx::stdx::optional<fail_point_guard_type> fail_point_guard;
             if (test["failPoint"]) {
                 const auto fail_point_name =
                     string::to_string(test["failPoint"]["configureFailPoint"].get_string().value);
