@@ -1,4 +1,4 @@
-// Copyright 2018-present MongoDB Inc.
+// Copyright 2009-present MongoDB, Inc.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -13,13 +13,16 @@
 // limitations under the License.
 
 #include <iostream>
+#include <unordered_set>
 
-#include <bsoncxx/test_util/catch.hh>
 #include <mongocxx/client.hpp>
 #include <mongocxx/exception/logic_error.hpp>
 #include <mongocxx/exception/operation_exception.hpp>
 #include <mongocxx/instance.hpp>
-#include <mongocxx/test_util/client_helpers.hh>
+
+#include <bsoncxx/test/catch.hh>
+
+#include <mongocxx/test/client_helpers.hh>
 
 namespace {
 using namespace mongocxx;
@@ -34,64 +37,62 @@ TEST_CASE("Transaction tests", "[transactions]") {
     client mongodb_client{uri{}, test_util::add_test_server_api()};
 
     if (!test_util::is_replica_set(mongodb_client)) {
-        WARN("Skipping: transactions tests require replica set");
-        return;
+        SKIP("transactions tests require replica set");
     } else if (test_util::get_max_wire_version(mongodb_client) < 7) {
-        WARN("Skipping - transactions tests require max wire version is >= 7");
-        return;
+        SKIP("transactions tests require max wire version is >= 7");
     }
 
     // The test run in first 3 SECTIONs below
-    auto successful_insert_test = [&mongodb_client](
-                                      client_session session,
-                                      stdx::optional<options::transaction> transaction_opts) {
-        auto db = mongodb_client["test"];
-        auto coll = db["txn_test"];
+    auto successful_insert_test =
+        [&mongodb_client](client_session session,
+                          bsoncxx::stdx::optional<options::transaction> transaction_opts) {
+            auto db = mongodb_client["test"];
+            auto coll = db["txn_test"];
 
-        // Insert a document that should change in this test
-        coll.insert_one(make_document(kvp("should_be_two", 1)));
+            // Insert a document that should change in this test
+            coll.insert_one(make_document(kvp("should_be_two", 1)));
 
-        if (transaction_opts) {
-            session.start_transaction(transaction_opts);
-        } else {
-            session.start_transaction();
-        }
-
-        try {
-            coll.update_one(session,
-                            make_document(kvp("should_be_two", 1)),
-                            make_document(kvp("$set", make_document(kvp("should_be_two", 2)))));
-            coll.insert_one(session, make_document(kvp("x", 1)));
-        } catch (mongocxx::exception& e) {
-            INFO("Collection transaction exception: " << e.what() << "\n");
-            session.abort_transaction();
-            REQUIRE(false);
-        }
-
-        try {
-            session.commit_transaction();
-        } catch (const operation_exception& e) {
-            INFO("Exception raw:     " << bsoncxx::to_json(*(e.raw_server_error())) << "\n");
-            INFO("Exception message: " << e.what() << "\n");
-
-            if (e.has_error_label("TransientTransactionError")) {
-                INFO("Transient error in transaction.\n");
-                REQUIRE(false);
+            if (transaction_opts) {
+                session.start_transaction(transaction_opts);
             } else {
-                INFO("Non-transient error in transaction.\n");
+                session.start_transaction();
+            }
+
+            try {
+                coll.update_one(session,
+                                make_document(kvp("should_be_two", 1)),
+                                make_document(kvp("$set", make_document(kvp("should_be_two", 2)))));
+                coll.insert_one(session, make_document(kvp("x", 1)));
+            } catch (mongocxx::exception& e) {
+                INFO("Collection transaction exception: " << e.what() << "\n");
+                session.abort_transaction();
                 REQUIRE(false);
             }
-        }
 
-        // Document with key should_be_two should have a value of 2
-        REQUIRE(coll.count_documents(make_document(kvp("should_be_two", 2))) == 1);
-        // Document {x:1} should have also been inserted
-        REQUIRE(coll.count_documents(make_document(kvp("x", 1))) == 1);
+            try {
+                session.commit_transaction();
+            } catch (const operation_exception& e) {
+                INFO("Exception raw:     " << bsoncxx::to_json(*(e.raw_server_error())) << "\n");
+                INFO("Exception message: " << e.what() << "\n");
 
-        // Cleanup
-        coll.find_one_and_delete(make_document(kvp("should_be_two", 2)));
-        coll.find_one_and_delete(make_document(kvp("x", 1)));
-    };
+                if (e.has_error_label("TransientTransactionError")) {
+                    INFO("Transient error in transaction.\n");
+                    REQUIRE(false);
+                } else {
+                    INFO("Non-transient error in transaction.\n");
+                    REQUIRE(false);
+                }
+            }
+
+            // Document with key should_be_two should have a value of 2
+            REQUIRE(coll.count_documents(make_document(kvp("should_be_two", 2))) == 1);
+            // Document {x:1} should have also been inserted
+            REQUIRE(coll.count_documents(make_document(kvp("x", 1))) == 1);
+
+            // Cleanup
+            coll.find_one_and_delete(make_document(kvp("should_be_two", 2)));
+            coll.find_one_and_delete(make_document(kvp("x", 1)));
+        };
 
     SECTION(
         "A move-constructed options::transactions object transfers properties and invalidates the "
@@ -181,7 +182,8 @@ TEST_CASE("Transaction tests", "[transactions]") {
             // Intentionally do NOT abort to force TransientTransactionError from server on commit.
             auto label = "TransientTransactionError";
             has_transient_error_null_str = e.has_error_label(label);
-            has_transient_error_no_null_str = e.has_error_label(stdx::string_view(label, 25));
+            has_transient_error_no_null_str =
+                e.has_error_label(bsoncxx::stdx::string_view(label, 25));
         }
 
         REQUIRE(has_transient_error_null_str);
@@ -194,7 +196,8 @@ TEST_CASE("Transaction tests", "[transactions]") {
         } catch (const operation_exception& e) {
             auto label = "TransientTransactionError";
             has_transient_error_null_str = e.has_error_label(label);
-            has_transient_error_no_null_str = e.has_error_label(stdx::string_view(label, 25));
+            has_transient_error_no_null_str =
+                e.has_error_label(bsoncxx::stdx::string_view(label, 25));
         }
 
         mongodb_client["admin"].run_command(
@@ -221,11 +224,9 @@ TEST_CASE("Transactions Documentation Examples", "[transactions]") {
     client client{uri{}, test_util::add_test_server_api()};
 
     if (!test_util::is_replica_set(client)) {
-        WARN("Skipping: transactions tests require replica set");
-        return;
+        SKIP("transactions tests require replica set");
     } else if (test_util::get_max_wire_version(client) < 7) {
-        WARN("Skipping - transactions tests require max wire version is >= 7");
-        return;
+        SKIP("transactions tests require max wire version is >= 7");
     }
 
     /* Create necessary collections. */
@@ -437,4 +438,68 @@ TEST_CASE("Transactions Documentation Examples", "[transactions]") {
     }
 }
 
+TEST_CASE("Transactions Mongos Pinning Prose Tests", "[transactions]") {
+    instance::current();
+
+    if (test_util::compare_versions(test_util::get_server_version(), "4.1.6") < 0) {
+        SKIP("requires server 4.1.6+");
+    }
+
+    if (test_util::get_topology() != "sharded") {
+        SKIP("requires sharded cluster topology");
+    }
+
+    // @require_mongos_count_at_least(2)
+    {
+        mongocxx::client client{mongocxx::uri{"mongodb://localhost:27017"}};
+        REQUIRE(client["config"].has_collection("shards"));
+    }
+    {
+        mongocxx::client client{mongocxx::uri{"mongodb://localhost:27018"}};
+        REQUIRE(client["config"].has_collection("shards"));
+    }
+
+    const auto uri =
+        mongocxx::uri("mongodb://localhost:27017,localhost:27018/?localThresholdMS=1000");
+
+    std::unordered_set<std::uint16_t> ports;
+
+    options::apm apm_opts;
+    apm_opts.on_command_started(
+        [&](const events::command_started_event& event) { ports.insert(event.port()); });
+    options::client client_opts;
+    client_opts.apm_opts(apm_opts);
+    mongocxx::client client{uri, client_opts};
+
+    auto test = client["test"]["test"];
+    test.insert_one(make_document());
+
+    auto s = client.start_session();
+    s.start_transaction();
+    test.insert_one(s, make_document());
+    s.commit_transaction();
+
+    // Prose Test 1
+    SECTION("Unpin for next transaction") {
+        for (int i = 0; i < 50; ++i) {
+            s.start_transaction();
+            auto cursor = test.find(s, {});
+            REQUIRE(cursor.begin() != cursor.end());
+            s.commit_transaction();
+        }
+
+        REQUIRE(ports.size() > 1u);
+    }
+
+    // Prose Test 2
+    SECTION("Unpin for non-transaction operation") {
+        for (int i = 0; i < 50; ++i) {
+            auto cursor = test.find(s, {});
+            REQUIRE(cursor.begin() != cursor.end());
+        }
+
+        REQUIRE(ports.size() > 1u);
+    }
+}
+
 }  // namespace
